@@ -19,7 +19,7 @@
 package org.apache.commons.compress.archivers;
 
 /**
- * Archiver related Exception
+ * Archiver related Exception 
  */
 public class ArchiveException extends Exception {
 
@@ -29,23 +29,23 @@ public class ArchiveException extends Exception {
     /**
      * Constructs a new exception with the specified detail message. The cause
      * is not initialized.
-     *
+     * 
      * @param message
      *            the detail message
      */
-    public ArchiveException(final String message) {
+    public ArchiveException(String message) {
         super(message);
     }
 
     /**
      * Constructs a new exception with the specified detail message and cause.
-     *
+     * 
      * @param message
      *            the detail message
      * @param cause
      *            the cause
      */
-    public ArchiveException(final String message, final Exception cause) {
+    public ArchiveException(String message, Exception cause) {
         super(message);
         this.initCause(cause);
     }
