@@ -40,6 +40,7 @@ import org.apache.commons.compress.archivers.dump.DumpArchiveInputStream;
 import org.apache.commons.compress.archivers.jar.JarArchiveInputStream;
 import org.apache.commons.compress.archivers.jar.JarArchiveOutputStream;
 import org.apache.commons.compress.archivers.sevenz.SevenZFile;
+import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
@@ -78,7 +79,7 @@ import org.apache.commons.compress.utils.Sets;
  * out.close();
  * in.close();
  * </pre>
- * 
+ *
  * @Immutable provided that the deprecated method setEntryEncoding is not used.
  * @ThreadSafe even if the deprecated method setEntryEncoding is used
  */
@@ -86,13 +87,15 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     private static final int TAR_HEADER_SIZE = 512;
 
+    private static final int TAR_TEST_ENTRY_COUNT = 10;
+
     private static final int DUMP_SIGNATURE_SIZE = 32;
 
     private static final int SIGNATURE_SIZE = 12;
 
     /**
      * The singleton instance using the platform default encoding.
-     * 
+     *
      * @since 1.21
      */
     public static final ArchiveStreamFactory DEFAULT = new ArchiveStreamFactory();
@@ -139,56 +142,56 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     /**
      * Constant (value {@value}) used to identify the AR archive format.
-     * 
+     *
      * @since 1.1
      */
     public static final String AR = "ar";
 
     /**
      * Constant (value {@value}) used to identify the ARJ archive format. Not supported as an output stream type.
-     * 
+     *
      * @since 1.6
      */
     public static final String ARJ = "arj";
 
     /**
      * Constant (value {@value}) used to identify the CPIO archive format.
-     * 
+     *
      * @since 1.1
      */
     public static final String CPIO = "cpio";
 
     /**
-     * Constant (value {@value}) used to identify the Unix DUMP archive format. Not supported as an output stream type.
-     * 
+     * Constant (value {@value}) used to identify the UNIX DUMP archive format. Not supported as an output stream type.
+     *
      * @since 1.3
      */
     public static final String DUMP = "dump";
 
     /**
      * Constant (value {@value}) used to identify the JAR archive format.
-     * 
+     *
      * @since 1.1
      */
     public static final String JAR = "jar";
 
     /**
      * Constant used to identify the TAR archive format.
-     * 
+     *
      * @since 1.1
      */
     public static final String TAR = "tar";
 
     /**
      * Constant (value {@value}) used to identify the ZIP archive format.
-     * 
+     *
      * @since 1.1
      */
     public static final String ZIP = "zip";
 
     /**
      * Constant (value {@value}) used to identify the 7z archive format.
-     * 
+     *
      * @since 1.8
      */
     public static final String SEVEN_Z = "7z";
@@ -199,7 +202,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     /**
      * Try to determine the type of Archiver
-     * 
+     *
      * @param in input stream
      * @return type of archiver if found
      * @throws ArchiveException if an archiver cannot be detected in the stream
@@ -224,9 +227,11 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
             throw new ArchiveException("IOException while reading signature.", e);
         }
 
+        // For now JAR files are detected as ZIP files.
         if (ZipArchiveInputStream.matches(signature, signatureLength)) {
             return ZIP;
         }
+        // For now JAR files are detected as ZIP files.
         if (JarArchiveInputStream.matches(signature, signatureLength)) {
             return JAR;
         }
@@ -269,18 +274,22 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
             return TAR;
         }
 
-        // COMPRESS-117 - improve auto-recognition
+        // COMPRESS-117
         if (signatureLength >= TAR_HEADER_SIZE) {
-            try (TarArchiveInputStream tais = new TarArchiveInputStream(new ByteArrayInputStream(tarHeader))) {
+            try (TarArchiveInputStream inputStream = new TarArchiveInputStream(new ByteArrayInputStream(tarHeader))) {
                 // COMPRESS-191 - verify the header checksum
-                if (tais.getNextEntry().isCheckSumOK()) {
+                // COMPRESS-644 - do not allow zero byte file entries
+                TarArchiveEntry entry = inputStream.getNextEntry();
+                // try to find the first non-directory entry within the first 10 entries.
+                int count = 0;
+                while (entry != null && entry.isDirectory() && entry.isCheckSumOK() && count++ < TAR_TEST_ENTRY_COUNT) {
+                    entry = inputStream.getNextEntry();
+                }
+                if (entry != null && entry.isCheckSumOK() && !entry.isDirectory() && entry.getSize() > 0 || count > 0) {
                     return TAR;
                 }
-            } catch (final Exception e) { // NOPMD NOSONAR
-                // can generate IllegalArgumentException as well
-                // as IOException
-                // autodetection, simply not a TAR
-                // ignored
+            } catch (final Exception ignored) {
+                // can generate IllegalArgumentException as well as IOException auto-detection, simply not a TAR ignored
             }
         }
         throw new ArchiveException("No Archiver found for the stream signature");
@@ -352,11 +361,6 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
         return name.toUpperCase(Locale.ROOT);
     }
 
-    /**
-     * Entry encoding, null for the platform default.
-     */
-    private final String encoding;
-
     /**
      * Entry encoding, null for the default.
      */
@@ -367,27 +371,25 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
     private SortedMap<String, ArchiveStreamProvider> archiveOutputStreamProviders;
 
     /**
-     * Create an instance using the platform default encoding.
+     * Constructs an instance using the platform default encoding.
      */
     public ArchiveStreamFactory() {
         this(null);
     }
 
     /**
-     * Create an instance using the specified encoding.
+     * Constructs an instance using the specified encoding.
      *
-     * @param encoding the encoding to be used.
+     * @param entryEncoding the encoding to be used.
      *
      * @since 1.10
      */
-    public ArchiveStreamFactory(final String encoding) {
-        this.encoding = encoding;
-        // Also set the original field so can continue to use it.
-        this.entryEncoding = encoding;
+    public ArchiveStreamFactory(final String entryEncoding) {
+        this.entryEncoding = entryEncoding;
     }
 
     /**
-     * Create an archive input stream from an input stream, autodetecting the archive type from the first few bytes of the stream. The InputStream must support
+     * Creates an archive input stream from an input stream, autodetecting the archive type from the first few bytes of the stream. The InputStream must support
      * marks, like BufferedInputStream.
      *
      * @param <I> The {@link ArchiveInputStream} type.
@@ -589,14 +591,9 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * @param entryEncoding the entry encoding, null uses the archiver default.
      * @since 1.5
      * @deprecated 1.10 use {@link #ArchiveStreamFactory(String)} to specify the encoding
-     * @throws IllegalStateException if the constructor {@link #ArchiveStreamFactory(String)} was used to specify the factory encoding.
      */
     @Deprecated
     public void setEntryEncoding(final String entryEncoding) {
-        // Note: this does not detect new ArchiveStreamFactory(null) but that does not set the encoding anyway
-        if (encoding != null) {
-            throw new IllegalStateException("Cannot overide encoding set by the constructor");
-        }
         this.entryEncoding = entryEncoding;
     }
 
