@@ -21,65 +21,42 @@ package org.apache.commons.compress.archivers.jar;
 import java.io.IOException;
 import java.io.InputStream;
 
+import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
 
 /**
  * Implements an input stream that can read entries from jar files.
- *
+ * 
  * @NotThreadSafe
  */
 public class JarArchiveInputStream extends ZipArchiveInputStream {
 
+    public JarArchiveInputStream( final InputStream inputStream ) {
+        super(inputStream);
+    }
+
+    public JarArchiveEntry getNextJarEntry() throws IOException {
+        ZipArchiveEntry entry = getNextZipEntry();
+        return entry == null ? null : new JarArchiveEntry(entry);
+    }
+
+    @Override
+    public ArchiveEntry getNextEntry() throws IOException {
+        return getNextJarEntry();
+    }
+
     /**
      * Checks if the signature matches what is expected for a jar file
-     * (in this case it is the same as for a ZIP file).
-     *
+     * (in this case it is the same as for a zip file).
+     * 
      * @param signature
      *            the bytes to check
      * @param length
      *            the number of bytes to check
      * @return true, if this stream is a jar archive stream, false otherwise
      */
-    public static boolean matches(final byte[] signature, final int length ) {
+    public static boolean matches(byte[] signature, int length ) {
         return ZipArchiveInputStream.matches(signature, length);
     }
-
-    /**
-     * Creates an instance from the input stream using the default encoding.
-     *
-     * @param inputStream the input stream to wrap
-     */
-    public JarArchiveInputStream( final InputStream inputStream ) {
-        super(inputStream);
-    }
-
-    /**
-     * Creates an instance from the input stream using the specified encoding.
-     *
-     * @param inputStream the input stream to wrap
-     * @param encoding the encoding to use
-     * @since 1.10
-     */
-    public JarArchiveInputStream( final InputStream inputStream, final String encoding ) {
-        super(inputStream, encoding);
-    }
-
-    @Override
-    public JarArchiveEntry getNextEntry() throws IOException {
-        return getNextJarEntry();
-    }
-
-    /**
-     * Gets the next entry.
-     *
-     * @return the next entry.
-     * @throws IOException
-     * @deprecated Use {@link #getNextEntry()}.
-     */
-    @Deprecated
-    public JarArchiveEntry getNextJarEntry() throws IOException {
-        final ZipArchiveEntry entry = getNextZipEntry();
-        return entry == null ? null : new JarArchiveEntry(entry);
-    }
 }
