@@ -52,8 +52,8 @@ import java.util.stream.StreamSupport;
 import java.util.zip.CRC32;
 
 import org.apache.commons.compress.archivers.ArchiveEntry;
-import org.apache.commons.compress.utils.CountingOutputStream;
-import org.apache.commons.compress.utils.TimeUtils;
+import org.apache.commons.io.file.attribute.FileTimes;
+import org.apache.commons.io.output.CountingOutputStream;
 
 /**
  * Writes a 7z file.
@@ -79,12 +79,11 @@ public class SevenZOutputFile implements Closeable {
 
         @Override
         public void write(final byte[] b) throws IOException {
-            OutputStreamWrapper.this.write(b, 0, b.length);
+            write(b, 0, b.length);
         }
 
         @Override
-        public void write(final byte[] b, final int off, final int len)
-            throws IOException {
+        public void write(final byte[] b, final int off, final int len) throws IOException {
             if (len > BUF_SIZE) {
                 channel.write(ByteBuffer.wrap(b, off, len));
             } else {
@@ -105,6 +104,7 @@ public class SevenZOutputFile implements Closeable {
             fileBytesWritten++;
         }
     }
+
     private static <T> Iterable<T> reverse(final Iterable<T> i) {
         final LinkedList<T> l = new LinkedList<>();
         for (final T t : i) {
@@ -112,6 +112,7 @@ public class SevenZOutputFile implements Closeable {
         }
         return l;
     }
+
     private final SeekableByteChannel channel;
     private final List<SevenZArchiveEntry> files = new ArrayList<>();
     private int numNonEmptyStreams;
@@ -121,11 +122,8 @@ public class SevenZOutputFile implements Closeable {
     private boolean finished;
     private CountingOutputStream currentOutputStream;
     private CountingOutputStream[] additionalCountingStreams;
-    private Iterable<? extends SevenZMethodConfiguration> contentMethods =
-            Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA2));
-
+    private Iterable<? extends SevenZMethodConfiguration> contentMethods = Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA2));
     private final Map<SevenZArchiveEntry, long[]> additionalSizes = new HashMap<>();
-
     private AES256Options aes256Options;
 
     /**
@@ -147,21 +145,16 @@ public class SevenZOutputFile implements Closeable {
      * @since 1.23
      */
     public SevenZOutputFile(final File fileName, final char[] password) throws IOException {
-        this(
-            Files.newByteChannel(
-                fileName.toPath(),
-                EnumSet.of(StandardOpenOption.CREATE, StandardOpenOption.WRITE, StandardOpenOption.TRUNCATE_EXISTING)
-            ),
-            password
-        );
+        this(Files.newByteChannel(fileName.toPath(), EnumSet.of(StandardOpenOption.CREATE, StandardOpenOption.WRITE, StandardOpenOption.TRUNCATE_EXISTING)),
+                password);
     }
 
     /**
      * Prepares channel to write a 7z archive to.
      *
-     * <p>{@link
-     * org.apache.commons.compress.utils.SeekableInMemoryByteChannel}
-     * allows you to write to an in-memory archive.</p>
+     * <p>
+     * {@link org.apache.commons.compress.utils.SeekableInMemoryByteChannel} allows you to write to an in-memory archive.
+     * </p>
      *
      * @param channel the channel to write to
      * @throws IOException if the channel cannot be positioned properly
@@ -174,11 +167,11 @@ public class SevenZOutputFile implements Closeable {
     /**
      * Prepares channel to write a 7z archive to.
      *
-     * <p>{@link
-     * org.apache.commons.compress.utils.SeekableInMemoryByteChannel}
-     * allows you to write to an in-memory archive.</p>
+     * <p>
+     * {@link org.apache.commons.compress.utils.SeekableInMemoryByteChannel} allows you to write to an in-memory archive.
+     * </p>
      *
-     * @param channel the channel to write to
+     * @param channel  the channel to write to
      * @param password optional password if the archive has to be encrypted
      * @throws IOException if the channel cannot be positioned properly
      * @since 1.23
@@ -209,6 +202,7 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Closes the archive entry.
+     *
      * @throws IOException on error
      */
     public void closeArchiveEntry() throws IOException {
@@ -221,14 +215,14 @@ public class SevenZOutputFile implements Closeable {
         if (fileBytesWritten > 0) { // this implies currentOutputStream != null
             entry.setHasStream(true);
             ++numNonEmptyStreams;
-            entry.setSize(currentOutputStream.getBytesWritten()); //NOSONAR
+            entry.setSize(currentOutputStream.getByteCount()); // NOSONAR
             entry.setCompressedSize(fileBytesWritten);
             entry.setCrcValue(crc32.getValue());
             entry.setCompressedCrcValue(compressedCrc32.getValue());
             entry.setHasCrc(true);
             if (additionalCountingStreams != null) {
                 final long[] sizes = new long[additionalCountingStreams.length];
-                Arrays.setAll(sizes, i -> additionalCountingStreams[i].getBytesWritten());
+                Arrays.setAll(sizes, i -> additionalCountingStreams[i].getByteCount());
                 additionalSizes.put(entry, sizes);
             }
         } else {
@@ -245,14 +239,13 @@ public class SevenZOutputFile implements Closeable {
     }
 
     /**
-     * Create an archive entry using the inputFile and entryName provided.
+     * Creates an archive entry using the inputFile and entryName provided.
      *
      * @param inputFile file to create an entry from
      * @param entryName the name to use
      * @return the ArchiveEntry set up with details from the file
      */
-    public SevenZArchiveEntry createArchiveEntry(final File inputFile,
-            final String entryName) {
+    public SevenZArchiveEntry createArchiveEntry(final File inputFile, final String entryName) {
         final SevenZArchiveEntry entry = new SevenZArchiveEntry();
         entry.setDirectory(inputFile.isDirectory());
         entry.setName(entryName);
@@ -265,18 +258,17 @@ public class SevenZOutputFile implements Closeable {
     }
 
     /**
-     * Create an archive entry using the inputPath and entryName provided.
+     * Creates an archive entry using the inputPath and entryName provided.
      *
      * @param inputPath path to create an entry from
      * @param entryName the name to use
-     * @param options options indicating how symbolic links are handled.
+     * @param options   options indicating how symbolic links are handled.
      * @return the ArchiveEntry set up with details from the file
      *
      * @throws IOException on error
      * @since 1.21
      */
-    public SevenZArchiveEntry createArchiveEntry(final Path inputPath,
-        final String entryName, final LinkOption... options) throws IOException {
+    public SevenZArchiveEntry createArchiveEntry(final Path inputPath, final String entryName, final LinkOption... options) throws IOException {
         final SevenZArchiveEntry entry = new SevenZArchiveEntry();
         entry.setDirectory(Files.isDirectory(inputPath, options));
         entry.setName(entryName);
@@ -284,8 +276,7 @@ public class SevenZOutputFile implements Closeable {
         return entry;
     }
 
-    private void fillDates(final Path inputPath, final SevenZArchiveEntry entry,
-        final LinkOption... options) throws IOException {
+    private void fillDates(final Path inputPath, final SevenZArchiveEntry entry, final LinkOption... options) throws IOException {
         final BasicFileAttributes attributes = Files.readAttributes(inputPath, BasicFileAttributes.class, options);
         entry.setLastModifiedTime(attributes.lastModifiedTime());
         entry.setCreationTime(attributes.creationTime());
@@ -316,13 +307,11 @@ public class SevenZOutputFile implements Closeable {
         final CRC32 crc32 = new CRC32();
         crc32.update(headerBytes);
 
-        final ByteBuffer bb = ByteBuffer.allocate(SevenZFile.sevenZSignature.length
-                                            + 2 /* version */
-                                            + 4 /* start header CRC */
-                                            + 8 /* next header position */
-                                            + 8 /* next header length */
-                                            + 4 /* next header CRC */)
-            .order(ByteOrder.LITTLE_ENDIAN);
+        final ByteBuffer bb = ByteBuffer.allocate(SevenZFile.sevenZSignature.length + 2 /* version */
+                + 4 /* start header CRC */
+                + 8 /* next header position */
+                + 8 /* next header length */
+                + 4 /* next header CRC */).order(ByteOrder.LITTLE_ENDIAN);
         // signature header
         channel.position(0);
         bb.put(SevenZFile.sevenZSignature);
@@ -333,9 +322,7 @@ public class SevenZOutputFile implements Closeable {
         bb.putInt(0);
 
         // start header
-        bb.putLong(headerPosition - SevenZFile.SIGNATURE_HEADER_SIZE)
-            .putLong(0xffffFFFFL & headerBytes.length)
-            .putInt((int) crc32.getValue());
+        bb.putLong(headerPosition - SevenZFile.SIGNATURE_HEADER_SIZE).putLong(0xffffFFFFL & headerBytes.length).putInt((int) crc32.getValue());
         crc32.reset();
         crc32.update(bb.array(), SevenZFile.sevenZSignature.length + 6, 20);
         bb.putInt(SevenZFile.sevenZSignature.length + 2, (int) crc32.getValue());
@@ -349,21 +336,16 @@ public class SevenZOutputFile implements Closeable {
 
         if (aes256Options != null) {
             // prepend encryption
-            iter =
-                Stream
-                    .concat(
-                        Stream.of(new SevenZMethodConfiguration(SevenZMethod.AES256SHA256, aes256Options)),
-                        StreamSupport.stream(iter.spliterator(), false)
-                    )
+            iter = Stream
+                    .concat(Stream.of(new SevenZMethodConfiguration(SevenZMethod.AES256SHA256, aes256Options)), StreamSupport.stream(iter.spliterator(), false))
                     .collect(Collectors.toList());
         }
         return iter;
     }
 
     /*
-     * Creation of output stream is deferred until data is actually
-     * written as some codecs might write header information even for
-     * empty streams and directories otherwise.
+     * Creation of output stream is deferred until data is actually written as some codecs might write header information even for empty streams and directories
+     * otherwise.
      */
     private OutputStream getCurrentOutputStream() throws IOException {
         if (currentOutputStream == null) {
@@ -375,8 +357,7 @@ public class SevenZOutputFile implements Closeable {
     /**
      * Records an archive entry to add.
      *
-     * The caller must then write the content to the archive and call
-     * {@link #closeArchiveEntry()} to complete the process.
+     * The caller must then write the content to the archive and call {@link #closeArchiveEntry()} to complete the process.
      *
      * @param archiveEntry describes the entry
      * @deprecated Use {@link #putArchiveEntry(SevenZArchiveEntry)}.
@@ -389,8 +370,7 @@ public class SevenZOutputFile implements Closeable {
     /**
      * Records an archive entry to add.
      *
-     * The caller must then write the content to the archive and call
-     * {@link #closeArchiveEntry()} to complete the process.
+     * The caller must then write the content to the archive and call {@link #closeArchiveEntry()} to complete the process.
      *
      * @param archiveEntry describes the entry
      * @since 1.25.0
@@ -400,15 +380,16 @@ public class SevenZOutputFile implements Closeable {
     }
 
     /**
-     * Sets the default compression method to use for entry contents - the
-     * default is LZMA2.
+     * Sets the default compression method to use for entry contents - the default is LZMA2.
      *
-     * <p>Currently only {@link SevenZMethod#COPY}, {@link
-     * SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link
-     * SevenZMethod#DEFLATE} are supported.</p>
+     * <p>
+     * Currently only {@link SevenZMethod#COPY}, {@link SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link SevenZMethod#DEFLATE} are supported.
+     * </p>
+     *
+     * <p>
+     * This is a short form for passing a single-element iterable to {@link #setContentMethods}.
+     * </p>
      *
-     * <p>This is a short form for passing a single-element iterable
-     * to {@link #setContentMethods}.</p>
      * @param method the default compression method
      */
     public void setContentCompression(final SevenZMethod method) {
@@ -416,15 +397,15 @@ public class SevenZOutputFile implements Closeable {
     }
 
     /**
-     * Sets the default (compression) methods to use for entry contents - the
-     * default is LZMA2.
+     * Sets the default (compression) methods to use for entry contents - the default is LZMA2.
      *
-     * <p>Currently only {@link SevenZMethod#COPY}, {@link
-     * SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link
-     * SevenZMethod#DEFLATE} are supported.</p>
+     * <p>
+     * Currently only {@link SevenZMethod#COPY}, {@link SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link SevenZMethod#DEFLATE} are supported.
+     * </p>
      *
-     * <p>The methods will be consulted in iteration order to create
-     * the final output.</p>
+     * <p>
+     * The methods will be consulted in iteration order to create the final output.
+     * </p>
      *
      * @since 1.8
      * @param methods the default (compression) methods
@@ -462,8 +443,7 @@ public class SevenZOutputFile implements Closeable {
             }
 
             @Override
-            public void write(final byte[] b, final int off, final int len)
-                throws IOException {
+            public void write(final byte[] b, final int off, final int len) throws IOException {
                 super.write(b, off, len);
                 crc32.update(b, off, len);
             }
@@ -478,6 +458,7 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Writes a byte array to the current archive entry.
+     *
      * @param b The byte array to be written.
      * @throws IOException on error
      */
@@ -487,7 +468,8 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Writes part of a byte array to the current archive entry.
-     * @param b The byte array to be written.
+     *
+     * @param b   The byte array to be written.
      * @param off offset into the array to start writing from
      * @param len number of bytes to write
      * @throws IOException on error
@@ -500,6 +482,7 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Writes all of the given input stream to the current archive entry.
+     *
      * @param inputStream the data source.
      * @throws IOException if an I/O error occurs.
      * @since 1.21
@@ -514,6 +497,7 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Writes a byte to the current archive entry.
+     *
      * @param b The byte to be written.
      * @throws IOException on error
      */
@@ -523,7 +507,8 @@ public class SevenZOutputFile implements Closeable {
 
     /**
      * Writes all of the given input stream to the current archive entry.
-     * @param path the data source.
+     *
+     * @param path    the data source.
      * @param options options specifying how the file is opened.
      * @throws IOException if an I/O error occurs.
      * @since 1.21
@@ -598,7 +583,7 @@ public class SevenZOutputFile implements Closeable {
             out.write(0);
             for (final SevenZArchiveEntry entry : files) {
                 if (entry.getHasAccessDate()) {
-                    final long ntfsTime = TimeUtils.toNtfsTime(entry.getAccessTime());
+                    final long ntfsTime = FileTimes.toNtfsTime(entry.getAccessTime());
                     out.writeLong(Long.reverseBytes(ntfsTime));
                 }
             }
@@ -634,7 +619,7 @@ public class SevenZOutputFile implements Closeable {
             out.write(0);
             for (final SevenZArchiveEntry entry : files) {
                 if (entry.getHasCreationDate()) {
-                    final long ntfsTime = TimeUtils.toNtfsTime(entry.getCreationTime());
+                    final long ntfsTime = FileTimes.toNtfsTime(entry.getCreationTime());
                     out.writeLong(Long.reverseBytes(ntfsTime));
                 }
             }
@@ -711,7 +696,7 @@ public class SevenZOutputFile implements Closeable {
             out.write(0);
             for (final SevenZArchiveEntry entry : files) {
                 if (entry.getHasLastModifiedDate()) {
-                    final long ntfsTime = TimeUtils.toNtfsTime(entry.getLastModifiedTime());
+                    final long ntfsTime = FileTimes.toNtfsTime(entry.getLastModifiedTime());
                     out.writeLong(Long.reverseBytes(ntfsTime));
                 }
             }
@@ -840,8 +825,7 @@ public class SevenZOutputFile implements Closeable {
 
     private void writeSingleCodec(final SevenZMethodConfiguration m, final OutputStream bos) throws IOException {
         final byte[] id = m.getMethod().getId();
-        final byte[] properties = Coders.findByMethod(m.getMethod())
-            .getOptionsAsProperties(m.getOptions());
+        final byte[] properties = Coders.findByMethod(m.getMethod()).getOptionsAsProperties(m.getOptions());
 
         int codecFlags = id.length;
         if (properties.length > 0) {
@@ -870,13 +854,13 @@ public class SevenZOutputFile implements Closeable {
     private void writeSubStreamsInfo(final DataOutput header) throws IOException {
         header.write(NID.kSubStreamsInfo);
         //
-        //        header.write(NID.kCRC);
-        //        header.write(1);
-        //        for (final SevenZArchiveEntry entry : files) {
-        //            if (entry.getHasCrc()) {
-        //                header.writeInt(Integer.reverseBytes(entry.getCrc()));
-        //            }
-        //        }
+        // header.write(NID.kCRC);
+        // header.write(1);
+        // for (final SevenZArchiveEntry entry : files) {
+        // if (entry.getHasCrc()) {
+        // header.writeInt(Integer.reverseBytes(entry.getCrc()));
+        // }
+        // }
         //
         header.write(NID.kEnd);
     }
@@ -886,7 +870,7 @@ public class SevenZOutputFile implements Closeable {
         int mask = 0x80;
         int i;
         for (i = 0; i < 8; i++) {
-            if (value < 1L << 7  * (i + 1)) {
+            if (value < 1L << 7 * (i + 1)) {
                 firstByte |= value >>> 8 * i;
                 break;
             }
