@@ -22,9 +22,9 @@ package org.apache.commons.compress.archivers.zip;
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
-import java.util.Arrays;
 
 import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.lang3.ArrayFill;
 
 /**
  * Binary tree of positive values.
@@ -44,8 +44,7 @@ final class BinaryTree {
      */
     static BinaryTree decode(final InputStream inputStream, final int totalNumberOfValues) throws IOException {
         if (totalNumberOfValues < 0) {
-            throw new IllegalArgumentException("totalNumberOfValues must be bigger than 0, is "
-                + totalNumberOfValues);
+            throw new IllegalArgumentException("totalNumberOfValues must be bigger than 0, is " + totalNumberOfValues);
         }
         // the first byte contains the size of the structure minus one
         final int size = inputStream.read() + 1;
@@ -111,7 +110,7 @@ final class BinaryTree {
         final int[] codes = new int[totalNumberOfValues];
 
         for (int i = totalNumberOfValues - 1; i >= 0; i--) {
-            code = code + codeIncrement;
+            code += codeIncrement;
             if (sortedBitLengths[i] != lastBitLength) {
                 lastBitLength = sortedBitLengths[i];
                 codeIncrement = 1 << 16 - lastBitLength;
@@ -133,27 +132,24 @@ final class BinaryTree {
     }
 
     /**
-     * The array representing the binary tree. The root is at index 0,
-     * the left children are at 2*i+1 and the right children at 2*i+2.
+     * The array representing the binary tree. The root is at index 0, the left children are at 2*i+1 and the right children at 2*i+2.
      */
     private final int[] tree;
 
-    public BinaryTree(final int depth) {
+    BinaryTree(final int depth) {
         if (depth < 0 || depth > 30) {
-            throw new IllegalArgumentException("depth must be bigger than 0 and not bigger than 30"
-                + " but is " + depth);
+            throw new IllegalArgumentException("depth must be bigger than 0 and not bigger than 30" + " but is " + depth);
         }
-        tree = new int[(int) ((1L << depth + 1) - 1)];
-        Arrays.fill(tree, UNDEFINED);
+        tree = ArrayFill.fill(new int[(int) ((1L << depth + 1) - 1)], UNDEFINED);
     }
 
     /**
      * Adds a leaf to the tree.
      *
-     * @param node   the index of the node where the path is appended
-     * @param path   the path to the leaf (bits are parsed from the right to the left)
-     * @param depth  the number of nodes in the path
-     * @param value  the value of the leaf (must be positive)
+     * @param node  the index of the node where the path is appended
+     * @param path  the path to the leaf (bits are parsed from the right to the left)
+     * @param depth the number of nodes in the path
+     * @param value the value of the leaf (must be positive)
      */
     public void addLeaf(final int node, final int path, final int depth, final int value) {
         if (depth == 0) {
@@ -172,7 +168,6 @@ final class BinaryTree {
         }
     }
 
-
     /**
      * Reads a value from the specified bit stream.
      *
