@@ -26,21 +26,16 @@ package org.apache.commons.compress.compressors.bzip2;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.ByteOrder;
-import java.util.Arrays;
 
 import org.apache.commons.compress.compressors.CompressorInputStream;
-import org.apache.commons.compress.utils.BitInputStream;
-import org.apache.commons.compress.utils.CloseShieldFilterInputStream;
-import org.apache.commons.compress.utils.InputStreamStatistics;
 
 /**
  * An input stream that decompresses from the BZip2 format to be read as any other stream.
- *
+ * 
  * @NotThreadSafe
  */
-public class BZip2CompressorInputStream extends CompressorInputStream
-    implements BZip2Constants, InputStreamStatistics {
+public class BZip2CompressorInputStream extends CompressorInputStream implements
+                                                                          BZip2Constants {
 
     /**
      * Index of the last char in the block, so the block size == last + 1.
@@ -60,13 +55,17 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
     private boolean blockRandomised;
 
+    private int bsBuff;
+    private int bsLive;
     private final CRC crc = new CRC();
 
     private int nInUse;
 
-    private BitInputStream bin;
+    private InputStream in;
     private final boolean decompressConcatenated;
 
+    private int currentChar = -1;
+
     private static final int EOF = 0;
     private static final int START_BLOCK_STATE = 1;
     private static final int RAND_PART_A_STATE = 2;
@@ -100,14 +99,13 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
     /**
      * Constructs a new BZip2CompressorInputStream which decompresses bytes
-     * read from the specified stream. This doesn't support decompressing
+     * read from the specified stream. This doesn't suppprt decompressing
      * concatenated .bz2 files.
-     *
-     * @param in the InputStream from which this object should be created
+     * 
      * @throws IOException
      *             if the stream content is malformed or an I/O error occurs.
      * @throws NullPointerException
-     *             if {@code in == null}
+     *             if <tt>in == null</tt>
      */
     public BZip2CompressorInputStream(final InputStream in) throws IOException {
         this(in, false);
@@ -125,30 +123,33 @@ public class BZip2CompressorInputStream extends CompressorInputStream
      *                     byte after the .bz2 stream
      *
      * @throws IOException
-     *             if {@code in == null}, the stream content is malformed, or an I/O error occurs.
+     *             if the stream content is malformed or an I/O error occurs.
+     * @throws NullPointerException
+     *             if <tt>in == null</tt>
      */
     public BZip2CompressorInputStream(final InputStream in, final boolean decompressConcatenated) throws IOException {
-        this.bin = new BitInputStream(in == System.in ? new CloseShieldFilterInputStream(in) : in,
-            ByteOrder.BIG_ENDIAN);
+        this.in = in;
         this.decompressConcatenated = decompressConcatenated;
 
         init(true);
         initBlock();
+        setupBlock();
     }
 
     @Override
     public int read() throws IOException {
-        if (this.bin != null) {
-            final int r = read0();
+        if (this.in != null) {
+            int r = read0();
             count(r < 0 ? -1 : 1);
             return r;
+        } else {
+            throw new IOException("stream closed");
         }
-        throw new IOException("Stream closed");
     }
 
     /*
      * (non-Javadoc)
-     *
+     * 
      * @see java.io.InputStream#read(byte[], int, int)
      */
     @Override
@@ -164,30 +165,19 @@ public class BZip2CompressorInputStream extends CompressorInputStream
             throw new IndexOutOfBoundsException("offs(" + offs + ") + len("
                                                 + len + ") > dest.length(" + dest.length + ").");
         }
-        if (this.bin == null) {
-            throw new IOException("Stream closed");
-        }
-        if (len == 0) {
-            return 0;
+        if (this.in == null) {
+            throw new IOException("stream closed");
         }
 
         final int hi = offs + len;
         int destOffs = offs;
-        int b;
-        while (destOffs < hi && ((b = read0()) >= 0)) {
+        for (int b; (destOffs < hi) && ((b = read0()) >= 0);) {
             dest[destOffs++] = (byte) b;
-            count(1);
         }
 
-        return (destOffs == offs) ? -1 : (destOffs - offs);
-    }
-
-    /**
-     * @since 1.17
-     */
-    @Override
-    public long getCompressedCount() {
-        return bin.getBytesRead();
+        int c = (destOffs == offs) ? -1 : (destOffs - offs);
+        count(c);
+        return c;
     }
 
     private void makeMaps() {
@@ -206,56 +196,55 @@ public class BZip2CompressorInputStream extends CompressorInputStream
     }
 
     private int read0() throws IOException {
-        switch (currentState) {
+        final int retChar = this.currentChar;
+
+        switch (this.currentState) {
         case EOF:
             return -1;
 
         case START_BLOCK_STATE:
-            return setupBlock();
+            throw new IllegalStateException();
 
         case RAND_PART_A_STATE:
             throw new IllegalStateException();
 
         case RAND_PART_B_STATE:
-            return setupRandPartB();
+            setupRandPartB();
+            break;
 
         case RAND_PART_C_STATE:
-            return setupRandPartC();
+            setupRandPartC();
+            break;
 
         case NO_RAND_PART_A_STATE:
             throw new IllegalStateException();
 
         case NO_RAND_PART_B_STATE:
-            return setupNoRandPartB();
+            setupNoRandPartB();
+            break;
 
         case NO_RAND_PART_C_STATE:
-            return setupNoRandPartC();
+            setupNoRandPartC();
+            break;
 
         default:
             throw new IllegalStateException();
         }
+
+        return retChar;
     }
 
-    private int readNextByte(final BitInputStream in) throws IOException {
-        final long b = in.readBits(8);
-        return (int) b;
-    }
-
-    private boolean init(final boolean isFirstStream) throws IOException {
-        if (null == bin) {
+    private boolean init(boolean isFirstStream) throws IOException {
+        if (null == in) {
             throw new IOException("No InputStream");
         }
 
-        if (!isFirstStream) {
-            bin.clearBitCache();
-        }
-
-        final int magic0 = readNextByte(this.bin);
+        int magic0 = this.in.read();
         if (magic0 == -1 && !isFirstStream) {
             return false;
         }
-        final int magic1 = readNextByte(this.bin);
-        final int magic2 = readNextByte(this.bin);
+        int magic1 = this.in.read();
+        int magic2 = this.in.read();
 
         if (magic0 != 'B' || magic1 != 'Z' || magic2 != 'h') {
             throw new IOException(isFirstStream
@@ -263,20 +252,20 @@ public class BZip2CompressorInputStream extends CompressorInputStream
                     : "Garbage after a valid BZip2 stream");
         }
 
-        final int blockSize = readNextByte(this.bin);
+        int blockSize = this.in.read();
         if ((blockSize < '1') || (blockSize > '9')) {
             throw new IOException("BZip2 block size is invalid");
         }
 
         this.blockSize100k = blockSize - '0';
 
+        this.bsLive = 0;
         this.computedCombinedCRC = 0;
 
         return true;
     }
 
     private void initBlock() throws IOException {
-        final BitInputStream bin = this.bin;
         char magic0;
         char magic1;
         char magic2;
@@ -286,12 +275,12 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
         while (true) {
             // Get the block magic bytes.
-            magic0 = bsGetUByte(bin);
-            magic1 = bsGetUByte(bin);
-            magic2 = bsGetUByte(bin);
-            magic3 = bsGetUByte(bin);
-            magic4 = bsGetUByte(bin);
-            magic5 = bsGetUByte(bin);
+            magic0 = bsGetUByte();
+            magic1 = bsGetUByte();
+            magic2 = bsGetUByte();
+            magic3 = bsGetUByte();
+            magic4 = bsGetUByte();
+            magic5 = bsGetUByte();
 
             // If isn't end of stream magic, break out of the loop.
             if (magic0 != 0x17 || magic1 != 0x72 || magic2 != 0x45
@@ -315,24 +304,25 @@ public class BZip2CompressorInputStream extends CompressorInputStream
             magic5 != 0x59 // 'Y'
             ) {
             this.currentState = EOF;
-            throw new IOException("Bad block header");
+            throw new IOException("bad block header");
+        } else {
+            this.storedBlockCRC = bsGetInt();
+            this.blockRandomised = bsR(1) == 1;
+
+            /**
+             * Allocate data here instead in constructor, so we do not allocate
+             * it if the input file is empty.
+             */
+            if (this.data == null) {
+                this.data = new Data(this.blockSize100k);
+            }
+
+            // currBlockNo++;
+            getAndMoveToFrontDecode();
+
+            this.crc.initialiseCRC();
+            this.currentState = START_BLOCK_STATE;
         }
-        this.storedBlockCRC = bsGetInt(bin);
-        this.blockRandomised = bsR(bin, 1) == 1;
-
-        /*
-         * Allocate data here instead in constructor, so we do not allocate
-         * it if the input file is empty.
-         */
-        if (this.data == null) {
-            this.data = new Data(this.blockSize100k);
-        }
-
-        // currBlockNo++;
-        getAndMoveToFrontDecode();
-
-        this.crc.initializeCRC();
-        this.currentState = START_BLOCK_STATE;
     }
 
     private void endBlock() throws IOException {
@@ -355,7 +345,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
     }
 
     private boolean complete() throws IOException {
-        this.storedCombinedCRC = bsGetInt(bin);
+        this.storedCombinedCRC = bsGetInt();
         this.currentState = EOF;
         this.data = null;
 
@@ -370,51 +360,69 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
     @Override
     public void close() throws IOException {
-        final BitInputStream inShadow = this.bin;
+        InputStream inShadow = this.in;
         if (inShadow != null) {
             try {
-                inShadow.close();
+                if (inShadow != System.in) {
+                    inShadow.close();
+                }
             } finally {
                 this.data = null;
-                this.bin = null;
+                this.in = null;
             }
         }
     }
 
-    /**
-     * read bits from the input stream
-     * @param n the number of bits to read, must not exceed 32?
-     * @return the requested bits combined into an int
-     * @throws IOException
-     */
-    private static int bsR(final BitInputStream bin, final int n) throws IOException {
-        final long thech = bin.readBits(n);
-        if (thech < 0) {
-            throw new IOException("Unexpected end of stream");
+    private int bsR(final int n) throws IOException {
+        int bsLiveShadow = this.bsLive;
+        int bsBuffShadow = this.bsBuff;
+
+        if (bsLiveShadow < n) {
+            final InputStream inShadow = this.in;
+            do {
+                int thech = inShadow.read();
+
+                if (thech < 0) {
+                    throw new IOException("unexpected end of stream");
+                }
+
+                bsBuffShadow = (bsBuffShadow << 8) | thech;
+                bsLiveShadow += 8;
+            } while (bsLiveShadow < n);
+
+            this.bsBuff = bsBuffShadow;
         }
-        return (int) thech;
+
+        this.bsLive = bsLiveShadow - n;
+        return (bsBuffShadow >> (bsLiveShadow - n)) & ((1 << n) - 1);
     }
 
-    private static boolean bsGetBit(final BitInputStream bin) throws IOException {
-        return bsR(bin, 1) != 0;
-    }
+    private boolean bsGetBit() throws IOException {
+        int bsLiveShadow = this.bsLive;
+        int bsBuffShadow = this.bsBuff;
 
-    private static char bsGetUByte(final BitInputStream bin) throws IOException {
-        return (char) bsR(bin, 8);
-    }
+        if (bsLiveShadow < 1) {
+            int thech = this.in.read();
 
-    private static int bsGetInt(final BitInputStream bin) throws IOException {
-        return bsR(bin, 32);
-    }
+            if (thech < 0) {
+                throw new IOException("unexpected end of stream");
+            }
 
-    private static void checkBounds(final int checkVal, final int limitExclusive, final String name)
-        throws IOException {
-        if (checkVal < 0) {
-            throw new IOException("Corrupted input, " + name + " value negative");
-        }
-        if (checkVal >= limitExclusive) {
-            throw new IOException("Corrupted input, " + name + " value too big");
+            bsBuffShadow = (bsBuffShadow << 8) | thech;
+            bsLiveShadow += 8;
+            this.bsBuff = bsBuffShadow;
         }
+
+        this.bsLive = bsLiveShadow - 1;
+        return ((bsBuffShadow >> (bsLiveShadow - 1)) & 1) != 0;
+    }
+
+    private char bsGetUByte() throws IOException {
+        return (char) bsR(8);
+    }
+
+    private int bsGetInt() throws IOException {
+        return (((((bsR(8) << 8) | bsR(8)) << 8) | bsR(8)) << 8) | bsR(8);
     }
 
     /**
@@ -422,8 +430,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
      */
     private static void hbCreateDecodeTables(final int[] limit,
                                              final int[] base, final int[] perm, final char[] length,
-                                             final int minLen, final int maxLen, final int alphaSize)
-        throws IOException {
+                                             final int minLen, final int maxLen, final int alphaSize) {
         for (int i = minLen, pp = 0; i <= maxLen; i++) {
             for (int j = 0; j < alphaSize; j++) {
                 if (length[j] == i) {
@@ -438,9 +445,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
         }
 
         for (int i = 0; i < alphaSize; i++) {
-            final int l = length[i];
-            checkBounds(l, MAX_ALPHA_SIZE, "length");
-            base[l + 1]++;
+            base[length[i] + 1]++;
         }
 
         for (int i = 1, b = base[0]; i < MAX_CODE_LEN; i++) {
@@ -462,7 +467,6 @@ public class BZip2CompressorInputStream extends CompressorInputStream
     }
 
     private void recvDecodingTables() throws IOException {
-        final BitInputStream bin = this.bin;
         final Data dataShadow = this.data;
         final boolean[] inUse = dataShadow.inUse;
         final byte[] pos = dataShadow.recvDecodingTables_pos;
@@ -473,17 +477,20 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
         /* Receive the mapping table */
         for (int i = 0; i < 16; i++) {
-            if (bsGetBit(bin)) {
+            if (bsGetBit()) {
                 inUse16 |= 1 << i;
             }
         }
 
-        Arrays.fill(inUse, false);
+        for (int i = 256; --i >= 0;) {
+            inUse[i] = false;
+        }
+
         for (int i = 0; i < 16; i++) {
             if ((inUse16 & (1 << i)) != 0) {
                 final int i16 = i << 4;
                 for (int j = 0; j < 16; j++) {
-                    if (bsGetBit(bin)) {
+                    if (bsGetBit()) {
                         inUse[i16 + j] = true;
                     }
                 }
@@ -492,29 +499,18 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
         makeMaps();
         final int alphaSize = this.nInUse + 2;
+
         /* Now the selectors */
-        final int nGroups = bsR(bin, 3);
-        final int selectors = bsR(bin, 15);
-        if (selectors < 0) {
-            throw new IOException("Corrupted input, nSelectors value negative");
-        }
-        checkBounds(alphaSize, MAX_ALPHA_SIZE + 1, "alphaSize");
-        checkBounds(nGroups, N_GROUPS + 1, "nGroups");
+        final int nGroups = bsR(3);
+        final int nSelectors = bsR(15);
 
-        // Don't fail on nSelectors overflowing boundaries but discard the values in overflow
-        // See https://gnu.wildebeest.org/blog/mjw/2019/08/02/bzip2-and-the-cve-that-wasnt/
-        // and https://sourceware.org/ml/bzip2-devel/2019-q3/msg00007.html
-
-        for (int i = 0; i < selectors; i++) {
+        for (int i = 0; i < nSelectors; i++) {
             int j = 0;
-            while (bsGetBit(bin)) {
+            while (bsGetBit()) {
                 j++;
             }
-            if (i < MAX_SELECTORS) {
-                selectorMtf[i] = (byte) j;
-            }
+            selectorMtf[i] = (byte) j;
         }
-        final int nSelectors = selectors > MAX_SELECTORS ? MAX_SELECTORS : selectors;
 
         /* Undo the MTF values for the selectors. */
         for (int v = nGroups; --v >= 0;) {
@@ -523,7 +519,6 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
         for (int i = 0; i < nSelectors; i++) {
             int v = selectorMtf[i] & 0xff;
-            checkBounds(v, N_GROUPS, "selectorMtf");
             final byte tmp = pos[v];
             while (v > 0) {
                 // nearly all times v is zero, 4 in most other cases
@@ -538,11 +533,11 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
         /* Now the coding tables */
         for (int t = 0; t < nGroups; t++) {
-            int curr = bsR(bin, 5);
+            int curr = bsR(5);
             final char[] len_t = len[t];
             for (int i = 0; i < alphaSize; i++) {
-                while (bsGetBit(bin)) {
-                    curr += bsGetBit(bin) ? -1 : 1;
+                while (bsGetBit()) {
+                    curr += bsGetBit() ? -1 : 1;
                 }
                 len_t[i] = (char) curr;
             }
@@ -556,7 +551,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
      * Called by recvDecodingTables() exclusively.
      */
     private void createHuffmanDecodingTables(final int alphaSize,
-                                             final int nGroups) throws IOException {
+                                             final int nGroups) {
         final Data dataShadow = this.data;
         final char[][] len = dataShadow.temp_charArray2d;
         final int[] minLens = dataShadow.minLens;
@@ -584,10 +579,10 @@ public class BZip2CompressorInputStream extends CompressorInputStream
     }
 
     private void getAndMoveToFrontDecode() throws IOException {
-        final BitInputStream bin = this.bin;
-        this.origPtr = bsR(bin, 24);
+        this.origPtr = bsR(24);
         recvDecodingTables();
 
+        final InputStream inShadow = this.in;
         final Data dataShadow = this.data;
         final byte[] ll8 = dataShadow.ll8;
         final int[] unzftab = dataShadow.unzftab;
@@ -613,10 +608,11 @@ public class BZip2CompressorInputStream extends CompressorInputStream
         int groupNo = 0;
         int groupPos = G_SIZE - 1;
         final int eob = this.nInUse + 1;
-        int nextSym = getAndMoveToFrontDecode0();
+        int nextSym = getAndMoveToFrontDecode0(0);
+        int bsBuffShadow = this.bsBuff;
+        int bsLiveShadow = this.bsLive;
         int lastShadow = -1;
         int zt = selector[groupNo] & 0xff;
-        checkBounds(zt, N_GROUPS, "zt");
         int[] base_zt = base[zt];
         int[] limit_zt = limit[zt];
         int[] perm_zt = perm[zt];
@@ -637,9 +633,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
                     if (groupPos == 0) {
                         groupPos = G_SIZE - 1;
-                        checkBounds(++groupNo, MAX_SELECTORS, "groupNo");
-                        zt = selector[groupNo] & 0xff;
-                        checkBounds(zt, N_GROUPS, "zt");
+                        zt = selector[++groupNo] & 0xff;
                         base_zt = base[zt];
                         limit_zt = limit[zt];
                         perm_zt = perm[zt];
@@ -649,41 +643,59 @@ public class BZip2CompressorInputStream extends CompressorInputStream
                     }
 
                     int zn = minLens_zt;
-                    checkBounds(zn, MAX_ALPHA_SIZE, "zn");
-                    int zvec = bsR(bin, zn);
-                    while(zvec > limit_zt[zn]) {
-                        checkBounds(++zn, MAX_ALPHA_SIZE, "zn");
-                        zvec = (zvec << 1) | bsR(bin, 1);
-                    }
-                    final int tmp = zvec - base_zt[zn];
-                    checkBounds(tmp, MAX_ALPHA_SIZE, "zvec");
-                    nextSym = perm_zt[tmp];
-                }
-                checkBounds(s, this.data.ll8.length, "s");
 
-                final int yy0 = yy[0];
-                checkBounds(yy0, 256, "yy");
-                final byte ch = seqToUnseq[yy0];
+                    // Inlined:
+                    // int zvec = bsR(zn);
+                    while (bsLiveShadow < zn) {
+                        final int thech = inShadow.read();
+                        if (thech >= 0) {
+                            bsBuffShadow = (bsBuffShadow << 8) | thech;
+                            bsLiveShadow += 8;
+                            continue;
+                        } else {
+                            throw new IOException("unexpected end of stream");
+                        }
+                    }
+                    int zvec = (bsBuffShadow >> (bsLiveShadow - zn))
+                        & ((1 << zn) - 1);
+                    bsLiveShadow -= zn;
+
+                    while (zvec > limit_zt[zn]) {
+                        zn++;
+                        while (bsLiveShadow < 1) {
+                            final int thech = inShadow.read();
+                            if (thech >= 0) {
+                                bsBuffShadow = (bsBuffShadow << 8) | thech;
+                                bsLiveShadow += 8;
+                                continue;
+                            } else {
+                                throw new IOException(
+                                                      "unexpected end of stream");
+                            }
+                        }
+                        bsLiveShadow--;
+                        zvec = (zvec << 1)
+                            | ((bsBuffShadow >> bsLiveShadow) & 1);
+                    }
+                    nextSym = perm_zt[zvec - base_zt[zn]];
+                }
+
+                final byte ch = seqToUnseq[yy[0]];
                 unzftab[ch & 0xff] += s + 1;
 
-                final int from = ++lastShadow;
-                lastShadow += s;
-                checkBounds(lastShadow, this.data.ll8.length, "lastShadow");
-                Arrays.fill(ll8, from, lastShadow + 1, ch);
+                while (s-- >= 0) {
+                    ll8[++lastShadow] = ch;
+                }
 
                 if (lastShadow >= limitLast) {
-                    throw new IOException("Block overrun while expanding RLE in MTF, "
-                        + lastShadow + " exceeds " + limitLast);
+                    throw new IOException("block overrun");
                 }
             } else {
                 if (++lastShadow >= limitLast) {
-                    throw new IOException("Block overrun in MTF, "
-                        + lastShadow + " exceeds " + limitLast);
+                    throw new IOException("block overrun");
                 }
-                checkBounds(nextSym, 256 + 1, "nextSym");
 
                 final char tmp = yy[nextSym - 1];
-                checkBounds(tmp, 256, "yy");
                 unzftab[seqToUnseq[tmp] & 0xff]++;
                 ll8[lastShadow] = seqToUnseq[tmp];
 
@@ -704,9 +716,7 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
                 if (groupPos == 0) {
                     groupPos = G_SIZE - 1;
-                    checkBounds(++groupNo, MAX_SELECTORS, "groupNo");
-                    zt = selector[groupNo] & 0xff;
-                    checkBounds(zt, N_GROUPS, "zt");
+                    zt = selector[++groupNo] & 0xff;
                     base_zt = base[zt];
                     limit_zt = limit[zt];
                     perm_zt = perm[zt];
@@ -716,47 +726,87 @@ public class BZip2CompressorInputStream extends CompressorInputStream
                 }
 
                 int zn = minLens_zt;
-                checkBounds(zn, MAX_ALPHA_SIZE, "zn");
-                int zvec = bsR(bin, zn);
-                while(zvec > limit_zt[zn]) {
-                    checkBounds(++zn, MAX_ALPHA_SIZE, "zn");
-                    zvec = (zvec << 1) | bsR(bin, 1);
+
+                // Inlined:
+                // int zvec = bsR(zn);
+                while (bsLiveShadow < zn) {
+                    final int thech = inShadow.read();
+                    if (thech >= 0) {
+                        bsBuffShadow = (bsBuffShadow << 8) | thech;
+                        bsLiveShadow += 8;
+                        continue;
+                    } else {
+                        throw new IOException("unexpected end of stream");
+                    }
                 }
-                final int idx = zvec - base_zt[zn];
-                checkBounds(idx, MAX_ALPHA_SIZE, "zvec");
-                nextSym = perm_zt[idx];
+                int zvec = (bsBuffShadow >> (bsLiveShadow - zn))
+                    & ((1 << zn) - 1);
+                bsLiveShadow -= zn;
+
+                while (zvec > limit_zt[zn]) {
+                    zn++;
+                    while (bsLiveShadow < 1) {
+                        final int thech = inShadow.read();
+                        if (thech >= 0) {
+                            bsBuffShadow = (bsBuffShadow << 8) | thech;
+                            bsLiveShadow += 8;
+                            continue;
+                        } else {
+                            throw new IOException("unexpected end of stream");
+                        }
+                    }
+                    bsLiveShadow--;
+                    zvec = (zvec << 1) | ((bsBuffShadow >> bsLiveShadow) & 1);
+                }
+                nextSym = perm_zt[zvec - base_zt[zn]];
             }
         }
 
         this.last = lastShadow;
+        this.bsLive = bsLiveShadow;
+        this.bsBuff = bsBuffShadow;
     }
 
-    private int getAndMoveToFrontDecode0() throws IOException {
+    private int getAndMoveToFrontDecode0(final int groupNo) throws IOException {
+        final InputStream inShadow = this.in;
         final Data dataShadow = this.data;
-        final int zt = dataShadow.selector[0] & 0xff;
-        checkBounds(zt, N_GROUPS, "zt");
+        final int zt = dataShadow.selector[groupNo] & 0xff;
         final int[] limit_zt = dataShadow.limit[zt];
         int zn = dataShadow.minLens[zt];
-        checkBounds(zn, MAX_ALPHA_SIZE, "zn");
-        int zvec = bsR(bin, zn);
-        while (zvec > limit_zt[zn]) {
-            checkBounds(++zn, MAX_ALPHA_SIZE, "zn");
-            zvec = (zvec << 1) | bsR(bin, 1);
-        }
-        final int tmp = zvec - dataShadow.base[zt][zn];
-        checkBounds(tmp, MAX_ALPHA_SIZE, "zvec");
+        int zvec = bsR(zn);
+        int bsLiveShadow = this.bsLive;
+        int bsBuffShadow = this.bsBuff;
 
-        return dataShadow.perm[zt][tmp];
+        while (zvec > limit_zt[zn]) {
+            zn++;
+            while (bsLiveShadow < 1) {
+                final int thech = inShadow.read();
+
+                if (thech >= 0) {
+                    bsBuffShadow = (bsBuffShadow << 8) | thech;
+                    bsLiveShadow += 8;
+                    continue;
+                } else {
+                    throw new IOException("unexpected end of stream");
+                }
+            }
+            bsLiveShadow--;
+            zvec = (zvec << 1) | ((bsBuffShadow >> bsLiveShadow) & 1);
+        }
+
+        this.bsLive = bsLiveShadow;
+        this.bsBuff = bsBuffShadow;
+
+        return dataShadow.perm[zt][zvec - dataShadow.base[zt][zn]];
     }
 
-    private int setupBlock() throws IOException {
-        if (currentState == EOF || this.data == null) {
-            return -1;
+    private void setupBlock() throws IOException {
+        if (this.data == null) {
+            return;
         }
 
         final int[] cftab = this.data.cftab;
-        final int ttLen = this.last + 1;
-        final int[] tt = this.data.initTT(ttLen);
+        final int[] tt = this.data.initTT(this.last + 1);
         final byte[] ll8 = this.data.ll8;
         cftab[0] = 0;
         System.arraycopy(this.data.unzftab, 0, cftab, 1, 256);
@@ -767,13 +817,11 @@ public class BZip2CompressorInputStream extends CompressorInputStream
         }
 
         for (int i = 0, lastShadow = this.last; i <= lastShadow; i++) {
-            final int tmp = cftab[ll8[i] & 0xff]++;
-            checkBounds(tmp, ttLen, "tt index");
-            tt[tmp] = i;
+            tt[cftab[ll8[i] & 0xff]++] = i;
         }
 
         if ((this.origPtr < 0) || (this.origPtr >= tt.length)) {
-            throw new IOException("Stream corrupted");
+            throw new IOException("stream corrupted");
         }
 
         this.su_tPos = tt[this.origPtr];
@@ -784,16 +832,16 @@ public class BZip2CompressorInputStream extends CompressorInputStream
         if (this.blockRandomised) {
             this.su_rNToGo = 0;
             this.su_rTPos = 0;
-            return setupRandPartA();
+            setupRandPartA();
+        } else {
+            setupNoRandPartA();
         }
-        return setupNoRandPartA();
     }
 
-    private int setupRandPartA() throws IOException {
+    private void setupRandPartA() throws IOException {
         if (this.su_i2 <= this.last) {
             this.su_chPrev = this.su_ch2;
             int su_ch2Shadow = this.data.ll8[this.su_tPos] & 0xff;
-            checkBounds(this.su_tPos, this.data.tt.length, "su_tPos");
             this.su_tPos = this.data.tt[this.su_tPos];
             if (this.su_rNToGo == 0) {
                 this.su_rNToGo = Rand.rNums(this.su_rTPos) - 1;
@@ -805,103 +853,104 @@ public class BZip2CompressorInputStream extends CompressorInputStream
             }
             this.su_ch2 = su_ch2Shadow ^= (this.su_rNToGo == 1) ? 1 : 0;
             this.su_i2++;
+            this.currentChar = su_ch2Shadow;
             this.currentState = RAND_PART_B_STATE;
             this.crc.updateCRC(su_ch2Shadow);
-            return su_ch2Shadow;
+        } else {
+            endBlock();
+            initBlock();
+            setupBlock();
         }
-        endBlock();
-        initBlock();
-        return setupBlock();
     }
 
-    private int setupNoRandPartA() throws IOException {
+    private void setupNoRandPartA() throws IOException {
         if (this.su_i2 <= this.last) {
             this.su_chPrev = this.su_ch2;
-            final int su_ch2Shadow = this.data.ll8[this.su_tPos] & 0xff;
+            int su_ch2Shadow = this.data.ll8[this.su_tPos] & 0xff;
             this.su_ch2 = su_ch2Shadow;
-            checkBounds(this.su_tPos, this.data.tt.length, "su_tPos");
             this.su_tPos = this.data.tt[this.su_tPos];
             this.su_i2++;
+            this.currentChar = su_ch2Shadow;
             this.currentState = NO_RAND_PART_B_STATE;
             this.crc.updateCRC(su_ch2Shadow);
-            return su_ch2Shadow;
+        } else {
+            this.currentState = NO_RAND_PART_A_STATE;
+            endBlock();
+            initBlock();
+            setupBlock();
         }
-        this.currentState = NO_RAND_PART_A_STATE;
-        endBlock();
-        initBlock();
-        return setupBlock();
     }
 
-    private int setupRandPartB() throws IOException {
+    private void setupRandPartB() throws IOException {
         if (this.su_ch2 != this.su_chPrev) {
             this.currentState = RAND_PART_A_STATE;
             this.su_count = 1;
-            return setupRandPartA();
-        }
-        if (++this.su_count < 4) {
-            this.currentState = RAND_PART_A_STATE;
-            return setupRandPartA();
-        }
-        this.su_z = (char) (this.data.ll8[this.su_tPos] & 0xff);
-        checkBounds(this.su_tPos, this.data.tt.length, "su_tPos");
-        this.su_tPos = this.data.tt[this.su_tPos];
-        if (this.su_rNToGo == 0) {
-            this.su_rNToGo = Rand.rNums(this.su_rTPos) - 1;
-            if (++this.su_rTPos == 512) {
-                this.su_rTPos = 0;
+            setupRandPartA();
+        } else if (++this.su_count >= 4) {
+            this.su_z = (char) (this.data.ll8[this.su_tPos] & 0xff);
+            this.su_tPos = this.data.tt[this.su_tPos];
+            if (this.su_rNToGo == 0) {
+                this.su_rNToGo = Rand.rNums(this.su_rTPos) - 1;
+                if (++this.su_rTPos == 512) {
+                    this.su_rTPos = 0;
+                }
+            } else {
+                this.su_rNToGo--;
             }
+            this.su_j2 = 0;
+            this.currentState = RAND_PART_C_STATE;
+            if (this.su_rNToGo == 1) {
+                this.su_z ^= 1;
+            }
+            setupRandPartC();
         } else {
-            this.su_rNToGo--;
+            this.currentState = RAND_PART_A_STATE;
+            setupRandPartA();
         }
-        this.su_j2 = 0;
-        this.currentState = RAND_PART_C_STATE;
-        if (this.su_rNToGo == 1) {
-            this.su_z ^= 1;
-        }
-        return setupRandPartC();
     }
 
-    private int setupRandPartC() throws IOException {
+    private void setupRandPartC() throws IOException {
         if (this.su_j2 < this.su_z) {
+            this.currentChar = this.su_ch2;
             this.crc.updateCRC(this.su_ch2);
             this.su_j2++;
-            return this.su_ch2;
+        } else {
+            this.currentState = RAND_PART_A_STATE;
+            this.su_i2++;
+            this.su_count = 0;
+            setupRandPartA();
         }
-        this.currentState = RAND_PART_A_STATE;
-        this.su_i2++;
-        this.su_count = 0;
-        return setupRandPartA();
     }
 
-    private int setupNoRandPartB() throws IOException {
+    private void setupNoRandPartB() throws IOException {
         if (this.su_ch2 != this.su_chPrev) {
             this.su_count = 1;
-            return setupNoRandPartA();
-        }
-        if (++this.su_count >= 4) {
-            checkBounds(this.su_tPos, this.data.ll8.length, "su_tPos");
+            setupNoRandPartA();
+        } else if (++this.su_count >= 4) {
             this.su_z = (char) (this.data.ll8[this.su_tPos] & 0xff);
             this.su_tPos = this.data.tt[this.su_tPos];
             this.su_j2 = 0;
-            return setupNoRandPartC();
+            setupNoRandPartC();
+        } else {
+            setupNoRandPartA();
         }
-        return setupNoRandPartA();
     }
 
-    private int setupNoRandPartC() throws IOException {
+    private void setupNoRandPartC() throws IOException {
         if (this.su_j2 < this.su_z) {
-            final int su_ch2Shadow = this.su_ch2;
+            int su_ch2Shadow = this.su_ch2;
+            this.currentChar = su_ch2Shadow;
             this.crc.updateCRC(su_ch2Shadow);
             this.su_j2++;
             this.currentState = NO_RAND_PART_C_STATE;
-            return su_ch2Shadow;
+        } else {
+            this.su_i2++;
+            this.su_count = 0;
+            setupNoRandPartA();
         }
-        this.su_i2++;
-        this.su_count = 0;
-        return setupNoRandPartA();
     }
 
-    private static final class Data {
+    private static final class Data extends Object {
 
         // (with blockSize 900k)
         final boolean[] inUse = new boolean[256]; // 256 byte
@@ -930,24 +979,24 @@ public class BZip2CompressorInputStream extends CompressorInputStream
         // 60798 byte
 
         int[] tt; // 3600000 byte
-        final byte[] ll8; // 900000 byte
+        byte[] ll8; // 900000 byte
 
         // ---------------
         // 4560782 byte
         // ===============
 
-        Data(final int blockSize100k) {
+        Data(int blockSize100k) {
             this.ll8 = new byte[blockSize100k * BZip2Constants.BASEBLOCKSIZE];
         }
 
         /**
          * Initializes the {@link #tt} array.
-         *
+         * 
          * This method is called when the required length of the array is known.
-         * I don't initialize it at construction time to avoid unnecessary
+         * I don't initialize it at construction time to avoid unneccessary
          * memory allocation when compressing small files.
          */
-        int[] initTT(final int length) {
+        int[] initTT(int length) {
             int[] ttShadow = this.tt;
 
             // tt.length should always be >= length, but theoretically
@@ -965,17 +1014,33 @@ public class BZip2CompressorInputStream extends CompressorInputStream
 
     /**
      * Checks if the signature matches what is expected for a bzip2 file.
-     *
+     * 
      * @param signature
      *            the bytes to check
      * @param length
      *            the number of bytes to check
      * @return true, if this stream is a bzip2 compressed stream, false otherwise
-     *
+     * 
      * @since 1.1
      */
-    public static boolean matches(final byte[] signature, final int length) {
-        return length >= 3 && signature[0] == 'B' &&
-                signature[1] == 'Z' && signature[2] == 'h';
+    public static boolean matches(byte[] signature, int length) {
+
+        if (length < 3) {
+            return false;
+        }
+
+        if (signature[0] != 'B') {
+            return false;
+        }
+
+        if (signature[1] != 'Z') {
+            return false;
+        }
+
+        if (signature[2] != 'h') {
+            return false;
+        }
+
+        return true;
     }
 }
