@@ -17,15 +17,16 @@
 
 package org.apache.commons.compress.utils;
 
+import java.nio.charset.StandardCharsets;
+
 /**
  * Character encoding names required of every implementation of the Java platform.
  *
- * From the Java documentation <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard
- * charsets</a>:
+ * From the Java documentation <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>:
  * <p>
- * <cite>Every implementation of the Java platform is required to support the following character encodings. Consult the
- * release documentation for your implementation to see if any other encodings are supported. Consult the release
- * documentation for your implementation to see if any other encodings are supported. </cite>
+ * <cite>Every implementation of the Java platform is required to support the following character encodings. Consult the release documentation for your
+ * implementation to see if any other encodings are supported. Consult the release documentation for your implementation to see if any other encodings are
+ * supported. </cite>
  * </p>
  *
  * <dl>
@@ -40,16 +41,20 @@ package org.apache.commons.compress.utils;
  * <dt>{@code UTF-16LE}</dt>
  * <dd>Sixteen-bit Unicode Transformation Format, little-endian byte order.</dd>
  * <dt>{@code UTF-16}</dt>
- * <dd>Sixteen-bit Unicode Transformation Format, byte order specified by a mandatory initial byte-order mark (either order
- * accepted on input, big-endian used on output.)</dd>
+ * <dd>Sixteen-bit Unicode Transformation Format, byte order specified by a mandatory initial byte-order mark (either order accepted on input, big-endian used
+ * on output.)</dd>
  * </dl>
  *
- * <p>This perhaps would best belong in the [lang] project. Even if a similar interface is defined in [lang], it is not
- * foreseen that [compress] would be made to depend on [lang].</p>
+ * <p>
+ * This perhaps would best belong in the [lang] project. Even if a similar interface is defined in [lang], it is not foreseen that [compress] would be made to
+ * depend on [lang].
+ * </p>
  *
  * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
  * @since 1.4
+ * @deprecated Use {@link StandardCharsets}.
  */
+@Deprecated
 public class CharsetNames {
     /**
      * CharEncodingISO Latin Alphabet No. 1, a.k.a. ISO-LATIN-1.
@@ -59,7 +64,7 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String ISO_8859_1 = "ISO-8859-1";
+    public static final String ISO_8859_1 = StandardCharsets.ISO_8859_1.name();
 
     /**
      * <p>
@@ -71,12 +76,12 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String US_ASCII = "US-ASCII";
+    public static final String US_ASCII = StandardCharsets.US_ASCII.name();
 
     /**
      * <p>
-     * Sixteen-bit Unicode Transformation Format, The byte order specified by a mandatory initial byte-order mark
-     * (either order accepted on input, big-endian used on output)
+     * Sixteen-bit Unicode Transformation Format, The byte order specified by a mandatory initial byte-order mark (either order accepted on input, big-endian
+     * used on output)
      * </p>
      * <p>
      * Every implementation of the Java platform is required to support this character encoding.
@@ -84,7 +89,7 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String UTF_16 = "UTF-16";
+    public static final String UTF_16 = StandardCharsets.UTF_16.name();
 
     /**
      * <p>
@@ -96,7 +101,7 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String UTF_16BE = "UTF-16BE";
+    public static final String UTF_16BE = StandardCharsets.UTF_16BE.name();
 
     /**
      * <p>
@@ -108,7 +113,7 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String UTF_16LE = "UTF-16LE";
+    public static final String UTF_16LE = StandardCharsets.UTF_16LE.name();
 
     /**
      * <p>
@@ -120,5 +125,5 @@ public class CharsetNames {
      *
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
      */
-    public static final String UTF_8 = "UTF-8";
+    public static final String UTF_8 = StandardCharsets.UTF_8.name();
 }
