@@ -13,17 +13,17 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
  */
 
 package org.apache.commons.compress.utils;
 
 import java.nio.charset.Charset;
-import java.nio.charset.StandardCharsets;
 
 /**
  * Charsets required of every implementation of the Java platform.
  *
- * From the Java documentation <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard
+ * From the Java documentation <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard
  * charsets</a>:
  * <p>
  * <cite>Every implementation of the Java platform is required to support the following character encodings. Consult the
@@ -32,17 +32,17 @@ import java.nio.charset.StandardCharsets;
  * </p>
  *
  * <dl>
- * <dt>{@code US-ASCII}</dt>
+ * <dt><code>US-ASCII</code></dt>
  * <dd>Seven-bit ASCII, a.k.a. ISO646-US, a.k.a. the Basic Latin block of the Unicode character set.</dd>
- * <dt>{@code ISO-8859-1}</dt>
+ * <dt><code>ISO-8859-1</code></dt>
  * <dd>ISO Latin Alphabet No. 1, a.k.a. ISO-LATIN-1.</dd>
- * <dt>{@code UTF-8}</dt>
+ * <dt><code>UTF-8</code></dt>
  * <dd>Eight-bit Unicode Transformation Format.</dd>
- * <dt>{@code UTF-16BE}</dt>
+ * <dt><code>UTF-16BE</code></dt>
  * <dd>Sixteen-bit Unicode Transformation Format, big-endian byte order.</dd>
- * <dt>{@code UTF-16LE}</dt>
+ * <dt><code>UTF-16LE</code></dt>
  * <dd>Sixteen-bit Unicode Transformation Format, little-endian byte order.</dd>
- * <dt>{@code UTF-16}</dt>
+ * <dt><code>UTF-16</code></dt>
  * <dd>Sixteen-bit Unicode Transformation Format, byte order specified by a mandatory initial byte-order mark (either order
  * accepted on input, big-endian used on output.)</dd>
  * </dl>
@@ -50,9 +50,9 @@ import java.nio.charset.StandardCharsets;
  * <p>This class best belongs in the Commons Lang or IO project. Even if a similar class is defined in another Commons
  * component, it is not foreseen that Commons Compress would be made to depend on another Commons component.</p>
  *
- * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
- * @see StandardCharsets
+ * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
  * @since 1.4
+ * @version $Id: Charsets.java 1552970 2013-12-22 07:03:43Z bodewig $
  */
 public class Charsets {
 
@@ -61,89 +61,6 @@ public class Charsets {
     // without delay on all Java platforms.
     //
 
-    /**
-     * CharsetNamesISO Latin Alphabet No. 1, a.k.a. ISO-LATIN-1.
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset ISO_8859_1 = StandardCharsets.ISO_8859_1;
-
-    /**
-     * <p>
-     * Seven-bit ASCII, also known as ISO646-US, also known as the Basic Latin block of the Unicode character set.
-     * </p>
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset US_ASCII = StandardCharsets.US_ASCII;
-
-    /**
-     * <p>
-     * Sixteen-bit Unicode Transformation Format, The byte order specified by a mandatory initial byte-order mark
-     * (either order accepted on input, big-endian used on output)
-     * </p>
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset UTF_16 = StandardCharsets.UTF_16;
-
-    /**
-     * <p>
-     * Sixteen-bit Unicode Transformation Format, big-endian byte order.
-     * </p>
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset UTF_16BE = StandardCharsets.UTF_16BE;
-
-    /**
-     * <p>
-     * Sixteen-bit Unicode Transformation Format, little-endian byte order.
-     * </p>
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset UTF_16LE = StandardCharsets.UTF_16LE;
-
-    /**
-     * <p>
-     * Eight-bit Unicode Transformation Format.
-     * </p>
-     * <p>
-     * Every implementation of the Java platform is required to support this character encoding.
-     * </p>
-     *
-     * @see <a href="https://docs.oracle.com/javase/8/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
-     * @deprecated replaced by {@link StandardCharsets} in Java 7
-     */
-    @Deprecated
-    public static final Charset UTF_8 = StandardCharsets.UTF_8;
-
     /**
      * Returns the given Charset or the default Charset if the given Charset is null.
      *
@@ -151,7 +68,7 @@ public class Charsets {
      *            A charset or null.
      * @return the given Charset or the default Charset if the given Charset is null
      */
-    public static Charset toCharset(final Charset charset) {
+    public static Charset toCharset(Charset charset) {
         return charset == null ? Charset.defaultCharset() : charset;
     }
 
@@ -166,7 +83,78 @@ public class Charsets {
      * @throws java.nio.charset.IllegalCharsetNameException
      *             If the given charset name is illegal
      */
-    public static Charset toCharset(final String charset) {
+    public static Charset toCharset(String charset) {
         return charset == null ? Charset.defaultCharset() : Charset.forName(charset);
     }
+
+    /**
+     * CharsetNamesISO Latin Alphabet No. 1, a.k.a. ISO-LATIN-1.
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset ISO_8859_1 = Charset.forName(CharsetNames.ISO_8859_1);
+
+    /**
+     * <p>
+     * Seven-bit ASCII, also known as ISO646-US, also known as the Basic Latin block of the Unicode character set.
+     * </p>
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset US_ASCII = Charset.forName(CharsetNames.US_ASCII);
+
+    /**
+     * <p>
+     * Sixteen-bit Unicode Transformation Format, The byte order specified by a mandatory initial byte-order mark
+     * (either order accepted on input, big-endian used on output)
+     * </p>
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset UTF_16 = Charset.forName(CharsetNames.UTF_16);
+
+    /**
+     * <p>
+     * Sixteen-bit Unicode Transformation Format, big-endian byte order.
+     * </p>
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset UTF_16BE = Charset.forName(CharsetNames.UTF_16BE);
+
+    /**
+     * <p>
+     * Sixteen-bit Unicode Transformation Format, little-endian byte order.
+     * </p>
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset UTF_16LE = Charset.forName(CharsetNames.UTF_16LE);
+
+    /**
+     * <p>
+     * Eight-bit Unicode Transformation Format.
+     * </p>
+     * <p>
+     * Every implementation of the Java platform is required to support this character encoding.
+     * </p>
+     *
+     * @see <a href="http://docs.oracle.com/javase/6/docs/api/java/nio/charset/Charset.html">Standard charsets</a>
+     */
+    public static final Charset UTF_8 = Charset.forName(CharsetNames.UTF_8);
 }
