@@ -24,9 +24,12 @@ import java.io.InputStream;
 
 /**
  * Input stream that tracks the number of bytes read.
+ *
  * @since 1.3
  * @NotThreadSafe
+ * @deprecated Use {@link org.apache.commons.io.input.CountingInputStream}.
  */
+@Deprecated
 public class CountingInputStream extends FilterInputStream {
     private long bytesRead;
 
@@ -35,8 +38,7 @@ public class CountingInputStream extends FilterInputStream {
     }
 
     /**
-     * Increments the counter of already read bytes.
-     * Doesn't increment if the EOF has been hit (read == -1)
+     * Increments the counter of already read bytes. Doesn't increment if the EOF has been hit (read == -1)
      *
      * @param read the number of bytes read
      */
@@ -48,6 +50,7 @@ public class CountingInputStream extends FilterInputStream {
 
     /**
      * Returns the current number of bytes read from this stream.
+     *
      * @return the number of read bytes
      */
     public long getBytesRead() {
