@@ -18,15 +18,11 @@
  */
 package org.apache.commons.compress.archivers;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.nio.file.Files;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -35,32 +31,30 @@ import org.apache.commons.compress.archivers.cpio.CpioArchiveEntry;
 import org.apache.commons.compress.archivers.cpio.CpioArchiveInputStream;
 import org.apache.commons.compress.archivers.cpio.CpioArchiveOutputStream;
 import org.apache.commons.compress.archivers.cpio.CpioConstants;
-import org.junit.jupiter.api.Test;
+import org.apache.commons.compress.utils.IOUtils;
 
 public final class CpioTestCase extends AbstractTestCase {
 
-    @Test
     public void testCpioArchiveCreation() throws Exception {
         final File output = new File(dir, "bla.cpio");
 
         final File file1 = getFile("test1.xml");
         final File file2 = getFile("test2.xml");
 
-        final OutputStream out = Files.newOutputStream(output.toPath());
-        final ArchiveOutputStream os = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("cpio", out);
+        final OutputStream out = new FileOutputStream(output);
+        final ArchiveOutputStream os = new ArchiveStreamFactory().createArchiveOutputStream("cpio", out);
         os.putArchiveEntry(new CpioArchiveEntry("test1.xml", file1.length()));
-        Files.copy(file1.toPath(), os);
+        IOUtils.copy(new FileInputStream(file1), os);
         os.closeArchiveEntry();
 
         os.putArchiveEntry(new CpioArchiveEntry("test2.xml", file2.length()));
-        Files.copy(file2.toPath(), os);
+        IOUtils.copy(new FileInputStream(file2), os);
         os.closeArchiveEntry();
 
         os.close();
         out.close();
     }
 
-    @Test
     public void testCpioUnarchive() throws Exception {
         final File output = new File(dir, "bla.cpio");
         final File file1 = getFile("test1.xml");
@@ -69,18 +63,18 @@ public final class CpioTestCase extends AbstractTestCase {
         final long file2Length = file2.length();
 
         {
-            final OutputStream out = Files.newOutputStream(output.toPath());
-            final ArchiveOutputStream os = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("cpio", out);
+            final OutputStream out = new FileOutputStream(output);
+            final ArchiveOutputStream os = new ArchiveStreamFactory().createArchiveOutputStream("cpio", out);
             CpioArchiveEntry entry = new CpioArchiveEntry("test1.xml", file1Length);
             entry.setMode(CpioConstants.C_ISREG);
             os.putArchiveEntry(entry);
-            Files.copy(file1.toPath(), os);
+            IOUtils.copy(new FileInputStream(file1), os);
             os.closeArchiveEntry();
 
             entry = new CpioArchiveEntry("test2.xml", file2Length);
             entry.setMode(CpioConstants.C_ISREG);
             os.putArchiveEntry(entry);
-            Files.copy(file2.toPath(), os);
+            IOUtils.copy(new FileInputStream(file2), os);
             os.closeArchiveEntry();
             os.finish();
             os.close();
@@ -88,47 +82,49 @@ public final class CpioTestCase extends AbstractTestCase {
         }
 
         // Unarchive Operation
-        final InputStream is = Files.newInputStream(output.toPath());
-        final ArchiveInputStream in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("cpio", is);
+        final File input = output;
+        final InputStream is = new FileInputStream(input);
+        final ArchiveInputStream in = new ArchiveStreamFactory().createArchiveInputStream("cpio", is);
 
 
-        final Map<String, File> result = new HashMap<>();
+        Map<String, File> result = new HashMap<String, File>();
         ArchiveEntry entry = null;
         while ((entry = in.getNextEntry()) != null) {
-            final File cpioget = new File(dir, entry.getName());
-            Files.copy(in, cpioget.toPath());
+            File cpioget = new File(dir, entry.getName());
+            final OutputStream out = new FileOutputStream(cpioget);
+            IOUtils.copy(in, out);
+            out.close();
             result.put(entry.getName(), cpioget);
         }
         in.close();
         is.close();
 
         File t = result.get("test1.xml");
-        assertTrue(t.exists(), "Expected " + t.getAbsolutePath() + " to exist");
-        assertEquals(file1Length, t.length(), "length of " + t.getAbsolutePath());
+        assertTrue("Expected " + t.getAbsolutePath() + " to exist", t.exists());
+        assertEquals("length of " + t.getAbsolutePath(), file1Length, t.length());
 
         t = result.get("test2.xml");
-        assertTrue(t.exists(), "Expected " + t.getAbsolutePath() + " to exist");
-        assertEquals(file2Length, t.length(), "length of " + t.getAbsolutePath());
+        assertTrue("Expected " + t.getAbsolutePath() + " to exist", t.exists());
+        assertEquals("length of " + t.getAbsolutePath(), file2Length, t.length());
     }
 
-    @Test
     public void testDirectoryEntryFromFile() throws Exception {
-        final File[] tmp = createTempDirAndFile();
+        File[] tmp = createTempDirAndFile();
         File archive = null;
         CpioArchiveOutputStream tos = null;
         CpioArchiveInputStream tis = null;
         try {
             archive = File.createTempFile("test.", ".cpio", tmp[0]);
             archive.deleteOnExit();
-            tos = new CpioArchiveOutputStream(Files.newOutputStream(archive.toPath()));
-            final long beforeArchiveWrite = tmp[0].lastModified();
-            final CpioArchiveEntry in = new CpioArchiveEntry(tmp[0], "foo");
+            tos = new CpioArchiveOutputStream(new FileOutputStream(archive));
+            long beforeArchiveWrite = tmp[0].lastModified();
+            CpioArchiveEntry in = new CpioArchiveEntry(tmp[0], "foo");
             tos.putArchiveEntry(in);
             tos.closeArchiveEntry();
             tos.close();
             tos = null;
-            tis = new CpioArchiveInputStream(Files.newInputStream(archive.toPath()));
-            final CpioArchiveEntry out = tis.getNextCPIOEntry();
+            tis = new CpioArchiveInputStream(new FileInputStream(archive));
+            CpioArchiveEntry out = tis.getNextCPIOEntry();
             tis.close();
             tis = null;
             assertNotNull(out);
@@ -151,26 +147,25 @@ public final class CpioTestCase extends AbstractTestCase {
         }
     }
 
-    @Test
     public void testExplicitDirectoryEntry() throws Exception {
-        final File[] tmp = createTempDirAndFile();
+        File[] tmp = createTempDirAndFile();
         File archive = null;
         CpioArchiveOutputStream tos = null;
         CpioArchiveInputStream tis = null;
         try {
             archive = File.createTempFile("test.", ".cpio", tmp[0]);
             archive.deleteOnExit();
-            tos = new CpioArchiveOutputStream(Files.newOutputStream(archive.toPath()));
-            final long beforeArchiveWrite = tmp[0].lastModified();
-            final CpioArchiveEntry in = new CpioArchiveEntry("foo/");
+            tos = new CpioArchiveOutputStream(new FileOutputStream(archive));
+            long beforeArchiveWrite = tmp[0].lastModified();
+            CpioArchiveEntry in = new CpioArchiveEntry("foo/");
             in.setTime(beforeArchiveWrite / 1000);
             in.setMode(CpioConstants.C_ISDIR);
             tos.putArchiveEntry(in);
             tos.closeArchiveEntry();
             tos.close();
             tos = null;
-            tis = new CpioArchiveInputStream(Files.newInputStream(archive.toPath()));
-            final CpioArchiveEntry out = tis.getNextCPIOEntry();
+            tis = new CpioArchiveInputStream(new FileInputStream(archive));
+            CpioArchiveEntry out = tis.getNextCPIOEntry();
             tis.close();
             tis = null;
             assertNotNull(out);
@@ -192,24 +187,20 @@ public final class CpioTestCase extends AbstractTestCase {
         }
     }
 
-    @Test
-    public void testExplicitFileEntry() throws Exception {
-        final File[] tmp = createTempDirAndFile();
+    public void testFileEntryFromFile() throws Exception {
+        File[] tmp = createTempDirAndFile();
         File archive = null;
         CpioArchiveOutputStream tos = null;
         CpioArchiveInputStream tis = null;
-        InputStream fis = null;
+        FileInputStream fis = null;
         try {
             archive = File.createTempFile("test.", ".cpio", tmp[0]);
             archive.deleteOnExit();
-            tos = new CpioArchiveOutputStream(Files.newOutputStream(archive.toPath()));
-            final CpioArchiveEntry in = new CpioArchiveEntry("foo");
-            in.setTime(tmp[1].lastModified() / 1000);
-            in.setSize(tmp[1].length());
-            in.setMode(CpioConstants.C_ISREG);
+            tos = new CpioArchiveOutputStream(new FileOutputStream(archive));
+            CpioArchiveEntry in = new CpioArchiveEntry(tmp[1], "foo");
             tos.putArchiveEntry(in);
-            final byte[] b = new byte[(int) tmp[1].length()];
-            fis = Files.newInputStream(tmp[1].toPath());
+            byte[] b = new byte[(int) tmp[1].length()];
+            fis = new FileInputStream(tmp[1]);
             while (fis.read(b) > 0) {
                 tos.write(b);
             }
@@ -218,8 +209,8 @@ public final class CpioTestCase extends AbstractTestCase {
             tos.closeArchiveEntry();
             tos.close();
             tos = null;
-            tis = new CpioArchiveInputStream(Files.newInputStream(archive.toPath()));
-            final CpioArchiveEntry out = tis.getNextCPIOEntry();
+            tis = new CpioArchiveInputStream(new FileInputStream(archive));
+            CpioArchiveEntry out = tis.getNextCPIOEntry();
             tis.close();
             tis = null;
             assertNotNull(out);
@@ -244,21 +235,23 @@ public final class CpioTestCase extends AbstractTestCase {
         }
     }
 
-    @Test
-    public void testFileEntryFromFile() throws Exception {
-        final File[] tmp = createTempDirAndFile();
+    public void testExplicitFileEntry() throws Exception {
+        File[] tmp = createTempDirAndFile();
         File archive = null;
         CpioArchiveOutputStream tos = null;
         CpioArchiveInputStream tis = null;
-        InputStream fis = null;
+        FileInputStream fis = null;
         try {
             archive = File.createTempFile("test.", ".cpio", tmp[0]);
             archive.deleteOnExit();
-            tos = new CpioArchiveOutputStream(Files.newOutputStream(archive.toPath()));
-            final CpioArchiveEntry in = new CpioArchiveEntry(tmp[1], "foo");
+            tos = new CpioArchiveOutputStream(new FileOutputStream(archive));
+            CpioArchiveEntry in = new CpioArchiveEntry("foo");
+            in.setTime(tmp[1].lastModified() / 1000);
+            in.setSize(tmp[1].length());
+            in.setMode(CpioConstants.C_ISREG);
             tos.putArchiveEntry(in);
-            final byte[] b = new byte[(int) tmp[1].length()];
-            fis = Files.newInputStream(tmp[1].toPath());
+            byte[] b = new byte[(int) tmp[1].length()];
+            fis = new FileInputStream(tmp[1]);
             while (fis.read(b) > 0) {
                 tos.write(b);
             }
@@ -267,8 +260,8 @@ public final class CpioTestCase extends AbstractTestCase {
             tos.closeArchiveEntry();
             tos.close();
             tos = null;
-            tis = new CpioArchiveInputStream(Files.newInputStream(archive.toPath()));
-            final CpioArchiveEntry out = tis.getNextCPIOEntry();
+            tis = new CpioArchiveInputStream(new FileInputStream(archive));
+            CpioArchiveEntry out = tis.getNextCPIOEntry();
             tis.close();
             tis = null;
             assertNotNull(out);
