@@ -29,6 +29,7 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -37,6 +38,7 @@ import java.nio.channels.Channels;
 import java.nio.channels.SeekableByteChannel;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Enumeration;
@@ -55,9 +57,9 @@ import org.apache.commons.compress.archivers.zip.ZipArchiveOutputStream;
 import org.apache.commons.compress.archivers.zip.ZipFile;
 import org.apache.commons.compress.archivers.zip.ZipMethod;
 import org.apache.commons.compress.archivers.zip.ZipSplitReadOnlySeekableByteChannel;
-import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.InputStreamStatistics;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
 
 public final class ZipTest extends AbstractTest {
@@ -88,8 +90,8 @@ public final class ZipTest extends AbstractTest {
 
     private void assertSameFileContents(final File expectedFile, final File actualFile) throws IOException {
         final int size = (int) Math.max(expectedFile.length(), actualFile.length());
-        try (final ZipFile expected = new ZipFile(expectedFile);
-                final ZipFile actual = new ZipFile(actualFile)) {
+        try (ZipFile expected = newZipFile(expectedFile);
+                ZipFile actual = newZipFile(actualFile)) {
             final byte[] expectedBuf = new byte[size];
             final byte[] actualBuf = new byte[size];
 
@@ -110,10 +112,10 @@ public final class ZipTest extends AbstractTest {
                 assertEquals(expectedElement.getExternalAttributes(), actualElement.getExternalAttributes());
                 assertEquals(expectedElement.getInternalAttributes(), actualElement.getInternalAttributes());
 
-                try (final InputStream actualIs = actual.getInputStream(actualElement);
-                        final InputStream expectedIs = expected.getInputStream(expectedElement)) {
-                    IOUtils.readFully(expectedIs, expectedBuf);
-                    IOUtils.readFully(actualIs, actualBuf);
+                try (InputStream actualIs = actual.getInputStream(actualElement);
+                        InputStream expectedIs = expected.getInputStream(expectedElement)) {
+                    org.apache.commons.compress.utils.IOUtils.readFully(expectedIs, expectedBuf);
+                    org.apache.commons.compress.utils.IOUtils.readFully(actualIs, actualBuf);
                 }
                 assertArrayEquals(expectedBuf, actualBuf); // Buffers are larger than payload. don't care
             }
@@ -142,6 +144,14 @@ public final class ZipTest extends AbstractTest {
         zos.closeArchiveEntry();
     }
 
+    private byte[] createArtificialData(final int size) {
+        final ByteArrayOutputStream output = new ByteArrayOutputStream();
+        for (int i = 0; i < size; i += 1) {
+            output.write((byte) ((i & 1) == 0 ? i / 2 % 256 : i / 2 / 256));
+        }
+        return output.toByteArray();
+    }
+
     private ZipArchiveOutputStream createFirstEntry(final ZipArchiveOutputStream zos) throws IOException {
         createArchiveEntry(first_payload, zos, "file1.txt");
         return zos;
@@ -149,7 +159,7 @@ public final class ZipTest extends AbstractTest {
 
     private File createReferenceFile(final Zip64Mode zipMode, final String prefix) throws IOException {
         final File reference = createTempFile(prefix, ".zip");
-        try (final ZipArchiveOutputStream zos = new ZipArchiveOutputStream(reference)) {
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(reference)) {
             zos.setUseZip64(zipMode);
             createFirstEntry(zos);
             createSecondEntry(zos);
@@ -166,14 +176,14 @@ public final class ZipTest extends AbstractTest {
         final File directoryToZip = getFilesToZip();
         final File outputZipFile = newTempFile("splitZip.zip");
         final long splitSize = 100 * 1024L; /* 100 KB */
-        try (final ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
             addFilesToZip(zipArchiveOutputStream, directoryToZip);
         }
     }
 
     private File getFilesToZip() throws IOException {
         final File originalZipFile = getFile("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip.zip");
-        try (ZipFile zipFile = new ZipFile(originalZipFile)) {
+        try (ZipFile zipFile = newZipFile(originalZipFile)) {
             final Enumeration<ZipArchiveEntry> zipEntries = zipFile.getEntries();
             ZipArchiveEntry zipEntry;
             File outputFile;
@@ -204,6 +214,10 @@ public final class ZipTest extends AbstractTest {
         return getTempDirFile().listFiles()[0];
     }
 
+    private ZipFile newZipFile(final File file) throws IOException {
+        return ZipFile.builder().setFile(file).get();
+    }
+
     private void readStream(final InputStream in, final ArchiveEntry entry, final Map<String, List<List<Long>>> map) throws IOException {
         final byte[] buf = new byte[4096];
         final InputStreamStatistics stats = (InputStreamStatistics) in;
@@ -219,11 +233,143 @@ public final class ZipTest extends AbstractTest {
         list.add(Arrays.asList(t, b));
     }
 
+    /**
+     * Tests split archive with 32-bit limit, both STORED and DEFLATED.
+     */
+    @Test
+    public void testBuildArtificialSplitZip32Test() throws IOException {
+        final File outputZipFile = newTempFile("artificialSplitZip.zip");
+        final long splitSize = 64 * 1024L; /* 64 KB */
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+            final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
+            ze1.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze1);
+            zipArchiveOutputStream.write(createArtificialData(65536));
+            zipArchiveOutputStream.closeArchiveEntry();
+            final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
+            ze2.setMethod(ZipEntry.DEFLATED);
+            zipArchiveOutputStream.putArchiveEntry(ze2);
+            zipArchiveOutputStream.write(createArtificialData(65536));
+            zipArchiveOutputStream.closeArchiveEntry();
+        }
+
+        try (ZipFile zipFile = ZipFile.builder()
+                .setPath(outputZipFile.toPath())
+                .setMaxNumberOfDisks(Integer.MAX_VALUE)
+                .get()
+        ) {
+            assertArrayEquals(createArtificialData(65536), IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
+            assertArrayEquals(createArtificialData(65536), IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file02"))));
+        }
+    }
+
+    /**
+     * Tests split archive with 64-bit limit, both STORED and DEFLATED.
+     */
+    @Test
+    public void testBuildArtificialSplitZip64Test() throws IOException {
+        final File outputZipFile = newTempFile("artificialSplitZip.zip");
+        final long splitSize = 64 * 1024L; /* 64 KB */
+        final byte[] data = createArtificialData(128 * 1024);
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            zipArchiveOutputStream.setUseZip64(Zip64Mode.Always);
+            final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
+            ze1.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze1);
+            zipArchiveOutputStream.write(data);
+            zipArchiveOutputStream.closeArchiveEntry();
+            final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
+            ze2.setMethod(ZipEntry.DEFLATED);
+            zipArchiveOutputStream.putArchiveEntry(ze2);
+            zipArchiveOutputStream.write(data);
+            zipArchiveOutputStream.closeArchiveEntry();
+        }
+        try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
+            assertArrayEquals(data, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
+            assertArrayEquals(data, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file02"))));
+        }
+    }
+
+    /**
+     * Tests split archive with 32-bit limit, with end of central directory skipping lack of space in segment.
+     */
+    @Test
+    public void testBuildSplitZip32_endOfCentralDirectorySkipBoundary() throws IOException {
+        final File outputZipFile = newTempFile("artificialSplitZip.zip");
+        final long splitSize = 64 * 1024L; /* 64 KB */
+        // 4 is PK signature, 36 is size of header + local file header,
+        // 36 is length of central directory entry
+        // 1 is remaining byte in first archive, this should be skipped
+        final byte[] data1 = createArtificialData(64 * 1024 - 4 - 36 - 52 - 1);
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+            final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
+            ze1.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze1);
+            zipArchiveOutputStream.write(data1);
+            zipArchiveOutputStream.closeArchiveEntry();
+        }
+        assertEquals(64 * 1024L - 1, Files.size(outputZipFile.toPath().getParent().resolve("artificialSplitZip.z01")));
+        try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
+            assertArrayEquals(data1, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
+        }
+    }
+
+    /**
+     * Tests split archive with 32-bit limit, with file local headers crossing segment boundaries.
+     */
+    @Test
+    public void testBuildSplitZip32_metaCrossBoundary() throws IOException {
+        final File outputZipFile = newTempFile("artificialSplitZip.zip");
+        final long splitSize = 64 * 1024L; /* 64 KB */
+        // 4 is PK signature, 36 is size of header + local file header,
+        // 15 is next local file header up to second byte of CRC
+        final byte[] data1 = createArtificialData(64 * 1024 - 4 - 36 - 15);
+        // 21 is remaining size of second local file header
+        // 19 is next local file header up to second byte of compressed size
+        final byte[] data2 = createArtificialData(64 * 1024 - 21 - 19);
+        // 17 is remaining size of third local file header
+        // 23 is next local file header up to second byte of uncompressed size
+        final byte[] data3 = createArtificialData(64 * 1024 - 17 - 23);
+        // 13 is remaining size of third local file header
+        // 1 is to wrap to next part
+        final byte[] data4 = createArtificialData(64 * 1024 - 13 + 1);
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+            final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
+            ze1.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze1);
+            zipArchiveOutputStream.write(data1);
+            zipArchiveOutputStream.closeArchiveEntry();
+            final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
+            ze2.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze2);
+            zipArchiveOutputStream.write(data2);
+            zipArchiveOutputStream.closeArchiveEntry();
+            final ZipArchiveEntry ze3 = new ZipArchiveEntry("file03");
+            ze3.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze3);
+            zipArchiveOutputStream.write(data3);
+            zipArchiveOutputStream.closeArchiveEntry();
+            final ZipArchiveEntry ze4 = new ZipArchiveEntry("file04");
+            ze4.setMethod(ZipEntry.STORED);
+            zipArchiveOutputStream.putArchiveEntry(ze4);
+            zipArchiveOutputStream.write(data4);
+            zipArchiveOutputStream.closeArchiveEntry();
+        }
+        try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
+            assertArrayEquals(data1, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
+            assertArrayEquals(data2, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file02"))));
+            assertArrayEquals(data3, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file03"))));
+            assertArrayEquals(data4, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file04"))));
+        }
+    }
+
     @Test
     public void testBuildSplitZipTest() throws IOException {
         final File directoryToZip = getFilesToZip();
         createTestSplitZipSegments();
-
         final File lastFile = newTempFile("splitZip.zip");
         try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
                 InputStream inputStream = Channels.newInputStream(channel);
@@ -237,10 +383,7 @@ public final class ZipTest extends AbstractTest {
                     continue;
                 }
                 // compare all files one by one
-                final File fileToCompare = new File(entry.getName());
-                try (InputStream inputStreamToCompare = Files.newInputStream(fileToCompare.toPath())) {
-                    assertArrayEquals(IOUtils.toByteArray(splitInputStream), IOUtils.toByteArray(inputStreamToCompare));
-                }
+                assertArrayEquals(IOUtils.toByteArray(splitInputStream), Files.readAllBytes(Paths.get(entry.getName())));
                 filesCount++;
             }
             // and the number of files should equal
@@ -253,12 +396,10 @@ public final class ZipTest extends AbstractTest {
         final File directoryToZip = getFilesToZip();
         final File outputZipFile = newTempFile("splitZip.zip");
         final long splitSize = 100 * 1024L; /* 100 KB */
-        try (final ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
-
+        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
             // create a file that has the same name of one of the created split segments
             final File sameNameFile = newTempFile("splitZip.z01");
             sameNameFile.createNewFile();
-
             assertThrows(IOException.class, () -> addFilesToZip(zipArchiveOutputStream, directoryToZip));
         } catch (final Exception e) {
             // Ignore:
@@ -287,25 +428,21 @@ public final class ZipTest extends AbstractTest {
 
     @Test
     public void testCopyRawEntriesFromFile() throws IOException {
-
         final File reference = createReferenceFile(Zip64Mode.Never, "expected.");
-
         final File file1 = createTempFile("src1.", ".zip");
-        try (final ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
             zos.setUseZip64(Zip64Mode.Never);
             createFirstEntry(zos).close();
         }
-
         final File file2 = createTempFile("src2.", ".zip");
-        try (final ZipArchiveOutputStream zos1 = new ZipArchiveOutputStream(file2)) {
+        try (ZipArchiveOutputStream zos1 = new ZipArchiveOutputStream(file2)) {
             zos1.setUseZip64(Zip64Mode.Never);
             createSecondEntry(zos1).close();
         }
-
-        try (final ZipFile zipFile1 = new ZipFile(file1);
-                final ZipFile zipFile2 = new ZipFile(file2)) {
+        try (ZipFile zipFile1 = newZipFile(file1);
+                ZipFile zipFile2 = newZipFile(file2)) {
             final File fileResult = createTempFile("file-actual.", ".zip");
-            try (final ZipArchiveOutputStream zos2 = new ZipArchiveOutputStream(fileResult)) {
+            try (ZipArchiveOutputStream zos2 = new ZipArchiveOutputStream(fileResult)) {
                 zipFile1.copyRawEntries(zos2, allFilesPredicate);
                 zipFile2.copyRawEntries(zos2, allFilesPredicate);
             }
@@ -318,22 +455,19 @@ public final class ZipTest extends AbstractTest {
 
     @Test
     public void testCopyRawZip64EntryFromFile() throws IOException {
-
         final File reference = createTempFile("z64reference.", ".zip");
-        try (final ZipArchiveOutputStream zos1 = new ZipArchiveOutputStream(reference)) {
+        try (ZipArchiveOutputStream zos1 = new ZipArchiveOutputStream(reference)) {
             zos1.setUseZip64(Zip64Mode.Always);
             createFirstEntry(zos1);
         }
-
         final File file1 = createTempFile("zip64src.", ".zip");
-        try (final ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
             zos.setUseZip64(Zip64Mode.Always);
             createFirstEntry(zos).close();
         }
-
         final File fileResult = createTempFile("file-actual.", ".zip");
-        try (final ZipFile zipFile1 = new ZipFile(file1)) {
-            try (final ZipArchiveOutputStream zos2 = new ZipArchiveOutputStream(fileResult)) {
+        try (ZipFile zipFile1 = newZipFile(file1)) {
+            try (ZipArchiveOutputStream zos2 = new ZipArchiveOutputStream(fileResult)) {
                 zos2.setUseZip64(Zip64Mode.Always);
                 zipFile1.copyRawEntries(zos2, allFilesPredicate);
             }
@@ -352,7 +486,7 @@ public final class ZipTest extends AbstractTest {
             zos.putArchiveEntry(in);
             zos.closeArchiveEntry();
         }
-        try (ZipFile zf = new ZipFile(archive)) {
+        try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo/");
             assertNotNull(out);
             assertEquals("foo/", out.getName());
@@ -374,7 +508,7 @@ public final class ZipTest extends AbstractTest {
             zos.putArchiveEntry(in);
             zos.closeArchiveEntry();
         }
-        try (ZipFile zf = new ZipFile(archive)) {
+        try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo/");
             assertNotNull(out);
             assertEquals("foo/", out.getName());
@@ -401,7 +535,7 @@ public final class ZipTest extends AbstractTest {
             }
             zos.closeArchiveEntry();
         }
-        try (ZipFile zf = new ZipFile(archive)) {
+        try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
             assertNotNull(out);
             assertEquals("foo", out.getName());
@@ -426,7 +560,7 @@ public final class ZipTest extends AbstractTest {
             }
             zos.closeArchiveEntry();
         }
-        try (ZipFile zf = new ZipFile(archive)) {
+        try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
             assertNotNull(out);
             assertEquals("foo", out.getName());
@@ -438,19 +572,14 @@ public final class ZipTest extends AbstractTest {
 
     private void testInputStreamStatistics(final String fileName, final Map<String, List<Long>> expectedStatistics) throws IOException, ArchiveException {
         final File input = getFile(fileName);
-
         final Map<String, List<List<Long>>> actualStatistics = new HashMap<>();
-
         // stream access
-        try (final InputStream fis = Files.newInputStream(input.toPath());
-                final ArchiveInputStream<?> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fis)) {
-            for (ArchiveEntry entry; (entry = in.getNextEntry()) != null;) {
-                readStream(in, entry, actualStatistics);
-            }
+        try (InputStream fis = Files.newInputStream(input.toPath());
+                ArchiveInputStream<?> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fis)) {
+            in.forEach(entry -> readStream(in, entry, actualStatistics));
         }
-
         // file access
-        try (final ZipFile zf = new ZipFile(input)) {
+        try (ZipFile zf = newZipFile(input)) {
             final Enumeration<ZipArchiveEntry> entries = zf.getEntries();
             while (entries.hasMoreElements()) {
                 final ZipArchiveEntry zae = entries.nextElement();
@@ -459,12 +588,10 @@ public final class ZipTest extends AbstractTest {
                 }
             }
         }
-
         // compare statistics of stream / file access
         for (final Map.Entry<String, List<List<Long>>> me : actualStatistics.entrySet()) {
             assertEquals(me.getValue().get(0), me.getValue().get(1), "Mismatch of stats for: " + me.getKey());
         }
-
         for (final Map.Entry<String, List<Long>> me : expectedStatistics.entrySet()) {
             assertEquals(me.getValue(), actualStatistics.get(me.getKey()).get(0), "Mismatch of stats with expected value for: " + me.getKey());
         }
@@ -524,17 +651,13 @@ public final class ZipTest extends AbstractTest {
     @Test
     public void testListAllFilesWithNestedArchive() throws Exception {
         final File input = getFile("OSX_ArchiveWithNestedArchive.zip");
-
         final List<String> results = new ArrayList<>();
         final List<ZipException> expectedExceptions = new ArrayList<>();
-
-        try (final InputStream fis = Files.newInputStream(input.toPath());
+        try (InputStream fis = Files.newInputStream(input.toPath());
                 ZipArchiveInputStream in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fis)) {
-
             ZipArchiveEntry entry;
             while ((entry = in.getNextEntry()) != null) {
                 results.add(entry.getName());
-
                 final ZipArchiveInputStream nestedIn = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", in);
                 try {
                     ZipArchiveEntry nestedEntry;
@@ -548,7 +671,6 @@ public final class ZipTest extends AbstractTest {
                 // nested stream must not be closed here
             }
         }
-
         assertTrue(results.contains("NestedArchiv.zip"));
         assertTrue(results.contains("test1.xml"));
         assertTrue(results.contains("test2.xml"));
@@ -582,7 +704,7 @@ public final class ZipTest extends AbstractTest {
         al.add("test1.xml");
         al.add("test2.xml");
         try (InputStream fis = Files.newInputStream(input.toPath());
-                final ZipArchiveInputStream inputStream = new ZipArchiveInputStream(fis)) {
+                ZipArchiveInputStream inputStream = new ZipArchiveInputStream(fis)) {
             checkArchiveContent(inputStream, al);
         }
     }
@@ -592,7 +714,7 @@ public final class ZipTest extends AbstractTest {
      */
     @Test
     public void testTokenizationCompressionMethod() throws IOException {
-        try (final ZipFile moby = new ZipFile(getFile("moby.zip"))) {
+        try (ZipFile moby = ZipFile.builder().setFile(getFile("moby.zip")).get()) {
             final ZipArchiveEntry entry = moby.getEntry("README");
             assertEquals(ZipMethod.TOKENIZATION.getCode(), entry.getMethod(), "method");
             assertFalse(moby.canReadEntryData(entry));
@@ -602,7 +724,7 @@ public final class ZipTest extends AbstractTest {
     @Test
     public void testUnixModeInAddRaw() throws IOException {
         final File file1 = createTempFile("unixModeBits.", ".zip");
-        try (final ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
             final ZipArchiveEntry archiveEntry = new ZipArchiveEntry("fred");
             archiveEntry.setUnixMode(0664);
             archiveEntry.setMethod(ZipEntry.STORED);
@@ -610,7 +732,7 @@ public final class ZipTest extends AbstractTest {
             archiveEntry.setCompressedSize(3);
             zos.addRawArchiveEntry(archiveEntry, new ByteArrayInputStream("fud".getBytes()));
         }
-        try (final ZipFile zf1 = new ZipFile(file1)) {
+        try (ZipFile zf1 = newZipFile(file1)) {
             final ZipArchiveEntry fred = zf1.getEntry("fred");
             assertEquals(0664, fred.getUnixMode());
         }
@@ -627,34 +749,30 @@ public final class ZipTest extends AbstractTest {
         final File output = newTempFile("bla.zip");
         final File file1 = getFile("test1.xml");
         final File file2 = getFile("test2.xml");
-
-        try (final OutputStream out = Files.newOutputStream(output.toPath())) {
+        try (OutputStream out = Files.newOutputStream(output.toPath())) {
             try (ArchiveOutputStream<ZipArchiveEntry> os = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("zip", out)) {
+                // entry 1
                 os.putArchiveEntry(new ZipArchiveEntry("testdata/test1.xml"));
                 Files.copy(file1.toPath(), os);
                 os.closeArchiveEntry();
-
+                // entry 2
                 os.putArchiveEntry(new ZipArchiveEntry("testdata/test2.xml"));
                 Files.copy(file2.toPath(), os);
                 os.closeArchiveEntry();
             }
         }
-
         // Unarchive the same
         final List<File> results = new ArrayList<>();
-
-        try (final InputStream fileInputStream = Files.newInputStream(output.toPath())) {
+        try (InputStream fileInputStream = Files.newInputStream(output.toPath())) {
             try (ArchiveInputStream<ZipArchiveEntry> archiveInputStream = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fileInputStream)) {
-                ZipArchiveEntry entry;
-                while ((entry = archiveInputStream.getNextEntry()) != null) {
+                archiveInputStream.forEach(entry -> {
                     final File outfile = new File(tempResultDir.getCanonicalPath() + "/result/" + entry.getName());
                     outfile.getParentFile().mkdirs();
                     Files.copy(archiveInputStream, outfile.toPath());
                     results.add(outfile);
-                }
+                });
             }
         }
-
         assertEquals(results.size(), 2);
         File result = results.get(0);
         assertEquals(file1.length(), result.length());
@@ -669,14 +787,9 @@ public final class ZipTest extends AbstractTest {
      */
     @Test
     public void testZipArchiveCreationInMemory() throws Exception {
-        final File file1 = getFile("test1.xml");
-        final File file2 = getFile("test2.xml");
-        final byte[] file1Contents = new byte[(int) file1.length()];
-        final byte[] file2Contents = new byte[(int) file2.length()];
-        IOUtils.read(file1, file1Contents);
-        IOUtils.read(file2, file2Contents);
+        final byte[] file1Contents = readAllBytes("test1.xml");
+        final byte[] file2Contents = readAllBytes("test2.xml");
         final List<byte[]> results = new ArrayList<>();
-
         try (SeekableInMemoryByteChannel channel = new SeekableInMemoryByteChannel()) {
             try (ZipArchiveOutputStream os = new ZipArchiveOutputStream(channel)) {
                 os.putArchiveEntry(new ZipArchiveEntry("testdata/test1.xml"));
@@ -687,10 +800,8 @@ public final class ZipTest extends AbstractTest {
                 os.write(file2Contents);
                 os.closeArchiveEntry();
             }
-
             // Unarchive the same
             try (ZipArchiveInputStream inputStream = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", new ByteArrayInputStream(channel.array()))) {
-
                 ZipArchiveEntry entry;
                 while ((entry = inputStream.getNextEntry()) != null) {
                     final byte[] result = new byte[(int) entry.getSize()];
@@ -721,7 +832,7 @@ public final class ZipTest extends AbstractTest {
             }
             zos.closeArchiveEntry();
         }
-        try (ZipFile zf = new ZipFile(archiveFile)) {
+        try (ZipFile zf = newZipFile(archiveFile)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
             assertNotNull(out);
             assertEquals("foo", out.getName());
@@ -739,8 +850,8 @@ public final class ZipTest extends AbstractTest {
     @Test
     public void testZipUnarchive() throws Exception {
         final File input = getFile("bla.zip");
-        try (final InputStream is = Files.newInputStream(input.toPath());
-                final ArchiveInputStream<ZipArchiveEntry> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", is)) {
+        try (InputStream is = Files.newInputStream(input.toPath());
+                ArchiveInputStream<ZipArchiveEntry> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", is)) {
             final ZipArchiveEntry entry = in.getNextEntry();
             Files.copy(in, newTempFile(entry.getName()).toPath());
         }
