@@ -21,22 +21,28 @@ package org.apache.commons.compress.archivers.dump;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTimeoutPreemptively;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.InputStream;
+import java.time.Duration;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.compress.AbstractTest;
-import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.archivers.ArchiveException;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.Timeout.ThreadMode;
 
 public class DumpArchiveInputStreamTest extends AbstractTest {
 
+    @SuppressWarnings("deprecation")
     @Test
     public void testConsumesArchiveCompletely() throws Exception {
-        try (final InputStream is = DumpArchiveInputStreamTest.class.getResourceAsStream("/archive_with_trailer.dump");
+        try (InputStream is = DumpArchiveInputStreamTest.class.getResourceAsStream("/archive_with_trailer.dump");
                 DumpArchiveInputStream dump = new DumpArchiveInputStream(is)) {
             while (dump.getNextDumpEntry() != null) {
                 // just consume the archive
@@ -48,12 +54,38 @@ public class DumpArchiveInputStreamTest extends AbstractTest {
         }
     }
 
+    @Test
+    public void testDirectoryNullBytes() throws Exception {
+        try (InputStream is = newInputStream("org/apache/commons/compress/dump/directory_null_bytes-fail.dump");
+                DumpArchiveInputStream archive = new DumpArchiveInputStream(is)) {
+            assertThrows(InvalidFormatException.class, archive::getNextEntry);
+        }
+    }
+
+    @Test
+    public void testInvalidCompressType() throws Exception {
+        try (InputStream is = newInputStream("org/apache/commons/compress/dump/invalid_compression_type-fail.dump")) {
+            final ArchiveException ex = assertThrows(ArchiveException.class, () -> new DumpArchiveInputStream(is).close());
+            assertInstanceOf(UnsupportedCompressionAlgorithmException.class, ex.getCause());
+        }
+    }
+
+    @Test
+    @Timeout(value = 15, unit = TimeUnit.SECONDS, threadMode = ThreadMode.SEPARATE_THREAD)
+    public void testLoopingInodes() throws Exception {
+        try (InputStream is = newInputStream("org/apache/commons/compress/dump/looping_inodes-fail.dump");
+                DumpArchiveInputStream archive = new DumpArchiveInputStream(is)) {
+            archive.getNextEntry();
+            assertThrows(DumpArchiveException.class, archive::getNextEntry);
+        }
+    }
+
     @Test
     public void testMultiByteReadConsistentlyReturnsMinusOneAtEof() throws Exception {
         final byte[] buf = new byte[2];
         try (InputStream in = newInputStream("bla.dump");
-             DumpArchiveInputStream archive = new DumpArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+                DumpArchiveInputStream archive = new DumpArchiveInputStream(in)) {
+            assertNotNull(archive.getNextEntry());
             IOUtils.toByteArray(archive);
             assertEquals(-1, archive.read(buf));
             assertEquals(-1, archive.read(buf));
@@ -63,8 +95,7 @@ public class DumpArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testNotADumpArchive() throws Exception {
         try (InputStream is = newInputStream("bla.zip")) {
-            final ArchiveException ex = assertThrows(ArchiveException.class, () -> new DumpArchiveInputStream(is).close(),
-                    "expected an exception");
+            final ArchiveException ex = assertThrows(ArchiveException.class, () -> new DumpArchiveInputStream(is).close(), "expected an exception");
             assertTrue(ex.getCause() instanceof ShortFileException);
         }
     }
@@ -72,17 +103,26 @@ public class DumpArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testNotADumpArchiveButBigEnough() throws Exception {
         try (InputStream is = newInputStream("zip64support.tar.bz2")) {
-            final ArchiveException ex = assertThrows(ArchiveException.class, () -> new DumpArchiveInputStream(is).close(),
-                    "expected an exception");
+            final ArchiveException ex = assertThrows(ArchiveException.class, () -> new DumpArchiveInputStream(is).close(), "expected an exception");
             assertInstanceOf(UnrecognizedFormatException.class, ex.getCause());
         }
     }
 
+    @Test
+    public void testRecLenZeroLongExecution() throws Exception {
+        try (InputStream is = newInputStream("org/apache/commons/compress/dump/reclen_zero-fail.dump");
+                DumpArchiveInputStream archive = new DumpArchiveInputStream(is)) {
+            assertTimeoutPreemptively(Duration.ofSeconds(20), () -> {
+                assertThrows(DumpArchiveException.class, archive::getNextEntry);
+            });
+        }
+    }
+
     @Test
     public void testSingleByteReadConsistentlyReturnsMinusOneAtEof() throws Exception {
         try (InputStream in = newInputStream("bla.dump");
-             DumpArchiveInputStream archive = new DumpArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+                DumpArchiveInputStream archive = new DumpArchiveInputStream(in)) {
+            assertNotNull(archive.getNextEntry());
             IOUtils.toByteArray(archive);
             assertEquals(-1, archive.read());
             assertEquals(-1, archive.read());
