@@ -20,33 +20,38 @@ package org.apache.commons.compress.archivers.memory;
 
 import java.io.IOException;
 
+import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.archivers.ArchiveInputStream;
 
-public final class MemoryArchiveInputStream extends ArchiveInputStream<MemoryArchiveEntry> {
+public final class MemoryArchiveInputStream extends ArchiveInputStream {
 
-    private final String[] fileNames;
+    private final String[] filenames;
     private final String[] content;
     private int p;
 
     public MemoryArchiveInputStream( final String[][] pFiles ) {
-        final int pFilesLength = pFiles.length;
-        fileNames = new String[pFilesLength];
-        content = new String[pFilesLength];
+        filenames = new String[pFiles.length];
+        content = new String[pFiles.length];
 
-        for (int i = 0; i < pFilesLength; i++) {
-            final String[] nameAndContent = pFiles[i];
-            fileNames[i] = nameAndContent[0];
+        for (int i = 0; i < pFiles.length; i++) {
+            String[] nameAndContent = pFiles[i];
+            filenames[i] = nameAndContent[0];
             content[i] = nameAndContent[1];
         }
         p = 0;
     }
 
     @Override
-    public MemoryArchiveEntry getNextEntry() throws IOException {
-        if (p >= fileNames.length) {
+    public ArchiveEntry getNextEntry() throws IOException {
+        if (p >= filenames.length) {
             return null;
         }
-        return new MemoryArchiveEntry(fileNames[p]);
+
+        return new MemoryArchiveEntry(filenames[p]);
+    }
+
+    public String readString() {
+        return content[p++];
     }
 
     @Override
@@ -54,8 +59,4 @@ public final class MemoryArchiveInputStream extends ArchiveInputStream<MemoryArc
         return 0;
     }
 
-    public String readString() {
-        return content[p++];
-    }
-
 }
