@@ -18,22 +18,22 @@
  */
 package org.apache.commons.compress.archivers.sevenz;
 
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import org.junit.jupiter.api.Test;
 
 public class CoverageTest {
 
-    @Test
-    public void testNidInstance() {
-        assertNotNull(new NID());
-    }
-
     @Test
     public void testCLIInstance() {
         final CLI foo = new CLI();
         assertNotNull(foo);
         assertThrows(Exception.class, () -> CLI.main(new String[] { "/dev/null/not-there" }));
     }
+
+    @Test
+    public void testNidInstance() {
+        assertNotNull(new NID());
+    }
 }
