@@ -21,6 +21,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -96,22 +97,22 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     private void createAndReadBack(final File output, final Iterable<SevenZMethodConfiguration> methods) throws Exception {
-        try (final SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
+        try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.setContentMethods(methods);
             addFile(outArchive, 0, true);
         }
 
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             assertEquals(Boolean.TRUE, verifyFile(archive, 0, methods));
         }
     }
 
     private void createAndReadBack(final SeekableInMemoryByteChannel output, final Iterable<SevenZMethodConfiguration> methods) throws Exception {
-        try (final SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
+        try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.setContentMethods(methods);
             addFile(outArchive, 0, true);
         }
-        try (SevenZFile archive = new SevenZFile(new SeekableInMemoryByteChannel(output.array()), "in memory")) {
+        try (SevenZFile archive = SevenZFile.builder().setByteArray(output.array()).setDefaultName("in memory").get()) {
             assertEquals(Boolean.TRUE, verifyFile(archive, 0, methods));
         }
     }
@@ -142,7 +143,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             addFile(outArchive, 1, true, Arrays.asList(new SevenZMethodConfiguration(SevenZMethod.BZIP2)));
         }
 
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             assertEquals(Boolean.TRUE, verifyFile(archive, 0, Arrays.asList(new SevenZMethodConfiguration(SevenZMethod.LZMA2))));
             assertEquals(Boolean.TRUE, verifyFile(archive, 1, Arrays.asList(new SevenZMethodConfiguration(SevenZMethod.BZIP2))));
         }
@@ -336,15 +337,15 @@ public class SevenZOutputFileTest extends AbstractTest {
             outArchive.finish();
         }
 
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             SevenZArchiveEntry entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/", entry.getName());
             assertTrue(entry.isDirectory());
             assertFalse(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -355,7 +356,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo0", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -366,7 +367,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo1", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -377,7 +378,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo10000", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -388,7 +389,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/test.txt", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -399,7 +400,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("xyzzy", entry.getName());
             assertEquals(1, entry.getSize());
             assertFalse(entry.getHasAccessDate());
@@ -407,19 +408,19 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(0, archive.read());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("baz/", entry.getName());
             assertTrue(entry.isDirectory());
             assertTrue(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("baz2/", entry.getName());
             assertTrue(entry.isDirectory());
             assertTrue(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("dada", entry.getName());
             assertEquals(2, entry.getSize());
             final byte[] content = new byte[2];
@@ -428,7 +429,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(42, content[1]);
             assertEquals(17, entry.getWindowsAttributes());
 
-            assert archive.getNextEntry() == null;
+            assertNull(archive.getNextEntry(), "getNextEntry should return null");
         }
 
     }
@@ -444,14 +445,14 @@ public class SevenZOutputFileTest extends AbstractTest {
             outArchive.closeArchiveEntry();
         }
 
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             final SevenZArchiveEntry entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "entry should not be null");
             assertEquals("foo/", entry.getName());
             assertTrue(entry.isDirectory());
             assertFalse(entry.isAntiItem());
 
-            assert archive.getNextEntry() == null;
+            assertNull(archive.getNextEntry(), "getnextEntry should return null");
         }
 
     }
@@ -486,13 +487,12 @@ public class SevenZOutputFileTest extends AbstractTest {
         }
 
         // Is archive really password-based encrypted ?
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             assertThrows(
-
                     PasswordRequiredException.class, () -> verifyFile(archive, 0), "A password should be needed");
         }
 
-        try (SevenZFile archive = new SevenZFile(output, "foo".toCharArray())) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).setPassword("foo").get()) {
             assertEquals(Boolean.TRUE, verifyFile(archive, 0, 1, null));
             assertEquals(Boolean.TRUE, verifyFile(archive, 1, 16, null));
             assertEquals(Boolean.TRUE, verifyFile(archive, 2, 32, null));
@@ -615,7 +615,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     private void verifyCompress252(final File output, final int numberOfFiles, final int numberOfNonEmptyFiles) throws Exception {
         int filesFound = 0;
         int nonEmptyFilesFound = 0;
-        try (SevenZFile archive = new SevenZFile(output)) {
+        try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             verifyDir(archive);
             Boolean b = verifyFile(archive, filesFound++);
             while (b != null) {
