@@ -47,12 +47,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarEpax() throws Exception {
         final String file = "COMPRESS-612/test-times-epax-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44.147126600Z"), e.getLastModifiedTime(), "mtime");
@@ -62,7 +62,7 @@ public class FileTimesIT extends AbstractTest {
             e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-17T00:38:20.470751500Z"), e.getLastModifiedTime(), "mtime");
@@ -77,11 +77,11 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarExustar() throws Exception {
         final String file = "COMPRESS-612/test-times-exustar-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44.147126600Z"), e.getLastModifiedTime(), "mtime");
@@ -90,7 +90,7 @@ public class FileTimesIT extends AbstractTest {
             assertNull(e.getCreationTime(), "birthtime");
             assertGlobalHeaders(e);
             e = tin.getNextTarEntry();
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-17T00:38:20.470751500Z"), e.getLastModifiedTime(), "mtime");
@@ -107,8 +107,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarGnu() throws Exception {
         final String file = "COMPRESS-612/test-times-gnu.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -125,12 +125,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarGnuIncremental() throws Exception {
         final String file = "COMPRESS-612/test-times-gnu-incremental.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test-times.txt", e.getName());
+            assertEquals("test-times.txt", e.getName());
             assertEquals(toFileTime("2022-03-14T01:25:03Z"), e.getLastModifiedTime(), "mtime");
             assertNull(e.getLastAccessTime(), "atime");
             assertNull(e.getStatusChangeTime(), "ctime");
@@ -138,7 +138,7 @@ public class FileTimesIT extends AbstractTest {
             e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test-times.txt", e.getName());
+            assertEquals("test-times.txt", e.getName());
             assertEquals(toFileTime("2022-03-14T03:17:05Z"), e.getLastModifiedTime(), "mtime");
             assertEquals(toFileTime("2022-03-14T03:17:10Z"), e.getLastAccessTime(), "atime");
             assertEquals(toFileTime("2022-03-14T03:17:10Z"), e.getStatusChangeTime(), "ctime");
@@ -152,8 +152,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarGnuTar() throws Exception {
         final String file = "COMPRESS-612/test-times-gnutar.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -169,8 +169,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarOldBsdTar() throws Exception {
         final String file = "COMPRESS-612/test-times-oldbsdtar.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -187,8 +187,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarOldGnu() throws Exception {
         final String file = "COMPRESS-612/test-times-oldgnu.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -205,12 +205,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarOldGnuIncremental() throws Exception {
         final String file = "COMPRESS-612/test-times-oldgnu-incremental.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test-times.txt", e.getName());
+            assertEquals("test-times.txt", e.getName());
             assertEquals(toFileTime("2022-03-14T01:25:03Z"), e.getLastModifiedTime(), "mtime");
             assertNull(e.getLastAccessTime(), "atime");
             assertNull(e.getStatusChangeTime(), "ctime");
@@ -218,7 +218,7 @@ public class FileTimesIT extends AbstractTest {
             e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test-times.txt", e.getName());
+            assertEquals("test-times.txt", e.getName());
             assertEquals(toFileTime("2022-03-14T03:17:05Z"), e.getLastModifiedTime(), "mtime");
             assertEquals(toFileTime("2022-03-14T03:17:06Z"), e.getLastAccessTime(), "atime");
             assertEquals(toFileTime("2022-03-14T03:17:05Z"), e.getStatusChangeTime(), "ctime");
@@ -232,12 +232,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarPax() throws Exception {
         final String file = "COMPRESS-612/test-times-pax-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44.147126600Z"), e.getLastModifiedTime(), "mtime");
@@ -247,7 +247,7 @@ public class FileTimesIT extends AbstractTest {
             e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-17T00:38:20.470751500Z"), e.getLastModifiedTime(), "mtime");
@@ -263,8 +263,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarPosix() throws Exception {
         final String file = "COMPRESS-612/test-times-posix.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -281,12 +281,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarPosixLibArchive() throws Exception {
         final String file = "COMPRESS-612/test-times-bsd-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-16T10:19:43.382883700Z"), e.getLastModifiedTime(), "mtime");
@@ -296,7 +296,7 @@ public class FileTimesIT extends AbstractTest {
             e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-16T10:21:00.249238500Z"), e.getLastModifiedTime(), "mtime");
@@ -312,8 +312,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarPosixLinux() throws Exception {
         final String file = "COMPRESS-612/test-times-posix-linux.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -329,12 +329,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarStarFolder() throws Exception {
         final String file = "COMPRESS-612/test-times-star-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44Z"), e.getLastModifiedTime(), "mtime");
@@ -343,7 +343,7 @@ public class FileTimesIT extends AbstractTest {
             assertNull(e.getCreationTime(), "birthtime");
             e = tin.getNextTarEntry();
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-17T00:38:20Z"), e.getLastModifiedTime(), "mtime");
@@ -358,8 +358,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarUstar() throws Exception {
         final String file = "COMPRESS-612/test-times-ustar.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -375,8 +375,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarV7() throws Exception {
         final String file = "COMPRESS-612/test-times-v7.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -392,8 +392,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXstar() throws Exception {
         final String file = "COMPRESS-612/test-times-xstar.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -409,12 +409,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXstarFolder() throws Exception {
         final String file = "COMPRESS-612/test-times-xstar-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44Z"), e.getLastModifiedTime(), "mtime");
@@ -422,7 +422,7 @@ public class FileTimesIT extends AbstractTest {
             assertEquals(toFileTime("2022-03-17T00:24:44Z"), e.getStatusChangeTime(), "ctime");
             assertNull(e.getCreationTime(), "birthtime");
             e = tin.getNextTarEntry();
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -438,12 +438,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXstarIncremental() throws Exception {
         final String file = "COMPRESS-612/test-times-xstar-incremental.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test-times.txt", e.getName());
+            assertEquals("test-times.txt", e.getName());
             assertEquals(toFileTime("2022-03-14T04:03:29Z"), e.getLastModifiedTime(), "mtime");
             assertEquals(toFileTime("2022-03-14T04:03:29Z"), e.getLastAccessTime(), "atime");
             assertEquals(toFileTime("2022-03-14T04:03:29Z"), e.getStatusChangeTime(), "ctime");
@@ -464,8 +464,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXustar() throws Exception {
         final String file = "COMPRESS-612/test-times-xustar.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             final TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
@@ -481,12 +481,12 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXustarFolder() throws Exception {
         final String file = "COMPRESS-612/test-times-xustar-folder.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/", e.getName());
+            assertEquals("test/", e.getName());
             assertEquals(TarConstants.LF_DIR, e.getLinkFlag());
             assertTrue(e.isDirectory());
             assertEquals(toFileTime("2022-03-17T00:24:44.147126600Z"), e.getLastModifiedTime(), "mtime");
@@ -495,7 +495,7 @@ public class FileTimesIT extends AbstractTest {
             assertNull(e.getCreationTime(), "birthtime");
             e = tin.getNextTarEntry();
             assertTrue(e.getExtraPaxHeaders().isEmpty());
-            assertEquals("name", "test/test-times.txt", e.getName());
+            assertEquals("test/test-times.txt", e.getName());
             assertEquals(TarConstants.LF_NORMAL, e.getLinkFlag());
             assertTrue(e.isFile());
             assertEquals(toFileTime("2022-03-17T00:38:20.470751500Z"), e.getLastModifiedTime(), "mtime");
@@ -510,8 +510,8 @@ public class FileTimesIT extends AbstractTest {
     @Test
     public void testReadTimeFromTarXustarIncremental() throws Exception {
         final String file = "COMPRESS-612/test-times-xustar-incremental.tar";
-        try (final InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
-             final TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
+        try (InputStream in = new BufferedInputStream(Files.newInputStream(getPath(file)));
+                TarArchiveInputStream tin = new TarArchiveInputStream(in)) {
             TarArchiveEntry e = tin.getNextTarEntry();
             assertNotNull(e);
             assertTrue(e.getExtraPaxHeaders().isEmpty());
