@@ -49,8 +49,7 @@ import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.parallel.FileBasedScatterGatherBackingStore;
 import org.apache.commons.compress.parallel.InputStreamSupplier;
 import org.apache.commons.compress.parallel.ScatterGatherBackingStoreSupplier;
-import org.apache.commons.compress.utils.CharsetNames;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
@@ -77,7 +76,7 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
         final Map<String, byte[]> entries;
         final ParallelScatterZipCreator zipCreator;
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(result)) {
-            zos.setEncoding(CharsetNames.UTF_8);
+            zos.setEncoding(StandardCharsets.UTF_8.name());
             final ExecutorService es = Executors.newFixedThreadPool(1);
 
             final ScatterGatherBackingStoreSupplier supp = () -> new FileBasedScatterGatherBackingStore(createTempFile("parallelscatter", "n1"));
@@ -96,7 +95,7 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
         final ParallelScatterZipCreator zipCreator;
         final Map<String, byte[]> entries;
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(result)) {
-            zos.setEncoding(CharsetNames.UTF_8);
+            zos.setEncoding(StandardCharsets.UTF_8.name());
             final ExecutorService es = Executors.newFixedThreadPool(1);
 
             final ScatterGatherBackingStoreSupplier supp = () -> new FileBasedScatterGatherBackingStore(createTempFile("parallelscatter", "n1"));
@@ -107,11 +106,11 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
         }
 
         // validate the content of the compressed files
-        try (ZipFile zf = new ZipFile(result)) {
+        try (ZipFile zf = ZipFile.builder().setFile(result).get()) {
             final Enumeration<ZipArchiveEntry> entriesInPhysicalOrder = zf.getEntriesInPhysicalOrder();
             while (entriesInPhysicalOrder.hasMoreElements()) {
                 final ZipArchiveEntry zipArchiveEntry = entriesInPhysicalOrder.nextElement();
-                try (final InputStream inputStream = zf.getInputStream(zipArchiveEntry)) {
+                try (InputStream inputStream = zf.getInputStream(zipArchiveEntry)) {
                     final byte[] actual = IOUtils.toByteArray(inputStream);
                     final byte[] expected = entries.remove(zipArchiveEntry.getName());
                     assertArrayEquals(expected, actual, "For " + zipArchiveEntry.getName());
@@ -131,7 +130,7 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
     }
 
     private void removeEntriesFoundInZipFile(final File result, final Map<String, byte[]> entries) throws IOException {
-        try (ZipFile zf = new ZipFile(result)) {
+        try (ZipFile zf = ZipFile.builder().setFile(result).get()) {
             final Enumeration<ZipArchiveEntry> entriesInPhysicalOrder = zf.getEntriesInPhysicalOrder();
             int i = 0;
             while (entriesInPhysicalOrder.hasMoreElements()) {
@@ -175,35 +174,35 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
 
     @Test
     public void testCallableApiUsingSubmit() throws Exception {
-        File result = createTempFile("parallelScatterGather2", "");
+        final File result = createTempFile("parallelScatterGather2", "");
         callableApi(zipCreator -> zipCreator::submit, result);
     }
 
     @Test
     public void testCallableApiUsingSubmitStreamAwareCallable() throws Exception {
-        File result = createTempFile("parallelScatterGather3", "");
+        final File result = createTempFile("parallelScatterGather3", "");
         callableApi(zipCreator -> zipCreator::submitStreamAwareCallable, result);
     }
 
     @Test
     public void testCallableApiWithHighestLevelUsingSubmitStreamAwareCallable() throws Exception {
-        File result = createTempFile("parallelScatterGather5", "");
+        final File result = createTempFile("parallelScatterGather5", "");
         callableApiWithTestFiles(zipCreator -> zipCreator::submitStreamAwareCallable, Deflater.BEST_COMPRESSION, result);
     }
 
     @Test
     public void testCallableWithLowestLevelApiUsingSubmit() throws Exception {
-        File result = createTempFile("parallelScatterGather4", "");
+        final File result = createTempFile("parallelScatterGather4", "");
         callableApiWithTestFiles(zipCreator -> zipCreator::submit, Deflater.NO_COMPRESSION, result);
     }
 
     @Test
     public void testConcurrentCustomTempFolder() throws Exception {
-        File result = createTempFile("parallelScatterGather1", "");
+        final File result = createTempFile("parallelScatterGather1", "");
         final ParallelScatterZipCreator zipCreator;
         final Map<String, byte[]> entries;
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(result)) {
-            zos.setEncoding(CharsetNames.UTF_8);
+            zos.setEncoding(StandardCharsets.UTF_8.name());
 
             // Formatter:off
             final Path dir = Paths.get("target/custom-temp-dir");
@@ -222,11 +221,11 @@ public class ParallelScatterZipCreatorTest extends AbstractTempDirTest {
 
     @Test
     public void testConcurrentDefaultTempFolder() throws Exception {
-        File result = createTempFile("parallelScatterGather1", "");
+        final File result = createTempFile("parallelScatterGather1", "");
         final ParallelScatterZipCreator zipCreator;
         final Map<String, byte[]> entries;
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(result)) {
-            zos.setEncoding(CharsetNames.UTF_8);
+            zos.setEncoding(StandardCharsets.UTF_8.name());
             zipCreator = new ParallelScatterZipCreator();
 
             entries = writeEntries(zipCreator);
