@@ -36,6 +36,7 @@ import java.util.zip.ZipException;
 
 import org.apache.commons.compress.utils.ByteUtils;
 import org.apache.commons.compress.utils.TimeUtils;
+import org.apache.commons.io.file.attribute.FileTimes;
 import org.junit.jupiter.api.Test;
 
 /**
@@ -60,9 +61,7 @@ public class ZipArchiveEntryTest {
         u.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
         u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
         final UnparseableExtraFieldData x = new UnparseableExtraFieldData();
-        final byte[] unparseable = {
-            0, 0, (byte) 0xff, (byte) 0xff, 0, 0, 0
-        };
+        final byte[] unparseable = { 0, 0, (byte) 0xff, (byte) 0xff, 0, 0, 0 };
         x.parseFromLocalFileData(unparseable, 0, unparseable.length);
         return new ZipExtraField[] { a, u, x };
     }
@@ -80,12 +79,12 @@ public class ZipArchiveEntryTest {
         u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
-        ze.setExtraFields(new ZipExtraField[] {a, u});
+        ze.setExtraFields(new ZipExtraField[] { a, u });
         final byte[] data1 = ze.getExtra();
 
         final UnrecognizedExtraField u2 = new UnrecognizedExtraField();
         u2.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u2.setLocalFileDataData(new byte[] {1});
+        u2.setLocalFileDataData(new byte[] { 1 });
 
         ze.addAsFirstExtraField(u2);
         final byte[] data2 = ze.getExtra();
@@ -97,7 +96,7 @@ public class ZipArchiveEntryTest {
 
         final UnrecognizedExtraField u3 = new UnrecognizedExtraField();
         u3.setHeaderId(new ZipShort(2));
-        u3.setLocalFileDataData(new byte[] {1});
+        u3.setLocalFileDataData(new byte[] { 1 });
         ze.addAsFirstExtraField(u3);
         result = ze.getExtraFields();
         assertEquals(3, result.length, "third pass");
@@ -107,9 +106,7 @@ public class ZipArchiveEntryTest {
     }
 
     /**
-     * Test case for
-     * <a href="https://issues.apache.org/jira/browse/COMPRESS-93"
-     * >COMPRESS-93</a>.
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-93" >COMPRESS-93</a>.
      */
     @Test
     public void testCompressionMethod() throws Exception {
@@ -164,31 +161,30 @@ public class ZipArchiveEntryTest {
         u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
-        ze.setExtraFields(new ZipExtraField[] {a, u});
+        ze.setExtraFields(new ZipExtraField[] { a, u });
 
         // merge
         // Header-ID 1 + length 1 + one byte of data
         final byte[] b = ExtraFieldUtilsTest.UNRECOGNIZED_HEADER.getBytes();
-        ze.setCentralDirectoryExtra(new byte[] {b[0], b[1], 1, 0, 127});
+        ze.setCentralDirectoryExtra(new byte[] { b[0], b[1], 1, 0, 127 });
 
         ZipExtraField[] result = ze.getExtraFields();
         assertEquals(2, result.length, "first pass");
         assertSame(a, result[0]);
-        assertEquals(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER,
-                     result[1].getHeaderId());
+        assertEquals(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER, result[1].getHeaderId());
         assertEquals(new ZipShort(0), result[1].getLocalFileDataLength());
         assertEquals(new ZipShort(1), result[1].getCentralDirectoryLength());
 
         // add new
         // Header-ID 2 + length 0
-        ze.setCentralDirectoryExtra(new byte[] {2, 0, 0, 0});
+        ze.setCentralDirectoryExtra(new byte[] { 2, 0, 0, 0 });
 
         result = ze.getExtraFields();
         assertEquals(3, result.length, "second pass");
 
         // merge
         // Header-ID 2 + length 1 + one byte of data
-        ze.setExtra(new byte[] {2, 0, 1, 0, 127});
+        ze.setExtra(new byte[] { 2, 0, 1, 0, 127 });
 
         result = ze.getExtraFields();
         assertEquals(3, result.length, "third pass");
@@ -211,7 +207,7 @@ public class ZipArchiveEntryTest {
         u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
-        ze.setExtraFields(new ZipExtraField[] {a, u});
+        ze.setExtraFields(new ZipExtraField[] { a, u });
         final byte[] data1 = ze.getExtra();
         ZipExtraField[] result = ze.getExtraFields();
         assertEquals(2, result.length, "first pass");
@@ -220,7 +216,7 @@ public class ZipArchiveEntryTest {
 
         final UnrecognizedExtraField u2 = new UnrecognizedExtraField();
         u2.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u2.setLocalFileDataData(new byte[] {1});
+        u2.setLocalFileDataData(new byte[] { 1 });
 
         ze.addExtraField(u2);
         final byte[] data2 = ze.getExtra();
@@ -232,7 +228,7 @@ public class ZipArchiveEntryTest {
 
         final UnrecognizedExtraField u3 = new UnrecognizedExtraField();
         u3.setHeaderId(new ZipShort(2));
-        u3.setLocalFileDataData(new byte[] {1});
+        u3.setLocalFileDataData(new byte[] { 1 });
         ze.addExtraField(u3);
         result = ze.getExtraFields();
         assertEquals(3, result.length, "third pass");
@@ -245,8 +241,7 @@ public class ZipArchiveEntryTest {
         assertSame(u3, result[1]);
         assertEquals(data2.length, data3.length, "length fourth pass");
 
-        assertThrows(NoSuchElementException.class, () -> ze.removeExtraField(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER),
-                "should be no such element");
+        assertThrows(NoSuchElementException.class, () -> ze.removeExtraField(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER), "should be no such element");
     }
 
     @Test
@@ -263,16 +258,14 @@ public class ZipArchiveEntryTest {
      */
     @Test
     public void testIsUnixSymlinkIsFalseIfMoreThanOneFlagIsSet() throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-379.jar"))) {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile("COMPRESS-379.jar")).get()) {
             final ZipArchiveEntry ze = zf.getEntry("META-INF/maven/");
             assertFalse(ze.isUnixSymlink());
         }
     }
 
     /**
-     * Test case for
-     * <a href="https://issues.apache.org/jira/browse/COMPRESS-94"
-     * >COMPRESS-94</a>.
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-94" >COMPRESS-94</a>.
      */
     @Test
     public void testNotEquals() {
@@ -283,6 +276,7 @@ public class ZipArchiveEntryTest {
 
     /**
      * Tests comment's influence on equals comparisons.
+     *
      * @see "https://issues.apache.org/jira/browse/COMPRESS-187"
      */
     @Test
@@ -317,9 +311,8 @@ public class ZipArchiveEntryTest {
     }
 
     @Test
-    public void testReparsingUnicodeExtraWithUnsupportedversionThrowsInStrictMode()
-        throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
+    public void testReparsingUnicodeExtraWithUnsupportedversionThrowsInStrictMode() throws Exception {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile("COMPRESS-479.zip")).get()) {
             final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
             assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS));
         }
@@ -356,8 +349,8 @@ public class ZipArchiveEntryTest {
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
         assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(accessTime), ntfs.getAccessTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(accessTime), ntfs.getAccessTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
     }
 
     @Test
@@ -371,7 +364,7 @@ public class ZipArchiveEntryTest {
         assertNull(ze.getExtraField(X5455_ExtendedTimestamp.HEADER_ID));
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
-        assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
         assertEquals(0L, ntfs.getAccessTime().getLongValue());
         assertEquals(0L, ntfs.getCreateTime().getLongValue());
     }
@@ -393,7 +386,7 @@ public class ZipArchiveEntryTest {
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
         assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(lastAccessTime), ntfs.getAccessTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(lastAccessTime), ntfs.getAccessTime().getLongValue());
         assertEquals(0L, ntfs.getCreateTime().getLongValue());
     }
 
@@ -416,8 +409,8 @@ public class ZipArchiveEntryTest {
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
         assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(accessTime), ntfs.getAccessTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(accessTime), ntfs.getAccessTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
     }
 
     @Test
@@ -438,7 +431,7 @@ public class ZipArchiveEntryTest {
         assertNotNull(ntfs);
         assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
         assertEquals(0L, ntfs.getAccessTime().getLongValue());
-        assertEquals(TimeUtils.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(creationTime), ntfs.getCreateTime().getLongValue());
     }
 
     @Test
@@ -456,7 +449,7 @@ public class ZipArchiveEntryTest {
         assertNull(extendedTimestamp.getCreateTime());
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
-        assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
         assertEquals(0L, ntfs.getAccessTime().getLongValue());
         assertEquals(0L, ntfs.getCreateTime().getLongValue());
     }
@@ -476,7 +469,7 @@ public class ZipArchiveEntryTest {
         assertNull(extendedTimestamp.getCreateTime());
         final X000A_NTFS ntfs = (X000A_NTFS) ze.getExtraField(X000A_NTFS.HEADER_ID);
         assertNotNull(ntfs);
-        assertEquals(TimeUtils.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
+        assertEquals(FileTimes.toNtfsTime(time), ntfs.getModifyTime().getLongValue());
         assertEquals(0L, ntfs.getAccessTime().getLongValue());
         assertEquals(0L, ntfs.getCreateTime().getLongValue());
     }
@@ -496,34 +489,30 @@ public class ZipArchiveEntryTest {
         assertEquals(0, ze.getPlatform());
         ze.setUnixMode(0755);
         assertEquals(3, ze.getPlatform());
-        assertEquals(0755,
-                     ze.getExternalAttributes() >> 16 & 0xFFFF);
-        assertEquals(0, ze.getExternalAttributes()  & 0xFFFF);
+        assertEquals(0755, ze.getExternalAttributes() >> 16 & 0xFFFF);
+        assertEquals(0, ze.getExternalAttributes() & 0xFFFF);
 
         ze.setUnixMode(0444);
         assertEquals(3, ze.getPlatform());
-        assertEquals(0444,
-                     ze.getExternalAttributes() >> 16 & 0xFFFF);
-        assertEquals(1, ze.getExternalAttributes()  & 0xFFFF);
+        assertEquals(0444, ze.getExternalAttributes() >> 16 & 0xFFFF);
+        assertEquals(1, ze.getExternalAttributes() & 0xFFFF);
 
         ze = new ZipArchiveEntry("foo/");
         assertEquals(0, ze.getPlatform());
         ze.setUnixMode(0777);
         assertEquals(3, ze.getPlatform());
-        assertEquals(0777,
-                     ze.getExternalAttributes() >> 16 & 0xFFFF);
-        assertEquals(0x10, ze.getExternalAttributes()  & 0xFFFF);
+        assertEquals(0777, ze.getExternalAttributes() >> 16 & 0xFFFF);
+        assertEquals(0x10, ze.getExternalAttributes() & 0xFFFF);
 
         ze.setUnixMode(0577);
         assertEquals(3, ze.getPlatform());
-        assertEquals(0577,
-                     ze.getExternalAttributes() >> 16 & 0xFFFF);
-        assertEquals(0x11, ze.getExternalAttributes()  & 0xFFFF);
+        assertEquals(0577, ze.getExternalAttributes() >> 16 & 0xFFFF);
+        assertEquals(0x11, ze.getExternalAttributes() & 0xFFFF);
     }
 
     @Test
     public void testZipArchiveClone() throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile("COMPRESS-479.zip")).get()) {
             final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
             final ZipArchiveEntry clonedZe = (ZipArchiveEntry) ze.clone();
             assertEquals(ze, clonedZe);
