@@ -24,7 +24,6 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
@@ -33,12 +32,14 @@ import java.io.EOFException;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
 import java.nio.channels.Channels;
 import java.nio.channels.SeekableByteChannel;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.time.Instant;
-import java.util.Arrays;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipException;
 
@@ -47,8 +48,8 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.archivers.ArchiveInputStream;
 import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.utils.ByteUtils;
-import org.apache.commons.compress.utils.CharsetNames;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang3.ArrayFill;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.ValueSource;
@@ -97,8 +98,8 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
      * @throws IOException there are problems
      */
     private InputStream forgeZipInputStream() throws IOException {
-        try (final ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
-                final ZipArchiveOutputStream zo = new ZipArchiveOutputStream(byteArrayOutputStream)) {
+        try (ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
+                ZipArchiveOutputStream zo = new ZipArchiveOutputStream(byteArrayOutputStream)) {
 
             final ZipArchiveEntry entryA = new ZipArchiveEntry("foo");
             entryA.setMethod(ZipEntry.STORED);
@@ -149,7 +150,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         final byte[] buf = new byte[2];
         try (InputStream in = newInputStream("bla.zip");
                 ZipArchiveInputStream archive = new ZipArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+            assertNotNull(archive.getNextEntry());
             IOUtils.toByteArray(archive);
             assertEquals(-1, archive.read(buf));
             assertEquals(-1, archive.read(buf));
@@ -159,13 +160,21 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     private void singleByteReadConsistentlyReturnsMinusOneAtEof(final File file) throws Exception {
         try (InputStream in = Files.newInputStream(file.toPath());
                 ZipArchiveInputStream archive = new ZipArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+            assertNotNull(archive.getNextEntry());
             IOUtils.toByteArray(archive);
             assertEquals(-1, archive.read());
             assertEquals(-1, archive.read());
         }
     }
 
+    @Test
+    public void testGetFirstEntryEmptyZip() throws IOException {
+        try (ZipArchiveInputStream zin = new ZipArchiveInputStream(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY))) {
+            final ZipArchiveEntry entry = zin.getNextEntry();
+            assertNull(entry);
+        }
+    }
+
     /**
      * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-351" >COMPRESS-351</a>.
      */
@@ -215,7 +224,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
 
     @Test
     public void testMultiByteReadThrowsAtEofForCorruptedStoredEntry() throws Exception {
-        final byte[] content = Files.readAllBytes(getFile("COMPRESS-264.zip").toPath());
+        final byte[] content = readAllBytes("COMPRESS-264.zip");
         // make size much bigger than entry's real size
         for (int i = 17; i < 26; i++) {
             content[i] = (byte) 0xff;
@@ -223,7 +232,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         final byte[] buf = new byte[2];
         try (ByteArrayInputStream in = new ByteArrayInputStream(content);
                 ZipArchiveInputStream archive = new ZipArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+            assertNotNull(archive.getNextEntry());
             final IOException ex1 = assertThrows(IOException.class, () -> IOUtils.toByteArray(archive), "expected exception");
             assertEquals("Truncated ZIP file", ex1.getMessage());
             final IOException ex2 = assertThrows(IOException.class, () -> archive.read(buf), "expected exception");
@@ -307,7 +316,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testProperlyReadsStoredEntryWithDataDescriptorWithoutSignature() throws IOException {
         try (InputStream fs = newInputStream("bla-stored-dd-nosig.zip");
-                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, CharsetNames.UTF_8, true, true)) {
+                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, StandardCharsets.UTF_8.name(), true, true)) {
             final ZipArchiveEntry e = archive.getNextZipEntry();
             assertNotNull(e);
             assertEquals("test1.xml", e.getName());
@@ -323,7 +332,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testProperlyReadsStoredEntryWithDataDescriptorWithSignature() throws IOException {
         try (InputStream fs = newInputStream("bla-stored-dd.zip");
-                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, CharsetNames.UTF_8, true, true)) {
+                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, StandardCharsets.UTF_8.name(), true, true)) {
             final ZipArchiveEntry e = archive.getNextZipEntry();
             assertNotNull(e);
             assertEquals("test1.xml", e.getName());
@@ -341,7 +350,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
      */
     @Test
     public void testProperUseOfInflater() throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-189.zip"))) {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile("COMPRESS-189.zip")).get()) {
             final ZipArchiveEntry zae = zf.getEntry("USD0558682-20080101.ZIP");
             try (ZipArchiveInputStream in = new ZipArchiveInputStream(new BufferedInputStream(zf.getInputStream(zae)))) {
                 ZipArchiveEntry innerEntry;
@@ -359,12 +368,10 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
      */
     @Test
     public void testReadDeflate64CompressedStream() throws Exception {
-        final File input = getFile("COMPRESS-380/COMPRESS-380-input");
+        final byte[] orig = readAllBytes("COMPRESS-380/COMPRESS-380-input");
         final File archive = getFile("COMPRESS-380/COMPRESS-380.zip");
-        try (InputStream in = Files.newInputStream(input.toPath());
-                ZipArchiveInputStream zin = new ZipArchiveInputStream(Files.newInputStream(archive.toPath()))) {
-            final byte[] orig = IOUtils.toByteArray(in);
-            final ZipArchiveEntry e = zin.getNextZipEntry();
+        try (ZipArchiveInputStream zin = new ZipArchiveInputStream(Files.newInputStream(archive.toPath()))) {
+            assertNotNull(zin.getNextZipEntry());
             final byte[] fromZip = IOUtils.toByteArray(zin);
             assertArrayEquals(orig, fromZip);
         }
@@ -467,14 +474,14 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
 
     @Test
     public void testSingleByteReadThrowsAtEofForCorruptedStoredEntry() throws Exception {
-        final byte[] content = Files.readAllBytes(getFile("COMPRESS-264.zip").toPath());
+        final byte[] content = readAllBytes("COMPRESS-264.zip");
         // make size much bigger than entry's real size
         for (int i = 17; i < 26; i++) {
             content[i] = (byte) 0xff;
         }
         try (ByteArrayInputStream in = new ByteArrayInputStream(content);
                 ZipArchiveInputStream archive = new ZipArchiveInputStream(in)) {
-            final ArchiveEntry e = archive.getNextEntry();
+            assertNotNull(archive.getNextEntry());
             final IOException ex1 = assertThrows(IOException.class, () -> IOUtils.toByteArray(archive), "expected exception");
             assertEquals("Truncated ZIP file", ex1.getMessage());
             final IOException ex2 = assertThrows(IOException.class, archive::read, "expected exception");
@@ -489,11 +496,11 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_winrar/split_zip_created_by_winrar.zip");
         try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
                 InputStream inputStream = Channels.newInputStream(channel);
-                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, CharsetNames.UTF_8, true, false, true)) {
+                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, StandardCharsets.UTF_8.name(), true, false, true)) {
 
             final File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_winrar/zip_to_compare_created_by_winrar.zip");
-            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare.toPath()), CharsetNames.UTF_8,
-                    true, false, true)) {
+            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare.toPath()),
+                    StandardCharsets.UTF_8.name(), true, false, true)) {
 
                 ArchiveEntry entry;
                 while ((entry = splitInputStream.getNextEntry()) != null && inputStreamToCompare.getNextEntry() != null) {
@@ -511,10 +518,10 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
         try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
                 InputStream inputStream = Channels.newInputStream(channel);
-                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, CharsetNames.UTF_8, true, false, true)) {
+                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, StandardCharsets.UTF_8.name(), true, false, true)) {
 
-            final File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip.zip");
-            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare.toPath()), CharsetNames.UTF_8,
+            final Path fileToCompare = getPath("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip.zip");
+            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare), StandardCharsets.UTF_8.name(),
                     true, false, true)) {
 
                 ArchiveEntry entry;
@@ -533,10 +540,10 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip_zip64.zip");
         try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
                 InputStream inputStream = Channels.newInputStream(channel);
-                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, CharsetNames.UTF_8, true, false, true)) {
+                ZipArchiveInputStream splitInputStream = new ZipArchiveInputStream(inputStream, StandardCharsets.UTF_8.name(), true, false, true)) {
 
-            final File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip_zip64.zip");
-            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare.toPath()), CharsetNames.UTF_8,
+            final Path fileToCompare = getPath("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip_zip64.zip");
+            try (ZipArchiveInputStream inputStreamToCompare = new ZipArchiveInputStream(Files.newInputStream(fileToCompare), StandardCharsets.UTF_8.name(),
                     true, false, true)) {
 
                 ArchiveEntry entry;
@@ -553,8 +560,8 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testSplitZipCreatedByZipThrowsException() throws IOException {
         final File zipSplitFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        try (ZipArchiveInputStream inputStream = new ZipArchiveInputStream(Files.newInputStream(zipSplitFile.toPath()), CharsetNames.UTF_8, true, false,
-                true)) {
+        try (ZipArchiveInputStream inputStream = new ZipArchiveInputStream(Files.newInputStream(zipSplitFile.toPath()), StandardCharsets.UTF_8.name(), true,
+                false, true)) {
 
             assertThrows(EOFException.class, () -> {
                 ArchiveEntry entry = inputStream.getNextEntry();
@@ -570,16 +577,16 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
      */
     @Test
     public void testThrowOnInvalidEntry() throws Exception {
-        try (final ZipArchiveInputStream zip = new ZipArchiveInputStream(ZipArchiveInputStreamTest.class.getResourceAsStream("/invalid-zip.zip"))) {
+        try (ZipArchiveInputStream zip = new ZipArchiveInputStream(ZipArchiveInputStreamTest.class.getResourceAsStream("/invalid-zip.zip"))) {
             final ZipException expected = assertThrows(ZipException.class, zip::getNextZipEntry, "IOException expected");
-            assertTrue(expected.getMessage().contains("Unexpected record signature"));
+            assertTrue(expected.getMessage().contains("Cannot find zip signature"));
         }
     }
 
     @Test
     public void testThrowsIfStoredDDIsDifferentFromLengthRead() throws IOException {
         try (InputStream fs = newInputStream("bla-stored-dd-contradicts-actualsize.zip");
-                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, CharsetNames.UTF_8, true, true)) {
+                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, StandardCharsets.UTF_8.name(), true, true)) {
             final ZipArchiveEntry e = archive.getNextZipEntry();
             assertNotNull(e);
             assertEquals("test1.xml", e.getName());
@@ -592,7 +599,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testThrowsIfStoredDDIsInconsistent() throws IOException {
         try (InputStream fs = newInputStream("bla-stored-dd-sizes-differ.zip");
-                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, CharsetNames.UTF_8, true, true)) {
+                ZipArchiveInputStream archive = new ZipArchiveInputStream(fs, StandardCharsets.UTF_8.name(), true, true)) {
             final ZipArchiveEntry e = archive.getNextZipEntry();
             assertNotNull(e);
             assertEquals("test1.xml", e.getName());
@@ -649,9 +656,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
                 assertTrue(in.canReadEntryData(entry));
             }
 
-            try (InputStream original = newInputStream("test2.xml")) {
-                assertArrayEquals(IOUtils.toByteArray(original), IOUtils.toByteArray(in));
-            }
+            assertArrayEquals(readAllBytes("test2.xml"), IOUtils.toByteArray(in));
         }
     }
 
@@ -661,8 +666,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         try (ZipArchiveInputStream in = new ZipArchiveInputStream(newInputStream("bzip2-zip.zip"))) {
             final ZipArchiveEntry ze = in.getNextZipEntry();
             assertEquals(42, ze.getSize());
-            final byte[] expected = new byte[42];
-            Arrays.fill(expected, (byte) 'a');
+            final byte[] expected = ArrayFill.fill(new byte[42], (byte) 'a');
             assertArrayEquals(expected, IOUtils.toByteArray(in));
         }
     }
@@ -687,7 +691,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     public void testWithBytesAfterData() throws Exception {
         final int expectedNumEntries = 2;
         try (InputStream is = ZipArchiveInputStreamTest.class.getResourceAsStream("/archive_with_bytes_after_data.zip");
-                final ZipArchiveInputStream zip = new ZipArchiveInputStream(is)) {
+                ZipArchiveInputStream zip = new ZipArchiveInputStream(is)) {
             int actualNumEntries = 0;
             ZipArchiveEntry zae = zip.getNextZipEntry();
             while (zae != null) {
@@ -702,7 +706,7 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
     @Test
     public void testZipUsingStoredWithDDAndNoDDSignature() throws IOException {
         try (InputStream inputStream = forgeZipInputStream();
-                ZipArchiveInputStream zipInputStream = new ZipArchiveInputStream(inputStream, CharsetNames.UTF_8, true, true)) {
+                ZipArchiveInputStream zipInputStream = new ZipArchiveInputStream(inputStream, StandardCharsets.UTF_8.name(), true, true)) {
             getAllZipEntries(zipInputStream);
         }
     }
@@ -715,18 +719,66 @@ public class ZipArchiveInputStreamTest extends AbstractTest {
         }
     }
 
+    @Test
+    public void testZipWithLongerBeginningGarbage() throws IOException {
+        final Path path = createTempPath("preamble", ".zip");
+
+        try (OutputStream fos = Files.newOutputStream(path)) {
+            fos.write("#!/usr/bin/env some-program with quite a few arguments to make it longer than the local header\n".getBytes(StandardCharsets.UTF_8));
+            try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(fos)) {
+                final ZipArchiveEntry entry = new ZipArchiveEntry("file-1.txt");
+                entry.setMethod(ZipEntry.DEFLATED);
+                zos.putArchiveEntry(entry);
+                zos.write("entry-content\n".getBytes(StandardCharsets.UTF_8));
+                zos.closeArchiveEntry();
+            }
+        }
+
+        try (InputStream is = Files.newInputStream(path);
+                ZipArchiveInputStream zis = new ZipArchiveInputStream(is)) {
+            final ZipArchiveEntry entry = zis.getNextEntry();
+            assertEquals("file-1.txt", entry.getName());
+            final byte[] content = IOUtils.toByteArray(zis);
+            assertArrayEquals("entry-content\n".getBytes(StandardCharsets.UTF_8), content);
+        }
+    }
+
+    @Test
+    public void testZipWithShortBeginningGarbage() throws IOException {
+        final Path path = createTempPath("preamble", ".zip");
+
+        try (OutputStream fos = Files.newOutputStream(path)) {
+            fos.write("#!/usr/bin/unzip\n".getBytes(StandardCharsets.UTF_8));
+            try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(fos)) {
+                final ZipArchiveEntry entry = new ZipArchiveEntry("file-1.txt");
+                entry.setMethod(ZipEntry.DEFLATED);
+                zos.putArchiveEntry(entry);
+                zos.write("entry-content\n".getBytes(StandardCharsets.UTF_8));
+                zos.closeArchiveEntry();
+            }
+        }
+
+        try (InputStream is = Files.newInputStream(path);
+                ZipArchiveInputStream zis = new ZipArchiveInputStream(is)) {
+            final ZipArchiveEntry entry = zis.getNextEntry();
+            assertEquals("file-1.txt", entry.getName());
+            final byte[] content = IOUtils.toByteArray(zis);
+            assertArrayEquals("entry-content\n".getBytes(StandardCharsets.UTF_8), content);
+        }
+    }
+
     @ParameterizedTest
     @ValueSource(booleans = { true, false })
     public void zipInputStream(final boolean allowStoredEntriesWithDataDescriptor) {
-        try (ZipArchiveInputStream zIn = new ZipArchiveInputStream(
-                Files.newInputStream(Paths.get("src/test/resources/COMPRESS-647/test.zip")), CharsetNames.UTF_8, false,
-                allowStoredEntriesWithDataDescriptor)) {
+        try (ZipArchiveInputStream zIn = new ZipArchiveInputStream(Files.newInputStream(Paths.get("src/test/resources/COMPRESS-647/test.zip")),
+                StandardCharsets.UTF_8.name(), false, allowStoredEntriesWithDataDescriptor)) {
             ZipArchiveEntry zae = zIn.getNextEntry();
             while (zae != null) {
                 zae = zIn.getNextEntry();
             }
-        } catch (IOException e) {
+        } catch (final IOException e) {
             // Ignore expected exception
         }
     }
+
 }
