@@ -23,18 +23,29 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.Enumeration;
 
 import org.apache.commons.compress.AbstractTest;
-import org.apache.commons.compress.utils.CharsetNames;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
 
 public class ZipFileIgnoringLocalFileHeaderTest {
 
-    private static ZipFile openZipWithoutLFH(final String fileName) throws IOException {
-        return new ZipFile(AbstractTest.getFile(fileName), CharsetNames.UTF_8, true, true);
+    private static ZipFile openZipWithoutLocalFileHeader(final String fileName) throws IOException {
+        // @formatter:off
+        return ZipFile.builder()
+                .setFile(AbstractTest.getFile(fileName))
+                .setCharset(StandardCharsets.UTF_8.name())
+                .setUseUnicodeExtraFields(true)
+                .setIgnoreLocalFileHeader(true)
+                .get();
+        // @formatter:on
+    }
+
+    private static ZipFile openZipWithoutLocalFileHeaderDeprecated(final String fileName) throws IOException {
+        return new ZipFile(AbstractTest.getFile(fileName), StandardCharsets.UTF_8.name(), true, true);
     }
 
     @TempDir
@@ -42,7 +53,7 @@ public class ZipFileIgnoringLocalFileHeaderTest {
 
     @Test
     public void testDuplicateEntry() throws Exception {
-        try (final ZipFile zf = openZipWithoutLFH("COMPRESS-227.zip")) {
+        try (ZipFile zf = openZipWithoutLocalFileHeader("COMPRESS-227.zip")) {
             int numberOfEntries = 0;
             for (final ZipArchiveEntry entry : zf.getEntries("test1.txt")) {
                 numberOfEntries++;
@@ -56,7 +67,7 @@ public class ZipFileIgnoringLocalFileHeaderTest {
 
     @Test
     public void testGetEntryWorks() throws IOException {
-        try (final ZipFile zf = openZipWithoutLFH("bla.zip")) {
+        try (ZipFile zf = openZipWithoutLocalFileHeader("bla.zip")) {
             final ZipArchiveEntry ze = zf.getEntry("test1.xml");
             assertEquals(610, ze.getSize());
         }
@@ -64,7 +75,7 @@ public class ZipFileIgnoringLocalFileHeaderTest {
 
     @Test
     public void testGetRawInputStreamReturnsNotNull() throws IOException {
-        try (final ZipFile zf = openZipWithoutLFH("bla.zip")) {
+        try (ZipFile zf = openZipWithoutLocalFileHeader("bla.zip")) {
             final ZipArchiveEntry ze = zf.getEntry("test1.xml");
             try (InputStream rawInputStream = zf.getRawInputStream(ze)) {
                 assertNotNull(rawInputStream);
@@ -74,7 +85,7 @@ public class ZipFileIgnoringLocalFileHeaderTest {
 
     @Test
     public void testPhysicalOrder() throws IOException {
-        try (final ZipFile zf = openZipWithoutLFH("ordertest.zip")) {
+        try (ZipFile zf = openZipWithoutLocalFileHeader("ordertest.zip")) {
             final Enumeration<ZipArchiveEntry> e = zf.getEntriesInPhysicalOrder();
             ZipArchiveEntry ze;
             do {
@@ -86,11 +97,12 @@ public class ZipFileIgnoringLocalFileHeaderTest {
 
     /**
      * Simple unarchive test. Asserts nothing.
+     *
      * @throws Exception
      */
     @Test
     public void testZipUnarchive() throws Exception {
-        try (final ZipFile zf = openZipWithoutLFH("bla.zip")) {
+        try (ZipFile zf = openZipWithoutLocalFileHeaderDeprecated("bla.zip")) {
             for (final Enumeration<ZipArchiveEntry> e = zf.getEntries(); e.hasMoreElements();) {
                 final ZipArchiveEntry entry = e.nextElement();
                 try (InputStream inputStream = zf.getInputStream(entry)) {
