@@ -35,7 +35,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.channels.SeekableByteChannel;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -53,10 +55,10 @@ import java.util.zip.ZipEntry;
 
 import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.utils.ByteUtils;
-import org.apache.commons.compress.utils.CharsetNames;
-import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
+import org.apache.commons.io.IOUtils;
 import org.apache.commons.io.function.IORunnable;
+import org.apache.commons.lang3.ArrayFill;
 import org.apache.commons.lang3.SystemUtils;
 import org.junit.Assume;
 import org.junit.jupiter.api.AfterEach;
@@ -73,7 +75,7 @@ public class ZipFileTest extends AbstractTest {
     }
 
     private static void nameSource(final String archive, final String entry, final ZipArchiveEntry.NameSource expected) throws Exception {
-        try (ZipFile zf = new ZipFile(getFile(archive))) {
+        try (ZipFile zf = ZipFile.builder().setFile(getFile(archive)).get()) {
             final ZipArchiveEntry ze = zf.getEntry(entry);
             assertEquals(entry, ze.getName());
             assertEquals(expected, ze.getNameSource());
@@ -142,8 +144,8 @@ public class ZipFileTest extends AbstractTest {
     private void assertFileEqualsToEntry(final File fileToCompare, final ZipArchiveEntry entry, final ZipFile zipFile) throws IOException {
         final byte[] buffer = new byte[10240];
         final File tempFile = createTempFile("temp", "txt");
-        try (final OutputStream outputStream = Files.newOutputStream(tempFile.toPath());
-                final InputStream inputStream = zipFile.getInputStream(entry)) {
+        try (OutputStream outputStream = Files.newOutputStream(tempFile.toPath());
+                InputStream inputStream = zipFile.getInputStream(entry)) {
             int readLen;
             while ((readLen = inputStream.read(buffer)) > 0) {
                 outputStream.write(buffer, 0, readLen);
@@ -160,7 +162,7 @@ public class ZipFileTest extends AbstractTest {
 
     private void multiByteReadConsistentlyReturnsMinusOneAtEof(final File file) throws Exception {
         final byte[] buf = new byte[2];
-        try (ZipFile archive = new ZipFile(file)) {
+        try (ZipFile archive = ZipFile.builder().setFile(file).get()) {
             final ZipArchiveEntry e = archive.getEntries().nextElement();
             try (InputStream is = archive.getInputStream(e)) {
                 IOUtils.toByteArray(is);
@@ -179,8 +181,7 @@ public class ZipFileTest extends AbstractTest {
      * The central directory has ZipFile and ZipUtil swapped so central directory order is different from entry data order.
      */
     private void readOrderTest() throws Exception {
-        final File archive = getFile("ordertest.zip");
-        zf = new ZipFile(archive);
+        zf = ZipFile.builder().setFile(getFile("ordertest.zip")).get();
     }
 
     /**
@@ -195,7 +196,7 @@ public class ZipFileTest extends AbstractTest {
     }
 
     private void singleByteReadConsistentlyReturnsMinusOneAtEof(final File file) throws Exception {
-        try (ZipFile archive = new ZipFile(file)) {
+        try (ZipFile archive = ZipFile.builder().setFile(file).get();) {
             final ZipArchiveEntry e = archive.getEntries().nextElement();
             try (InputStream is = archive.getInputStream(e)) {
                 IOUtils.toByteArray(is);
@@ -213,66 +214,49 @@ public class ZipFileTest extends AbstractTest {
     @Test
     public void testCDOrder() throws Exception {
         readOrderTest();
-        final ArrayList<ZipArchiveEntry> l = Collections.list(zf.getEntries());
-        assertEntryName(l, 0, "AbstractUnicodeExtraField");
-        assertEntryName(l, 1, "AsiExtraField");
-        assertEntryName(l, 2, "ExtraFieldUtils");
-        assertEntryName(l, 3, "FallbackZipEncoding");
-        assertEntryName(l, 4, "GeneralPurposeBit");
-        assertEntryName(l, 5, "JarMarker");
-        assertEntryName(l, 6, "NioZipEncoding");
-        assertEntryName(l, 7, "Simple8BitZipEncoding");
-        assertEntryName(l, 8, "UnicodeCommentExtraField");
-        assertEntryName(l, 9, "UnicodePathExtraField");
-        assertEntryName(l, 10, "UnixStat");
-        assertEntryName(l, 11, "UnparseableExtraFieldData");
-        assertEntryName(l, 12, "UnrecognizedExtraField");
-        assertEntryName(l, 13, "ZipArchiveEntry");
-        assertEntryName(l, 14, "ZipArchiveInputStream");
-        assertEntryName(l, 15, "ZipArchiveOutputStream");
-        assertEntryName(l, 16, "ZipEncoding");
-        assertEntryName(l, 17, "ZipEncodingHelper");
-        assertEntryName(l, 18, "ZipExtraField");
-        assertEntryName(l, 19, "ZipUtil");
-        assertEntryName(l, 20, "ZipLong");
-        assertEntryName(l, 21, "ZipShort");
-        assertEntryName(l, 22, "ZipFile");
+        testCDOrderInMemory();
     }
 
     @Test
     public void testCDOrderInMemory() throws Exception {
-        byte[] data;
-        try (InputStream fis = newInputStream("ordertest.zip")) {
-            data = IOUtils.toByteArray(fis);
-        }
-
+        final byte[] data = readAllBytes("ordertest.zip");
+        zf = ZipFile.builder().setByteArray(data).setCharset(StandardCharsets.UTF_8).get();
+        testCDOrderInMemory(zf);
         try (SeekableInMemoryByteChannel channel = new SeekableInMemoryByteChannel(data)) {
-            zf = new ZipFile(channel, CharsetNames.UTF_8);
-            final ArrayList<ZipArchiveEntry> l = Collections.list(zf.getEntries());
-            assertEntryName(l, 0, "AbstractUnicodeExtraField");
-            assertEntryName(l, 1, "AsiExtraField");
-            assertEntryName(l, 2, "ExtraFieldUtils");
-            assertEntryName(l, 3, "FallbackZipEncoding");
-            assertEntryName(l, 4, "GeneralPurposeBit");
-            assertEntryName(l, 5, "JarMarker");
-            assertEntryName(l, 6, "NioZipEncoding");
-            assertEntryName(l, 7, "Simple8BitZipEncoding");
-            assertEntryName(l, 8, "UnicodeCommentExtraField");
-            assertEntryName(l, 9, "UnicodePathExtraField");
-            assertEntryName(l, 10, "UnixStat");
-            assertEntryName(l, 11, "UnparseableExtraFieldData");
-            assertEntryName(l, 12, "UnrecognizedExtraField");
-            assertEntryName(l, 13, "ZipArchiveEntry");
-            assertEntryName(l, 14, "ZipArchiveInputStream");
-            assertEntryName(l, 15, "ZipArchiveOutputStream");
-            assertEntryName(l, 16, "ZipEncoding");
-            assertEntryName(l, 17, "ZipEncodingHelper");
-            assertEntryName(l, 18, "ZipExtraField");
-            assertEntryName(l, 19, "ZipUtil");
-            assertEntryName(l, 20, "ZipLong");
-            assertEntryName(l, 21, "ZipShort");
-            assertEntryName(l, 22, "ZipFile");
+            zf = ZipFile.builder().setSeekableByteChannel(channel).setCharset(StandardCharsets.UTF_8).get();
+            testCDOrderInMemory(zf);
         }
+        try (SeekableInMemoryByteChannel channel = new SeekableInMemoryByteChannel(data)) {
+            zf = new ZipFile(channel, StandardCharsets.UTF_8.name());
+            testCDOrderInMemory(zf);
+        }
+    }
+
+    private void testCDOrderInMemory(final ZipFile zipFile) {
+        final ArrayList<ZipArchiveEntry> list = Collections.list(zipFile.getEntries());
+        assertEntryName(list, 0, "AbstractUnicodeExtraField");
+        assertEntryName(list, 1, "AsiExtraField");
+        assertEntryName(list, 2, "ExtraFieldUtils");
+        assertEntryName(list, 3, "FallbackZipEncoding");
+        assertEntryName(list, 4, "GeneralPurposeBit");
+        assertEntryName(list, 5, "JarMarker");
+        assertEntryName(list, 6, "NioZipEncoding");
+        assertEntryName(list, 7, "Simple8BitZipEncoding");
+        assertEntryName(list, 8, "UnicodeCommentExtraField");
+        assertEntryName(list, 9, "UnicodePathExtraField");
+        assertEntryName(list, 10, "UnixStat");
+        assertEntryName(list, 11, "UnparseableExtraFieldData");
+        assertEntryName(list, 12, "UnrecognizedExtraField");
+        assertEntryName(list, 13, "ZipArchiveEntry");
+        assertEntryName(list, 14, "ZipArchiveInputStream");
+        assertEntryName(list, 15, "ZipArchiveOutputStream");
+        assertEntryName(list, 16, "ZipEncoding");
+        assertEntryName(list, 17, "ZipEncodingHelper");
+        assertEntryName(list, 18, "ZipExtraField");
+        assertEntryName(list, 19, "ZipUtil");
+        assertEntryName(list, 20, "ZipLong");
+        assertEntryName(list, 21, "ZipShort");
+        assertEntryName(list, 22, "ZipFile");
     }
 
     @Test
@@ -283,7 +267,7 @@ public class ZipFileTest extends AbstractTest {
 
         final Map<String, byte[]> content = new HashMap<>();
         for (final ZipArchiveEntry entry : Collections.list(zf.getEntries())) {
-            try (final InputStream inputStream = zf.getInputStream(entry)) {
+            try (InputStream inputStream = zf.getInputStream(entry)) {
                 content.put(entry.getName(), IOUtils.toByteArray(inputStream));
             }
         }
@@ -311,8 +295,8 @@ public class ZipFileTest extends AbstractTest {
         try (InputStream fis = newInputStream("mixed.zip")) {
             data = IOUtils.toByteArray(fis);
         }
-        try (final SeekableInMemoryByteChannel channel = new SeekableInMemoryByteChannel(data)) {
-            zf = new ZipFile(channel, CharsetNames.UTF_8);
+        try (SeekableInMemoryByteChannel channel = new SeekableInMemoryByteChannel(data)) {
+            zf = ZipFile.builder().setSeekableByteChannel(channel).setCharset(StandardCharsets.UTF_8).get();
 
             final Map<String, byte[]> content = new HashMap<>();
             for (final ZipArchiveEntry entry : Collections.list(zf.getEntries())) {
@@ -362,7 +346,7 @@ public class ZipFileTest extends AbstractTest {
 
         }
 
-        try (ZipFile zf = new ZipFile(new SeekableInMemoryByteChannel(zipContent.toByteArray()))) {
+        try (ZipFile zf = ZipFile.builder().setByteArray(zipContent.toByteArray()).get()) {
             final ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
             assertNotEquals(-1L, inflatedEntry.getLocalHeaderOffset());
             assertNotEquals(-1L, inflatedEntry.getDataOffset());
@@ -447,7 +431,7 @@ public class ZipFileTest extends AbstractTest {
 
             }
 
-            try (ZipFile zf = new ZipFile(new SeekableInMemoryByteChannel(Arrays.copyOfRange(zipContent.array(), 0, (int) zipContent.size())))) {
+            try (ZipFile zf = ZipFile.builder().setByteArray(Arrays.copyOfRange(zipContent.array(), 0, (int) zipContent.size())).get()) {
                 final ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
                 final ResourceAlignmentExtraField inflatedAlignmentEx = (ResourceAlignmentExtraField) inflatedEntry
                         .getExtraField(ResourceAlignmentExtraField.ID);
@@ -528,8 +512,8 @@ public class ZipFileTest extends AbstractTest {
     @Test
     public void testExtractFileLiesAcrossSplitZipSegmentsCreatedByWinrar() throws Exception {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_winrar/split_zip_created_by_winrar.zip");
-        try (final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
-            zf = new ZipFile(channel);
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
+            zf = ZipFile.builder().setSeekableByteChannel(channel).get();
 
             // the compressed content of ZipArchiveInputStream.java lies between .z01 and .z02
             final ZipArchiveEntry zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/archivers/zip/ZipArchiveInputStream.java");
@@ -541,7 +525,7 @@ public class ZipFileTest extends AbstractTest {
     @Test
     public void testExtractFileLiesAcrossSplitZipSegmentsCreatedByZip() throws Exception {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
-        try (final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
             zf = new ZipFile(channel);
 
             // the compressed content of UnsupportedCompressionAlgorithmException.java lies between .z01 and .z02
@@ -560,7 +544,7 @@ public class ZipFileTest extends AbstractTest {
     @Test
     public void testExtractFileLiesAcrossSplitZipSegmentsCreatedByZipOfZip64() throws Exception {
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip_zip64.zip");
-        try (final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile)) {
             zf = new ZipFile(channel);
 
             // the compressed content of UnsupportedCompressionAlgorithmException.java lies between .z01 and .z02
@@ -825,7 +809,7 @@ public class ZipFileTest extends AbstractTest {
             }
 
             try (InputStream inputStream = Files.newInputStream(extractedFile.toPath())) {
-                bytesRead = IOUtils.readFully(inputStream, buffer);
+                bytesRead = org.apache.commons.compress.utils.IOUtils.readFully(inputStream, buffer);
                 assertEquals(testData.length, bytesRead);
                 assertArrayEquals(testData, Arrays.copyOfRange(buffer, 0, bytesRead));
             }
@@ -836,15 +820,17 @@ public class ZipFileTest extends AbstractTest {
     }
 
     @Test
-    public void testSetLevelTooBigForZipArchiveOutputStream() {
-        final ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream());
-        assertThrows(IllegalArgumentException.class, () -> fixture.setLevel(Deflater.BEST_COMPRESSION + 1));
+    public void testSetLevelTooBigForZipArchiveOutputStream() throws IOException {
+        try (ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream())) {
+            assertThrows(IllegalArgumentException.class, () -> fixture.setLevel(Deflater.BEST_COMPRESSION + 1));
+        }
     }
 
     @Test
-    public void testSetLevelTooSmallForZipArchiveOutputStream() {
-        final ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream());
+    public void testSetLevelTooSmallForZipArchiveOutputStream() throws IOException {
+        try (ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream())) {
         assertThrows(IllegalArgumentException.class, () -> fixture.setLevel(Deflater.DEFAULT_COMPRESSION - 1));
+        }
     }
 
     @Test
@@ -890,9 +876,11 @@ public class ZipFileTest extends AbstractTest {
 
     @Test
     public void testThrowsExceptionWhenWritingPreamble() throws IOException {
-        final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(new ByteArrayOutputStream());
-        outputStream.putArchiveEntry(new ZipArchiveEntry());
-        assertThrows(IllegalStateException.class, () -> outputStream.writePreamble(ByteUtils.EMPTY_BYTE_ARRAY));
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(new ByteArrayOutputStream())) {
+            outputStream.putArchiveEntry(new ZipArchiveEntry());
+            assertThrows(IllegalStateException.class, () -> outputStream.writePreamble(ByteUtils.EMPTY_BYTE_ARRAY));
+            outputStream.closeArchiveEntry();
+        }
     }
 
     @Test
@@ -956,8 +944,7 @@ public class ZipFileTest extends AbstractTest {
         zf = new ZipFile(archive);
         final ZipArchiveEntry ze = zf.getEntry("lots-of-as");
         assertEquals(42, ze.getSize());
-        final byte[] expected = new byte[42];
-        Arrays.fill(expected, (byte) 'a');
+        final byte[] expected = ArrayFill.fill(new byte[42], (byte) 'a');
         try (InputStream inputStream = zf.getInputStream(ze)) {
             assertArrayEquals(expected, IOUtils.toByteArray(inputStream));
         }
@@ -973,4 +960,29 @@ public class ZipFileTest extends AbstractTest {
         assertNull(zf.getEntry("\u00e4\\\u00fc.txt"));
         assertNotNull(zf.getEntry("\u00e4/\u00fc.txt"));
     }
+
+    @Test
+    public void testZipWithShortBeginningGarbage() throws IOException {
+        final Path path = createTempPath("preamble", ".zip");
+        try (OutputStream fos = Files.newOutputStream(path)) {
+            fos.write("#!/usr/bin/unzip\n".getBytes(StandardCharsets.UTF_8));
+            try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(fos)) {
+                final ZipArchiveEntry entry = new ZipArchiveEntry("file-1.txt");
+                entry.setMethod(ZipEntry.DEFLATED);
+                zos.putArchiveEntry(entry);
+                zos.write("entry-content\n".getBytes(StandardCharsets.UTF_8));
+                zos.closeArchiveEntry();
+            }
+        }
+        try (ZipFile zipFile = ZipFile.builder().setPath(path).get()) {
+            final ZipArchiveEntry entry = zipFile.getEntry("file-1.txt");
+            assertEquals("file-1.txt", entry.getName());
+            try (InputStream inputStream = zipFile.getInputStream(entry)) {
+                final byte[] content = IOUtils.toByteArray(inputStream);
+                assertArrayEquals("entry-content\n".getBytes(StandardCharsets.UTF_8), content);
+            }
+        }
+    }
+
+
 }
