@@ -13,13 +13,12 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers.zip;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.commons.compress.AbstractTestCase.getPath;
+import static org.apache.commons.compress.AbstractTest.getPath;
 import static org.apache.commons.compress.archivers.zip.ZipArchiveEntryRequest.createZipArchiveEntryRequest;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -27,8 +26,10 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.channels.SeekableByteChannel;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.FileSystem;
 import java.nio.file.Files;
 import java.nio.file.Path;
@@ -46,11 +47,13 @@ import java.util.stream.Stream;
 import java.util.zip.Deflater;
 import java.util.zip.ZipEntry;
 
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.archivers.ArchiveException;
 import org.apache.commons.compress.archivers.ArchiveOutputStream;
 import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.parallel.InputStreamSupplier;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.io.file.PathUtils;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -69,8 +72,26 @@ public class ZipMemoryFileSystemTest {
         return () -> payload;
     }
 
+    @BeforeEach
+    public void setup() throws IOException {
+        dir = Files.createTempDirectory(UUID.randomUUID().toString());
+    }
+
+    @AfterEach
+    public void tearDown() throws IOException {
+        try (Stream<Path> walk = Files.walk(dir)) {
+            walk.sorted(Comparator.reverseOrder()).peek(path -> println("Deleting: " + path.toAbsolutePath())).forEach(path -> {
+                try {
+                    Files.deleteIfExists(path);
+                } catch (final IOException ignored) {
+                    // ignored
+                }
+            });
+        }
+    }
+
     @Test
-    public void forPathsReturnCorrectClassInMemory() throws IOException {
+    public void testForPathsReturnCorrectClassInMemory() throws IOException {
         final Path firstFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
         final Path secondFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
         final Path lastFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
@@ -85,22 +106,21 @@ public class ZipMemoryFileSystemTest {
             list.add(firstFile);
             list.add(secondFile);
 
-            SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(lastFile, list);
-            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+            try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(lastFile, list)) {
+                assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+            }
 
-            channel = ZipSplitReadOnlySeekableByteChannel.forPaths(firstFile, secondFile, lastFile);
-            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+            try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(firstFile, secondFile, lastFile)) {
+                assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+            }
         }
     }
 
     @Test
-    public void positionToSomeZipSplitSegmentInMemory() throws IOException {
-        final Path firstFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        final Path secondFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
-        final Path lastFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
-        final byte[] firstBytes = Files.readAllBytes(firstFile);
-        final byte[] secondBytes = Files.readAllBytes(secondFile);
-        final byte[] lastBytes = Files.readAllBytes(lastFile);
+    public void testPositionToSomeZipSplitSegmentInMemory() throws IOException {
+        final byte[] firstBytes = AbstractTest.readAllBytes("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        final byte[] secondBytes = AbstractTest.readAllBytes("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
+        final byte[] lastBytes = AbstractTest.readAllBytes("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
         final int firstFileSize = firstBytes.length;
         final int secondFileSize = secondBytes.length;
         final int lastFileSize = lastBytes.length;
@@ -114,190 +134,215 @@ public class ZipMemoryFileSystemTest {
             final int randomDiskNumber = random.nextInt(3);
             final int randomOffset = randomDiskNumber < 2 ? random.nextInt(firstFileSize) : random.nextInt(lastFileSize);
 
-            final ZipSplitReadOnlySeekableByteChannel channel = (ZipSplitReadOnlySeekableByteChannel)
-                    ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastMemoryPath);
-            channel.position(randomDiskNumber, randomOffset);
-            long expectedPosition = randomOffset;
+            try (ZipSplitReadOnlySeekableByteChannel channel = (ZipSplitReadOnlySeekableByteChannel) ZipSplitReadOnlySeekableByteChannel
+                    .buildFromLastSplitSegment(lastMemoryPath)) {
+                channel.position(randomDiskNumber, randomOffset);
+                long expectedPosition = randomOffset;
 
-            expectedPosition += randomDiskNumber > 0 ? firstFileSize : 0;
-            expectedPosition += randomDiskNumber > 1 ? secondFileSize : 0;
+                expectedPosition += randomDiskNumber > 0 ? firstFileSize : 0;
+                expectedPosition += randomDiskNumber > 1 ? secondFileSize : 0;
 
-            assertEquals(expectedPosition, channel.position());
+                assertEquals(expectedPosition, channel.position());
+            }
         }
 
     }
 
     @Test
-    public void scatterFileInMemory() throws IOException {
+    public void testScatterFileInMemory() throws IOException {
+        final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
+        final byte[] A_PAYLOAD = "XAAY".getBytes();
+        final Path target = Files.createTempFile(dir, "scattertest", ".zip");
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path scatterFile = fileSystem.getPath("scattertest.notzip");
-            final ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile);
-            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
-            final byte[] A_PAYLOAD = "XAAY".getBytes();
+            try (ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile)) {
 
-            final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
-            zab.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
+                final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
+                zab.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
 
-            final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
-            zae.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
+                final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
+                zae.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
 
-            final Path target = Files.createTempFile(dir, "scattertest", ".zip");
-            final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target);
-            scatterZipOutputStream.writeTo(outputStream);
-            outputStream.close();
-            scatterZipOutputStream.close();
+                try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target)) {
+                    scatterZipOutputStream.writeTo(outputStream);
+                }
+            }
 
-            final ZipFile zf = new ZipFile(target.toFile());
-            final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
-            assertEquals(8, b_entry.getSize());
-            assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(b_entry)));
-
-            final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
-            assertEquals(4, a_entry.getSize());
-            assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(a_entry)));
-            zf.close();
-        }
-
-    }
-
-    @Test
-    public void scatterFileWithCompressionAndTargetInMemory() throws IOException {
-        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
-            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
-            final ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile,
-                    Deflater.BEST_COMPRESSION);
-            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
-            final byte[] A_PAYLOAD = "XAAY".getBytes();
-
-            final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
-            zab.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
-
-            final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
-            zae.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
-
-            final Path target = fileSystem.getPath("scattertest.zip");
-            final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target);
-            scatterZipOutputStream.writeTo(outputStream);
-            outputStream.close();
-            scatterZipOutputStream.close();
-
-            try (final ZipFile zf = new ZipFile(Files.newByteChannel(target, StandardOpenOption.READ),
-                    target.getFileName().toString(), ZipEncodingHelper.UTF8, true)) {
+            try (ZipFile zf = ZipFile.builder().setPath(target).get()) {
                 final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
                 assertEquals(8, b_entry.getSize());
-                assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(b_entry)));
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
 
                 final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
                 assertEquals(4, a_entry.getSize());
-                assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(a_entry)));
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+            }
+        } finally {
+            PathUtils.delete(target);
+        }
+    }
+
+    @Test
+    public void testScatterFileWithCompressionAndTargetInMemory() throws IOException {
+        final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
+        final byte[] A_PAYLOAD = "XAAY".getBytes();
+        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
+            final Path target = fileSystem.getPath("scattertest.zip");
+            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
+            try (ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile, Deflater.BEST_COMPRESSION)) {
+
+                final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
+                zab.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
+
+                final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
+                zae.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
+
+                try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target)) {
+                    scatterZipOutputStream.writeTo(outputStream);
+                }
+            }
+            try (ZipFile zf = ZipFile.builder().setPath(target).get()) {
+                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
+                assertEquals(8, b_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+
+                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
+                assertEquals(4, a_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+            }
+
+            try (ZipFile zf = new ZipFile(Files.newByteChannel(target, StandardOpenOption.READ), target.getFileName().toString(), StandardCharsets.UTF_8.name(),
+                    true)) {
+                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
+                assertEquals(8, b_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+
+                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
+                assertEquals(4, a_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+            }
+
+            try (ZipFile zf = new ZipFile(Files.newByteChannel(target, StandardOpenOption.READ), target.getFileName().toString(), StandardCharsets.UTF_8.name(),
+                    true, false)) {
+                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
+                assertEquals(8, b_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+
+                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
+                assertEquals(4, a_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+            }
+
+        }
+    }
+
+    @Test
+    public void testScatterFileWithCompressionInMemory() throws IOException {
+        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
+            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
+            final Path target = Files.createTempFile(dir, "scattertest", ".zip");
+            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
+            final byte[] A_PAYLOAD = "XAAY".getBytes();
+            try (ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile, Deflater.BEST_COMPRESSION)) {
+
+                final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
+                zab.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
+
+                final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
+                zae.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
+
+                try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target)) {
+                    scatterZipOutputStream.writeTo(outputStream);
+                }
+            }
+
+            try (ZipFile zf = ZipFile.builder().setPath(target).get()) {
+                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
+                assertEquals(8, b_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+
+                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
+                assertEquals(4, a_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+            }
+        }
+
+    }
+
+    @Test
+    public void testZipFileInMemory() throws IOException {
+        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
+            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
+            final Path target = fileSystem.getPath("scattertest.zip");
+            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
+            final byte[] A_PAYLOAD = "XAAY".getBytes();
+            try (ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile, Deflater.BEST_COMPRESSION)) {
+
+                final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
+                zab.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
+
+                final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
+                zae.setMethod(ZipEntry.DEFLATED);
+                final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
+                scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
+
+                try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target)) {
+                    scatterZipOutputStream.writeTo(outputStream);
+                }
+            }
+
+            try (ZipFile zf = new ZipFile(target)) {
+                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
+                assertEquals(8, b_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(b_entry)) {
+                    assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
+
+                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
+                assertEquals(4, a_entry.getSize());
+                try (InputStream inputStream = zf.getInputStream(a_entry)) {
+                    assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+                }
             }
         }
     }
 
     @Test
-    public void scatterFileWithCompressionInMemory() throws IOException {
-        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
-            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
-            final ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile,
-                    Deflater.BEST_COMPRESSION);
-            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
-            final byte[] A_PAYLOAD = "XAAY".getBytes();
-
-            final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
-            zab.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
-
-            final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
-            zae.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
-
-            final Path target = Files.createTempFile(dir, "scattertest", ".zip");
-            final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target);
-            scatterZipOutputStream.writeTo(outputStream);
-            outputStream.close();
-            scatterZipOutputStream.close();
-
-            final ZipFile zf = new ZipFile(target.toFile());
-            final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
-            assertEquals(8, b_entry.getSize());
-            assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(b_entry)));
-
-            final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
-            assertEquals(4, a_entry.getSize());
-            assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(a_entry)));
-            zf.close();
-        }
-
-    }
-
-    @BeforeEach
-    public void setup() throws IOException {
-        dir = Files.createTempDirectory(UUID.randomUUID().toString());
-    }
-
-    @AfterEach
-    public void tearDown() throws IOException {
-        try (Stream<Path> walk = Files.walk(dir)) {
-            walk.sorted(Comparator.reverseOrder())
-                    .peek(path -> println("Deleting: " + path.toAbsolutePath()))
-                    .forEach(path -> {
-                        try {
-                            Files.deleteIfExists(path);
-                        } catch (final IOException ignore) {
-                        }
-                    });
-        }
-    }
-
-    @Test
-    public void zipFileInMemory() throws IOException {
-        try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
-            final Path scatterFile = fileSystem.getPath("scattertest.notzip");
-            final ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.pathBased(scatterFile,
-                    Deflater.BEST_COMPRESSION);
-            final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
-            final byte[] A_PAYLOAD = "XAAY".getBytes();
-
-            final ZipArchiveEntry zab = new ZipArchiveEntry("b.txt");
-            zab.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload = new ByteArrayInputStream(B_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zab, createPayloadSupplier(payload)));
-
-            final ZipArchiveEntry zae = new ZipArchiveEntry("a.txt");
-            zae.setMethod(ZipEntry.DEFLATED);
-            final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
-            scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
-
-            final Path target = fileSystem.getPath("scattertest.zip");
-            final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target);
-            scatterZipOutputStream.writeTo(outputStream);
-            outputStream.close();
-            scatterZipOutputStream.close();
-
-            try (final ZipFile zf = new ZipFile(target)) {
-                final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
-                assertEquals(8, b_entry.getSize());
-                assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(b_entry)));
-
-                final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
-                assertEquals(4, a_entry.getSize());
-                assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(a_entry)));
-            }
-        }
-    }
-
-    @Test
-    public void zipFromMemoryFileSystemFile() throws IOException, NoSuchAlgorithmException {
+    public void testZipFromMemoryFileSystemFile() throws IOException, NoSuchAlgorithmException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path textFileInMemSys = fileSystem.getPath("test.txt");
             final byte[] bytes = new byte[100 * 1024];
@@ -305,7 +350,7 @@ public class ZipMemoryFileSystemTest {
             Files.write(textFileInMemSys, bytes);
 
             final Path zipInLocalSys = Files.createTempFile(dir, "commons-compress-memoryfs", ".zip");
-            try (final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys.toFile())) {
+            try (ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys.toFile())) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry(textFileInMemSys, textFileInMemSys.getFileName().toString());
                 entry.setSize(Files.size(textFileInMemSys));
                 zipOut.putArchiveEntry(entry);
@@ -319,14 +364,14 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipFromMemoryFileSystemOutputStream() throws IOException, ArchiveException {
+    public void testZipFromMemoryFileSystemOutputStream() throws IOException, ArchiveException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path p = fileSystem.getPath("test.txt");
             Files.write(p, "Test".getBytes(UTF_8));
 
             final Path f = Files.createTempFile(dir, "commons-compress-memoryfs", ".zip");
-            try (final OutputStream out = Files.newOutputStream(f);
-                 final ArchiveOutputStream zipOut = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.ZIP, out)) {
+            try (OutputStream out = Files.newOutputStream(f);
+                    ArchiveOutputStream<ZipArchiveEntry> zipOut = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.ZIP, out)) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry(p, p.getFileName().toString());
                 entry.setSize(Files.size(p));
                 zipOut.putArchiveEntry(entry);
@@ -339,7 +384,7 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipFromMemoryFileSystemPath() throws IOException, NoSuchAlgorithmException {
+    public void testZipFromMemoryFileSystemPath() throws IOException, NoSuchAlgorithmException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path textFileInMemSys = fileSystem.getPath("test.txt");
             final byte[] bytes = new byte[100 * 1024];
@@ -347,7 +392,7 @@ public class ZipMemoryFileSystemTest {
             Files.write(textFileInMemSys, bytes);
 
             final Path zipInLocalSys = Files.createTempFile(dir, "commons-compress-memoryfs", ".zip");
-            try (final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys)) {
+            try (ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys)) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry(textFileInMemSys, textFileInMemSys.getFileName().toString());
                 entry.setSize(Files.size(textFileInMemSys));
                 zipOut.putArchiveEntry(entry);
@@ -361,7 +406,7 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipFromMemoryFileSystemSeekableByteChannel() throws IOException, NoSuchAlgorithmException {
+    public void testZipFromMemoryFileSystemSeekableByteChannel() throws IOException, NoSuchAlgorithmException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path textFileInMemSys = fileSystem.getPath("test.txt");
             final byte[] bytes = new byte[100 * 1024];
@@ -369,9 +414,9 @@ public class ZipMemoryFileSystemTest {
             Files.write(textFileInMemSys, bytes);
 
             final Path zipInLocalSys = Files.createTempFile(dir, "commons-compress-memoryfs", ".zip");
-            try (final SeekableByteChannel byteChannel = Files.newByteChannel(zipInLocalSys,
+            try (SeekableByteChannel byteChannel = Files.newByteChannel(zipInLocalSys,
                     EnumSet.of(StandardOpenOption.READ, StandardOpenOption.WRITE, StandardOpenOption.TRUNCATE_EXISTING));
-                 final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(byteChannel)) {
+                    ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(byteChannel)) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry(textFileInMemSys, textFileInMemSys.getFileName().toString());
                 entry.setSize(Files.size(textFileInMemSys));
                 zipOut.putArchiveEntry(entry);
@@ -385,7 +430,7 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipFromMemoryFileSystemSplitFile() throws IOException, NoSuchAlgorithmException {
+    public void testZipFromMemoryFileSystemSplitFile() throws IOException, NoSuchAlgorithmException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path textFileInMemSys = fileSystem.getPath("test.txt");
             final byte[] bytes = new byte[100 * 1024];
@@ -393,7 +438,7 @@ public class ZipMemoryFileSystemTest {
             Files.write(textFileInMemSys, bytes);
 
             final Path zipInLocalSys = Files.createTempFile(dir, "commons-compress-memoryfs", ".zip");
-            try (final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys.toFile(), 64 * 1024L)) {
+            try (ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInLocalSys.toFile(), 64 * 1024L)) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry(textFileInMemSys, textFileInMemSys.getFileName().toString());
                 entry.setSize(Files.size(textFileInMemSys));
                 zipOut.putArchiveEntry(entry);
@@ -403,26 +448,22 @@ public class ZipMemoryFileSystemTest {
                 zipOut.finish();
                 List<Path> splitZips;
                 try (Stream<Path> paths = Files.walk(dir, 1)) {
-                    splitZips = paths
-                            .filter(Files::isRegularFile)
-                            .peek(path -> println("Found: " + path.toAbsolutePath()))
-                            .collect(Collectors.toList());
+                    splitZips = paths.filter(Files::isRegularFile).peek(path -> println("Found: " + path.toAbsolutePath())).collect(Collectors.toList());
                 }
                 assertEquals(splitZips.size(), 2);
-                assertEquals(Files.size(splitZips.get(0)) +
-                        Files.size(splitZips.get(1)) - 4, zipOut.getBytesWritten());
+                assertEquals(Files.size(splitZips.get(0)) + Files.size(splitZips.get(1)) - 4, zipOut.getBytesWritten());
             }
         }
 
     }
 
     @Test
-    public void zipToMemoryFileSystemOutputStream() throws IOException, ArchiveException {
+    public void testZipToMemoryFileSystemOutputStream() throws IOException, ArchiveException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path p = fileSystem.getPath("target.zip");
 
-            try (final OutputStream out = Files.newOutputStream(p);
-                 final ArchiveOutputStream zipOut = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.ZIP, out)) {
+            try (OutputStream out = Files.newOutputStream(p);
+                    ArchiveOutputStream<ZipArchiveEntry> zipOut = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.ZIP, out)) {
                 final String content = "Test";
                 final ZipArchiveEntry entry = new ZipArchiveEntry("test.txt");
                 entry.setSize(content.length());
@@ -438,11 +479,11 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipToMemoryFileSystemPath() throws IOException {
+    public void testZipToMemoryFileSystemPath() throws IOException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path zipInMemSys = fileSystem.getPath("target.zip");
 
-            try (final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInMemSys)) {
+            try (ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInMemSys)) {
                 final String content = "Test";
                 final ZipArchiveEntry entry = new ZipArchiveEntry("test.txt");
                 entry.setSize(content.length());
@@ -458,14 +499,13 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipToMemoryFileSystemSeekableByteChannel() throws IOException {
+    public void testZipToMemoryFileSystemSeekableByteChannel() throws IOException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path zipInMemSys = fileSystem.getPath("target.zip");
 
-            try (final SeekableByteChannel byteChannel = Files.newByteChannel(zipInMemSys,
-                    EnumSet.of(StandardOpenOption.READ, StandardOpenOption.WRITE,
-                            StandardOpenOption.TRUNCATE_EXISTING, StandardOpenOption.CREATE_NEW));
-                 final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(byteChannel)) {
+            try (SeekableByteChannel byteChannel = Files.newByteChannel(zipInMemSys,
+                    EnumSet.of(StandardOpenOption.READ, StandardOpenOption.WRITE, StandardOpenOption.TRUNCATE_EXISTING, StandardOpenOption.CREATE_NEW));
+                    ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(byteChannel)) {
                 final String content = "Test";
                 final ZipArchiveEntry entry = new ZipArchiveEntry("test.txt");
                 entry.setSize(content.length());
@@ -481,13 +521,13 @@ public class ZipMemoryFileSystemTest {
     }
 
     @Test
-    public void zipToMemoryFileSystemSplitPath() throws IOException, NoSuchAlgorithmException {
+    public void testZipToMemoryFileSystemSplitPath() throws IOException, NoSuchAlgorithmException {
         try (FileSystem fileSystem = MemoryFileSystemBuilder.newLinux().build()) {
             final Path zipInMemSys = fileSystem.getPath("target.zip");
             final byte[] bytes = new byte[100 * 1024];
             SecureRandom.getInstanceStrong().nextBytes(bytes);
 
-            try (final ArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInMemSys, 64 * 1024L)) {
+            try (ZipArchiveOutputStream zipOut = new ZipArchiveOutputStream(zipInMemSys, 64 * 1024L)) {
                 final ZipArchiveEntry entry = new ZipArchiveEntry("test.txt");
                 entry.setSize(bytes.length);
                 zipOut.putArchiveEntry(entry);
@@ -499,14 +539,10 @@ public class ZipMemoryFileSystemTest {
 
                 List<Path> splitZips;
                 try (Stream<Path> paths = Files.walk(fileSystem.getPath("."), 1)) {
-                    splitZips = paths
-                            .filter(Files::isRegularFile)
-                            .peek(path -> println("Found: " + path.toAbsolutePath()))
-                            .collect(Collectors.toList());
+                    splitZips = paths.filter(Files::isRegularFile).peek(path -> println("Found: " + path.toAbsolutePath())).collect(Collectors.toList());
                 }
                 assertEquals(splitZips.size(), 2);
-                assertEquals(Files.size(splitZips.get(0)) +
-                        Files.size(splitZips.get(1)) - 4, zipOut.getBytesWritten());
+                assertEquals(Files.size(splitZips.get(0)) + Files.size(splitZips.get(1)) - 4, zipOut.getBytesWritten());
             }
         }
 
