@@ -119,7 +119,7 @@ public final class DetectCompressorTest {
         new TestData("multiple.xz", new char[] { 'a' }, factoryFalse, false),
         new TestData("multiple.xz", new char[] { 'a' }, factorySetFalse, false),
         new TestData("multiple.xz", new char[] { 'a' }, factory, false),
-        // @formatter:off
+        // @formatter:on
     };
 
     @SuppressWarnings("resource") // Caller closes.
@@ -128,12 +128,14 @@ public final class DetectCompressorTest {
     }
 
     @SuppressWarnings("resource") // Caller closes.
-    private CompressorInputStream createCompressorInputStream(final String resource, final CompressorStreamFactory factory) throws CompressorException, IOException {
+    private CompressorInputStream createCompressorInputStream(final String resource, final CompressorStreamFactory factory)
+            throws CompressorException, IOException {
         return factory.createCompressorInputStream(new BufferedInputStream(Files.newInputStream(getFile(resource).toPath())));
     }
 
     @SuppressWarnings("resource") // Caller closes.
-    private CompressorInputStream createCompressorInputStream(final String resource, final Set<String> compressorNames) throws CompressorException, IOException {
+    private CompressorInputStream createCompressorInputStream(final String resource, final Set<String> compressorNames)
+            throws CompressorException, IOException {
         return factory.createCompressorInputStream(new BufferedInputStream(Files.newInputStream(getFile(resource).toPath())), compressorNames);
     }
 
@@ -320,7 +322,6 @@ public final class DetectCompressorTest {
         }
     }
 
-
     @Test
     public void testOverride() {
         final CompressorStreamFactory fac1 = new CompressorStreamFactory();
