@@ -28,6 +28,7 @@ public class BlockSortTest {
     private static final class DS {
         private final BZip2CompressorOutputStream.Data data;
         private final BlockSort s;
+
         DS(final BZip2CompressorOutputStream.Data data, final BlockSort s) {
             this.data = data;
             this.s = s;
@@ -35,56 +36,36 @@ public class BlockSortTest {
     }
 
     /*
-      Burrows-Wheeler transform of fixture the manual way:
+     * Burrows-Wheeler transform of fixture the manual way:
+     *
+     * build the matrix
+     *
+     * 0, 1, 252, 253, 255, 254, 3, 2, 128 1, 252, 253, 255, 254, 3, 2, 128, 0 252, 253, 255, 254, 3, 2, 128, 0, 1 253, 255, 254, 3, 2, 128, 0, 1, 252 255, 254,
+     * 3, 2, 128, 0, 1, 252, 253 254, 3, 2, 128, 0, 1, 252, 253, 255 3, 2, 128, 0, 1, 252, 253, 255, 254 2, 128, 0, 1, 252, 253, 255, 254, 3 128, 0, 1, 252,
+     * 253, 255, 254, 3, 2
+     *
+     * sort it
+     *
+     * 0, 1, 252, 253, 255, 254, 3, 2, 128 1, 252, 253, 255, 254, 3, 2, 128, 0 2, 128, 0, 1, 252, 253, 255, 254, 3 3, 2, 128, 0, 1, 252, 253, 255, 254 128, 0,
+     * 1, 252, 253, 255, 254, 3, 2 252, 253, 255, 254, 3, 2, 128, 0, 1 253, 255, 254, 3, 2, 128, 0, 1, 252 254, 3, 2, 128, 0, 1, 252, 253, 255 255, 254, 3, 2,
+     * 128, 0, 1, 252, 253
+     *
+     * grab last column
+     *
+     * 128, 0, 3, 254, 2, 1, 252, 255, 253
+     *
+     * and the original line has been 0
+     */
 
-      * build the matrix
+    private static final byte[] FIXTURE = { 0, 1, (byte) 252, (byte) 253, (byte) 255, (byte) 254, 3, 2, (byte) 128 };
 
-      0, 1, 252, 253, 255, 254, 3, 2, 128
-      1, 252, 253, 255, 254, 3, 2, 128, 0
-      252, 253, 255, 254, 3, 2, 128, 0, 1
-      253, 255, 254, 3, 2, 128, 0, 1, 252
-      255, 254, 3, 2, 128, 0, 1, 252, 253
-      254, 3, 2, 128, 0, 1, 252, 253, 255
-      3, 2, 128, 0, 1, 252, 253, 255, 254
-      2, 128, 0, 1, 252, 253, 255, 254, 3
-      128, 0, 1, 252, 253, 255, 254, 3, 2
+    private static final byte[] FIXTURE_BWT = { (byte) 128, 0, 3, (byte) 254, 2, 1, (byte) 252, (byte) 255, (byte) 253 };
 
-      * sort it
+    private static final int[] FIXTURE_SORTED = { 0, 1, 7, 6, 8, 2, 3, 5, 4 };
 
-      0, 1, 252, 253, 255, 254, 3, 2, 128
-      1, 252, 253, 255, 254, 3, 2, 128, 0
-      2, 128, 0, 1, 252, 253, 255, 254, 3
-      3, 2, 128, 0, 1, 252, 253, 255, 254
-      128, 0, 1, 252, 253, 255, 254, 3, 2
-      252, 253, 255, 254, 3, 2, 128, 0, 1
-      253, 255, 254, 3, 2, 128, 0, 1, 252
-      254, 3, 2, 128, 0, 1, 252, 253, 255
-      255, 254, 3, 2, 128, 0, 1, 252, 253
+    private static final byte[] FIXTURE2 = { 'C', 'o', 'm', 'm', 'o', 'n', 's', ' ', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', };
 
-      * grab last column
-
-      128, 0, 3, 254, 2, 1, 252, 255, 253
-
-        and the original line has been 0
-    */
-
-    private static final byte[] FIXTURE = { 0, 1, (byte) 252, (byte) 253, (byte) 255,
-                                            (byte) 254, 3, 2, (byte) 128 };
-
-    private static final byte[] FIXTURE_BWT = { (byte) 128, 0, 3, (byte) 254, 2, 1,
-                                                (byte) 252, (byte) 255, (byte) 253 };
-
-    private static final int[] FIXTURE_SORTED = {
-        0, 1, 7, 6, 8, 2, 3, 5, 4
-    };
-
-    private static final byte[] FIXTURE2 = {
-        'C', 'o', 'm', 'm', 'o', 'n', 's', ' ', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's',
-    };
-
-    private static final byte[] FIXTURE2_BWT = {
-        's', 's', ' ', 'r', 'o', 'm', 'o', 'o', 'C', 'C', 'm', 'm', 'p', 'n', 's', 'e',
-    };
+    private static final byte[] FIXTURE2_BWT = { 's', 's', ' ', 'r', 'o', 'm', 'o', 'o', 'C', 'C', 'm', 'm', 'p', 'n', 's', 'e', };
 
     private void assertFixture2Sorted(final BZip2CompressorOutputStream.Data data) {
         assertFixtureSorted(data, FIXTURE2, FIXTURE2_BWT);
@@ -94,8 +75,7 @@ public class BlockSortTest {
         assertFixtureSorted(data, FIXTURE, FIXTURE_BWT);
     }
 
-    private void assertFixtureSorted(final BZip2CompressorOutputStream.Data data,
-                                     final byte[] fixture, final byte[] fixtureBwt) {
+    private void assertFixtureSorted(final BZip2CompressorOutputStream.Data data, final byte[] fixture, final byte[] fixtureBwt) {
         assertEquals(fixture[fixture.length - 1], data.block[0]);
         for (int i = 0; i < fixture.length; i++) {
             assertEquals(fixtureBwt[i], data.block[data.fmap[i]]);
@@ -168,4 +148,4 @@ public class BlockSortTest {
         ds.s.mainSort(ds.data, FIXTURE.length - 1);
         assertFixtureSorted(ds.data);
     }
-}
\ No newline at end of file
+}
