@@ -26,7 +26,7 @@ import java.io.InputStream;
 import java.nio.file.Files;
 
 import org.apache.commons.compress.AbstractTest;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
 
 public class DeflateCompressorInputStreamTest {
