@@ -29,11 +29,11 @@ public class Deflate64BugsTest {
 
     @Test
     public void testReadBeyondMemoryException() throws Exception {
-        try (ZipFile zfile = new ZipFile(getFile("COMPRESS-380/COMPRESS-380-readbeyondmemory.zip"))) {
+        try (ZipFile zfile = ZipFile.builder().setFile(getFile("COMPRESS-380/COMPRESS-380-readbeyondmemory.zip")).get()) {
             final Enumeration<ZipArchiveEntry> entries = zfile.getEntries();
             while (entries.hasMoreElements()) {
                 final ZipArchiveEntry e = entries.nextElement();
-                final byte [] buf = new byte [1024 * 8];
+                final byte[] buf = new byte[1024 * 8];
                 try (InputStream is = zfile.getInputStream(e)) {
                     while (true) {
                         final int read = is.read(buf);
