@@ -32,7 +32,7 @@ import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 import org.apache.commons.compress.AbstractTest;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
 
 /**
@@ -43,14 +43,15 @@ import org.junit.jupiter.api.Test;
 public class ZCompressorInputStreamTest {
 
     @Test
-    public void testFailsToCreateZCompressorInputStreamAndThrowsIOException() {
-        final SequenceInputStream sequenceInputStream = new SequenceInputStream(Collections.emptyEnumeration());
-        assertThrows(IOException.class, () -> new ZCompressorInputStream(sequenceInputStream));
+    public void testFailsToCreateZCompressorInputStreamAndThrowsIOException() throws IOException {
+        try (SequenceInputStream sequenceInputStream = new SequenceInputStream(Collections.emptyEnumeration())) {
+            assertThrows(IOException.class, () -> new ZCompressorInputStream(sequenceInputStream));
+        }
     }
 
     @Test
     public void testInvalidMaxCodeSize() throws IOException {
-        final byte[] bytes = Files.readAllBytes(AbstractTest.getPath("bla.tar.Z"));
+        final byte[] bytes = AbstractTest.readAllBytes("bla.tar.Z");
 
         // @formatter:off
         final IntStream[] invalid = {
@@ -68,8 +69,7 @@ public class ZCompressorInputStreamTest {
 
         Stream.of(invalid).forEach(ints -> ints.forEach(i -> {
             bytes[2] = (byte) i;
-            assertThrows(IllegalArgumentException.class, () -> new ZCompressorInputStream(new ByteArrayInputStream(bytes), 1024 * 1024),
-                    () -> "value=" + i);
+            assertThrows(IllegalArgumentException.class, () -> new ZCompressorInputStream(new ByteArrayInputStream(bytes), 1024 * 1024), () -> "value=" + i);
         }));
     }
 
