@@ -30,7 +30,7 @@ import java.nio.file.Files;
 import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.compressors.CompressorInputStream;
 import org.apache.commons.compress.compressors.CompressorStreamFactory;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
 
 import com.github.luben.zstd.NoPool;
@@ -138,51 +138,45 @@ public class ZstdCompressorInputStreamTest extends AbstractTest {
     @Test
     public void testZstdDecode() throws IOException {
         final File input = getFile("zstandard.testdata.zst");
-        final File expected = getFile("zstandard.testdata");
         try (InputStream inputStream = Files.newInputStream(input.toPath());
                 ZstdCompressorInputStream zstdInputStream = new ZstdCompressorInputStream(inputStream)) {
-            final byte[] b = new byte[97];
-            IOUtils.read(expected, b);
+            final byte[] expected = readAllBytes("zstandard.testdata");
             final ByteArrayOutputStream bos = new ByteArrayOutputStream();
             int readByte = -1;
             while ((readByte = zstdInputStream.read()) != -1) {
                 bos.write(readByte);
             }
-            assertArrayEquals(b, bos.toByteArray());
+            assertArrayEquals(expected, bos.toByteArray());
         }
     }
 
     @Test
     public void testZstdDecodeWithNoPool() throws IOException {
         final File input = getFile("zstandard.testdata.zst");
-        final File expected = getFile("zstandard.testdata");
         try (InputStream inputStream = Files.newInputStream(input.toPath());
                 ZstdCompressorInputStream zstdInputStream = new ZstdCompressorInputStream(inputStream, NoPool.INSTANCE)) {
-            final byte[] b = new byte[97];
-            IOUtils.read(expected, b);
+            final byte[] expected = readAllBytes("zstandard.testdata");
             final ByteArrayOutputStream bos = new ByteArrayOutputStream();
             int readByte = -1;
             while ((readByte = zstdInputStream.read()) != -1) {
                 bos.write(readByte);
             }
-            assertArrayEquals(b, bos.toByteArray());
+            assertArrayEquals(expected, bos.toByteArray());
         }
     }
 
     @Test
     public void testZstdDecodeWithRecyclingBufferPool() throws IOException {
         final File input = getFile("zstandard.testdata.zst");
-        final File expected = getFile("zstandard.testdata");
         try (InputStream inputStream = Files.newInputStream(input.toPath());
                 ZstdCompressorInputStream zstdInputStream = new ZstdCompressorInputStream(inputStream, RecyclingBufferPool.INSTANCE)) {
-            final byte[] b = new byte[97];
-            IOUtils.read(expected, b);
+            final byte[] expected = readAllBytes("zstandard.testdata");
             final ByteArrayOutputStream bos = new ByteArrayOutputStream();
             int readByte = -1;
             while ((readByte = zstdInputStream.read()) != -1) {
                 bos.write(readByte);
             }
-            assertArrayEquals(b, bos.toByteArray());
+            assertArrayEquals(expected, bos.toByteArray());
         }
     }
 
