@@ -39,36 +39,35 @@ public class ChecksumVerifyingInputStreamTest {
         final Adler32 adler32 = new Adler32();
         final byte[] byteArray = new byte[3];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(adler32, byteArrayInputStream, -1859L,
-                (byte) -68)) {
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(adler32, byteArrayInputStream, -1859L, (byte) -68)) {
             assertThrows(IOException.class, () -> checksumVerifyingInputStream.read(byteArray));
         }
     }
 
     @Test
     public void testReadTakingNoArgumentsThrowsIOException() throws IOException {
-        final CRC32 cRC32_ = new CRC32();
+        final CRC32 crc32 = new CRC32();
         final byte[] byteArray = new byte[9];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte) 1, (byte) 1)) {
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(crc32, byteArrayInputStream, (byte) 1, (byte) 1)) {
             assertThrows(IOException.class, () -> checksumVerifyingInputStream.read());
         }
     }
 
     @Test
     public void testSkip() throws IOException {
-        final CRC32 cRC32_ = new CRC32();
+        final CRC32 crc32 = new CRC32();
         final byte[] byteArray = new byte[4];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte) 33, 2303L)) {
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(crc32, byteArrayInputStream, (byte) 33, 2303L)) {
             @SuppressWarnings("unused")
             final int intOne = checksumVerifyingInputStream.read(byteArray);
             final long skipReturnValue = checksumVerifyingInputStream.skip((byte) 1);
-            assertEquals(558161692L, cRC32_.getValue());
+            assertEquals(558161692L, crc32.getValue());
             assertEquals(0, byteArrayInputStream.available());
-            assertArrayEquals(new byte[] { (byte) 0, (byte) 0, (byte) 0, (byte) 0 }, byteArray);
+            assertArrayEquals(new byte[4], byteArray);
             assertEquals(0L, skipReturnValue);
         }
     }
 
-}
\ No newline at end of file
+}
