@@ -19,6 +19,7 @@ package org.apache.commons.compress.utils;
 
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.ByteArrayInputStream;
@@ -27,10 +28,13 @@ import java.io.EOFException;
 import java.io.FilterInputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.lang.reflect.Field;
+import java.io.OutputStream;
 import java.nio.ByteBuffer;
 import java.nio.channels.ReadableByteChannel;
+import java.nio.charset.StandardCharsets;
 
+import org.apache.commons.io.input.NullInputStream;
+import org.apache.commons.io.output.NullOutputStream;
 import org.junit.jupiter.api.Test;
 
 public class IOUtilsTest {
@@ -53,6 +57,29 @@ public class IOUtilsTest {
         }
     }
 
+    @Test
+    public void testCopy_inputStreamToOutputStream_IO84() throws Exception {
+        final long size = (long) Integer.MAX_VALUE + (long) 1;
+        final InputStream in = new NullInputStream(size);
+        final OutputStream out = NullOutputStream.INSTANCE;
+        // Test copy() method
+        assertEquals(-1, IOUtils.copy(in, out));
+        // reset the input
+        in.close();
+    }
+
+    @Test
+    public void testCopy_inputStreamToOutputStream_nullIn() {
+        final OutputStream out = new ByteArrayOutputStream();
+        assertThrows(NullPointerException.class, () -> IOUtils.copy((InputStream) null, out));
+    }
+
+    @Test
+    public void testCopy_inputStreamToOutputStream_nullOut() {
+        final InputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4 });
+        assertThrows(NullPointerException.class, () -> IOUtils.copy(in, (OutputStream) null));
+    }
+
     @Test
     public void testCopyRangeDoesntCopyMoreThanAskedFor() throws IOException {
         try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 });
@@ -80,8 +107,8 @@ public class IOUtilsTest {
     }
 
     @Test
-    public void testCopyThrowsOnZeroBufferSize() {
-        assertThrows(IllegalArgumentException.class, () -> IOUtils.copy(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), new ByteArrayOutputStream(), 0));
+    public void testCopyThrowsOnZeroBufferSize() throws IOException {
+        assertEquals(0, IOUtils.copy(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), new ByteArrayOutputStream(), 0));
     }
 
     @Test
@@ -165,9 +192,7 @@ public class IOUtilsTest {
 
     @Test
     public void testReadRangeMoreThanCopyBufferSize() throws Exception {
-        final Field COPY_BUF_SIZE = IOUtils.class.getDeclaredField("COPY_BUF_SIZE");
-        COPY_BUF_SIZE.setAccessible(true);
-        final int copyBufSize = (int) COPY_BUF_SIZE.get(null);
+        final int copyBufSize = org.apache.commons.io.IOUtils.DEFAULT_BUFFER_SIZE;
 
         // Make an input that requires two read loops to trigger COMPRESS-585
         final byte[] input = new byte[copyBufSize + 10];
@@ -212,4 +237,18 @@ public class IOUtilsTest {
             }
         });
     }
+
+    @Test
+    public void testToByteArray_InputStream() throws Exception {
+        final byte[] bytes = "ABCB".getBytes(StandardCharsets.UTF_8);
+        try (InputStream fin = new ByteArrayInputStream(bytes)) {
+            @SuppressWarnings("deprecation")
+            final byte[] out = IOUtils.toByteArray(fin);
+            assertNotNull(out);
+            assertEquals(0, fin.available());
+            assertEquals(4, out.length);
+            assertArrayEquals(bytes, out);
+        }
+    }
+
 }
