@@ -13,7 +13,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
  */
 
 package org.apache.commons.compress.utils;
@@ -25,7 +24,7 @@ import org.junit.jupiter.api.Test;
 public class OsgiUtilsTest {
 
     @Test
-    public void detectsItIsNotRunningInsideOsgiEnv() {
+    public void testDetectsItIsNotRunningInsideOsgiEnv() {
         assertFalse(OsgiUtils.isRunningInOsgiEnvironment());
     }
 
